@@ -41,17 +41,32 @@ cd ../configurator/; make clean
 rm Makefile
 rm -r .ui .moc .obj core*
 
+cd ../addons/jhead/libjhead/jheadGui; make clean
+rm -r jheadGui Makefile .ui .moc .obj
+
+cd ..; make clean 
+rm Makefile Makefile.interface
+rm -r .obj .moc .ui
+cd ..; make clean
+rm jhead *.o
+cd ..; rm ../lib/*
+
 cd ../qdvdauthor/; make clean 
 rm Makefile
 rm i18n/*.qm
 rm CONFIG.h
 rm core*
 
-cd tools; make clean
-rm core*
+if [ -e tools ];
+then
+  cd tools; make clean
+  rm core*
+  cd ..
+fi;
 
-cd ../qslideshow/; make clean
+cd qslideshow/; make clean
 rm Makefile
+rm -r .ui .moc .obj
 rm core*
 
 cd ../qplayer/; make clean
@@ -65,9 +80,23 @@ rm core*
 
 cd ../plugins/menuslide; make clean
 rm Makefile
+rm -r .obj .moc .ui menuslide
+rm core*
+
+cd ../simpledvd; make clean
+rm -r Makefile .obj .ui .moc
 rm menuslide
 rm core*
 
+cd ../complexdvd; make clean
+rm -r Makefile .obj .ui .moc
+rm core*
+
+cd ../testplugs; make clean
+rm -r Makefile .obj .ui .moc
+rm core*
+rm ../plugins/*
+
 cd ../..
 rm -r .ui .moc .obj
 rm core*
@@ -75,6 +104,10 @@ rm core*
 cd ../manual; make clean
 rm core*
 
+cd ../qrender/; make clean
+rm -rf Makefile .obj .ui .moc 
+rm core*
+
 cd ..
 sourceFiles=`cat \`find . -name "*.cpp"\` | wc -l`
 sourceHeader=`cat \`find . -name "*.h"\`  | wc -l`
