@@ -217,15 +217,15 @@ void Configurator::slotCompile()
 	// Next we should remove the Makefile's so we build with new media engine - support.
 	if (hasMediaEngineSelectionChanged())
 		iRet = system ("rm Makefile ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile");
-
 	m_pNewProcess->setWorkingDirectory (QDir ("../"));
 	// And here we generate the make file and compile the application.
-	m_pNewProcess->addArgument ("qmake");
-	m_pNewProcess->addArgument ("all.pro");
-	m_pNewProcess->start ();
-	// wait for a second until qmake is done ...
-	while (m_pNewProcess->isRunning())
-		sleep (1);
+	m_pNewProcess->addArgument (  "qmake" );
+	m_pNewProcess->addArgument ( "all.pro");
+	m_pNewProcess->start ( );
+	// wait for a second until qmake is done ..
+	while ( m_pNewProcess->isRunning ( ) )
+		sleep ( 1 );
+
 	m_pNewProcess->clearArguments();
 	QApplication::setOverrideCursor (myCursor);
 
@@ -375,46 +375,74 @@ void Configurator::slotProcessExited()
 
 int Configurator::getCompileSteps ()
 {
-	int iStepCounter, t;
-	int iUIFiles, iHeaderFiles, iObjectHeader ,iExtra;
+	int iStepCounter, iUIFiles, iHeaderFiles, iObjectHeader ,iExtra;
 	QStringList fileList;
+	QString     qsPath;
+	bool        bFirst;
 	// This function checks how many steps the compilation process approximately has.
 //	QStringList fileList;
 // 	5 *.ui + 2 *.h (object) + .h(normal) - .ui/* -.moc/* -.obj/*
-	QString arrayDirs[7];
+	QStringList listSource, listGenerated;
 	// Here we init the directory array
-	arrayDirs[0] = QString ("../qdvdauthor");
-	arrayDirs[1] = QString ("../qdvdauthor/qplayer");
-	arrayDirs[2] = QString ("../qdvdauthor/qplayer/engines");
-	arrayDirs[3] = QString ("../qdvdauthor/qslideshow");
-	arrayDirs[4] = QString ("../qdvdauthor/.ui");
-	arrayDirs[5] = QString ("../qdvdauthor/.moc");
-	arrayDirs[6] = QString ("../qdvdauthor/.obj");
+	listSource.append    ( "../qdvdauthor"                 );
+	listSource.append    ( "../qdvdauthor/qplayer"         );
+	listSource.append    ( "../qdvdauthor/qplayer/engines" );
+	listSource.append    ( "../qdvdauthor/qslideshow"      );
+	listGenerated.append ( "../qdvdauthor/.ui"             );
+	listGenerated.append ( "../qdvdauthor/.moc"            );
+	listGenerated.append ( "../qdvdauthor/.obj"            );
+
+	// Add the libjhead dependand stuff
+	listSource.append    ( "../addons/jhead/libjhead"      );
+        listGenerated.append ( "../addons/jhead/libjhead/.ui"  );
+	listGenerated.append ( "../addons/jhead/libjhead/.moc" );
+	listGenerated.append ( "../addons/jhead/libjhead/.obj" );	
+
+	listSource.append    ( "../qdvdauthor/plugins/simpledvd"       );
+	listGenerated.append ( "../qdvdauthor/plugins/simpledvd/.ui"   );
+	listGenerated.append ( "../qdvdauthor/plugins/simpledvd/.moc"  );
+	listGenerated.append ( "../qdvdauthor/plugins/simpledvd/.obj"  );
+
+	listSource.append    ( "../qdvdauthor/plugins/complexdvd"      );
+	listGenerated.append ( "../qdvdauthor/plugins/complexdvd/.ui"  );
+	listGenerated.append ( "../qdvdauthor/plugins/complexdvd/.moc" );
+	listGenerated.append ( "../qdvdauthor/plugins/complexdvd/.obj" );
+
 	// Next we change into the source directory
 	QDir theDir ("../qdvdauthor");
 
 	iUIFiles = iHeaderFiles = iObjectHeader = iExtra = 0;
 	// obtain with : `find . -name "*.h" -exec grep Q_OBJECT {} \; -print | grep -v Q_OBJECT | grep -v "/.ui/" | wc -l`
-	iObjectHeader = 39;
+	iObjectHeader = 83; // 39;
 	// obtain through trial and error
 	iExtra        = 19;
 	// now we get the rest of the information ...
 	theDir.setNameFilter("*.ui");
-	for (t=0;t<4;t++)	{
-		theDir.setPath(arrayDirs[t]);
+	bFirst = true;
+	QStringList::iterator it = listSource.begin ( );
+	while ( it != listSource.end ( ) )  {
+		qsPath = *it++;
+		theDir.setPath ( qsPath );
 		fileList = theDir.entryList();
 		iUIFiles += fileList.count();
-		if (t>0)	// the first entry we dont want to change directories
+		if ( bFirst )  {	// the first entry we dont want to change directories
 			theDir.setPath("..");
+			bFirst = false;
+		}
 	}
+	bFirst    = true;
 	iUIFiles *= 5;
 	theDir.setNameFilter("*.h");
-	for (t=0;t<4;t++)	{
-		theDir.setPath(arrayDirs[t]);
+	it = listSource.begin ( );
+	while ( it != listSource.end ( ) )  {
+		qsPath = *it++;
+		theDir.setPath ( qsPath );
 		fileList = theDir.entryList();
 		iHeaderFiles += fileList.count();
-		if (t>0)	// the first entry we dont want to change directories
+		if ( bFirst )  { // the first entry we dont want to change directories
 			theDir.setPath("..");
+			bFirst = false;
+		}
 	}
 	// finally we adjust for object headers count.
 	iObjectHeader *= 2;
@@ -430,8 +458,10 @@ int Configurator::getCompileSteps ()
 		 iStepCounter -= 6;
 
 	theDir.setNameFilter("*");
-	for (t=4;t<7;t++)	{
-		theDir.setPath(arrayDirs[t]);
+	it = listGenerated.begin ( );
+	while ( it != listGenerated.end ( ) )  {
+		qsPath = *it++;
+		theDir.setPath  ( qsPath );
 		fileList = theDir.entryList();
 		iStepCounter -= fileList.count();
 		theDir.setPath("..");
@@ -442,6 +472,7 @@ int Configurator::getCompileSteps ()
 	// Okay, for now manually until I found a good algol ...
 //	iStepCounter = 270;	// MPlayer and Xine support
 //	iStepCounter = 276;	// VLC, MPlayer and Xine support
+//printf ( "iStepCounter = <%d>\n", iStepCounter );
 	return iStepCounter;
 }
 
