@@ -1,5 +1,5 @@
 
-cd /home/varol/projects/
+cd $HOME/projects/
 
 echo "cd htdocs/nightly/
 put qdvdauthor.tar.bz2
