@@ -147,7 +147,7 @@ void CreateTemplatePreview::paintEvent ( QPaintEvent *pEvent )
   //void drawText ( int x, int y, const QString &, int len = -1, TextDirection dir = Auto )
   thePainter.setBrush ( Qt::black  );
   thePainter.setPen   ( Qt::yellow );
-    
+
   for (t=0;t<(int)m_listOfDropZones.count ();t++) {
     pMenuObject = m_listOfDropZones[t];
     rect = pMenuObject->boundingRect ( );
@@ -291,7 +291,7 @@ void DialogCreateTemplate::initMe ( DVDMenu *pDVDMenu )
     char c = m_qsCreateString.constref ( t );
     qsTemp += --c;
   }
-  
+
   pLayout->addWidget( m_pFrameProperties, 1, 1 );
   QSpacerItem *spacer1 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Expanding );
   pLayout->addItem( spacer1, 0, 1 );
@@ -310,7 +310,7 @@ void DialogCreateTemplate::initMe ( DVDMenu *pDVDMenu )
 
   m_pEditAuthor->setText  ( qsAuthor );
   m_pEditContact->setText ( qsContactInfo );
-  
+
   connect ( m_pButtonCreateTemplate, SIGNAL ( clicked ( ) ), this, SLOT ( slotCreateTemplate ( ) ) );
   connect ( m_pButtonInstall,        SIGNAL ( clicked ( ) ), this, SLOT ( slotInstall        ( ) ) );
   connect ( m_pButtonHelp,           SIGNAL ( clicked ( ) ), this, SLOT ( slotHelp           ( ) ) );
@@ -364,7 +364,7 @@ void DialogCreateTemplate::slotCreateTemplate ( )
     QString qsAuthor, qsContactInfo;
     qsAuthor      = m_pEditAuthor->text  ( );
     qsContactInfo = m_pEditContact->text ( );
-    
+
     qInit.setTemplateAuthor  ( qsAuthor );
     qInit.setTemplateContact ( qsContactInfo );
 
@@ -896,7 +896,7 @@ void DialogCreateTemplate::handleMenuImages ( QString &qsMenuXml, QString &qsTem
       }
       else // Not found .. Oooops ...
 	qsFileName = QString ( "dummy.png" );
-      
+
       qsTemp = QString ( "FileName=\"+PREFIX_DIRECTORY+/%1%2/%3\"" ).arg ( getTypePath ( ) ).arg ( QFile::encodeName ( m_pEditFileName->text ( ) ) ).arg ( qsFileName );
       qsImageObject.replace ( rx1, qsTemp );
       listNew.append  ( qsImageObject );
@@ -986,7 +986,7 @@ QString DialogCreateTemplate::handleButtonXml ( int iCount, QString &qsButtonXml
     qsNormalState.replace ( rx1, qsKey );
     rx1.setPattern ( "TextObject" );
     qsNormalState.replace ( rx1, qsKey );
-    
+
     // Replace the FileName - attribute
     rx1.setPattern ( "FileName=\"[^\"]*\"" );
     qsKey = QString( "FileName=\"+DROP_ZONE_%1_FILE_NAME+\"" ).arg ( iCount );
@@ -1106,7 +1106,7 @@ bool DialogCreateTemplate::createIndexXml ( )
     iHeight = pThumbnail->height ( );
   }
   qsCategory = m_pComboCategory->currentText ( );
-  
+
   qsFileName = m_pEditFileName->text ( );
   qsTemplatePath = QString ( "%1/%2%3" ).arg ( Global::qsTempPath ).arg ( getTypePath ( ) ).arg ( qsFileName );
 
@@ -1159,6 +1159,11 @@ bool DialogCreateTemplate::createWebHtml ( )
 
 void DialogCreateTemplate::slotUpload ( )
 {
+  QValueList<MenuObject *> listOfDropZones = m_pFrameProperties->getDropZones ( );
+  if ( listOfDropZones.count ( ) < 1 )  {
+    MessageBox::warning ( this, tr ("No DropZones defined"), tr ( "You need to define at least one DropZone.\nPlease go to the [Define Drop Zones] tab and define at least 1 DropZone.\n"), QMessageBox::Ok, QMessageBox::NoButton );
+    return;
+  }
   QString qsUrl;
   qsUrl = m_qsCreateString + QString( "outdex.xml" );
   m_Network = QUrlOperator ( qsUrl );
