@@ -25,7 +25,8 @@
 #include <qtooltip.h>
 #include <qscrollview.h>
 #include <qwhatsthis.h>
-#include <qregexp.h> 
+#include <qregexp.h>
+#include <qtimer.h>
 
 #include "win32.h"
 #include "execute.h"
@@ -82,19 +83,13 @@ printf ("\n\n");
 */
 
 	// In case the user does not want to display a execute Dialog but instead prefers the default settings.
-	if (!bShowDialog)
-		m_doSomething.system (commandList);
+	if ( ! bShowDialog )
+		m_doSomething.system ( commandList );
 
-	createMainForm ();
-	createPreprocessing  ();
-	createDVDAuthorTab   (listExecuteBlocks);
-	createPostprocessing ();
-
-	languageChange();
-	show ();
-	resize( QSize(877, 662).expandedTo(minimumSizeHint()) );
-	clearWState( WState_Polished );
-	slotCheckBlock (true);
+	createMainForm       ( );
+	createPreprocessing  ( );
+	createDVDAuthorTab   ( listExecuteBlocks );
+	QTimer::singleShot ( 50, this, SLOT ( slotResize ( ) ) );
 }
 
 DialogExecute::~DialogExecute()
@@ -109,6 +104,15 @@ DialogExecute::~DialogExecute()
   delete m_pInitObject;
 }
 
+void DialogExecute::slotResize ( )
+{
+  // Delayed initialization to have the dialog on screen for resize.
+  createPostprocessing ( );
+  languageChange ( );
+  resize ( QSize ( 877, 662 ).expandedTo ( minimumSizeHint ( ) ) );
+  slotCheckBlock ( true );
+}
+
 void DialogExecute::setInit(QDVDAuthorInit *pInit)
 {
 	m_pInitObject = pInit;
