@@ -33,6 +33,8 @@ class QPushButton;
 class QTimer;
 
 class SourceToolBar;
+class CXmlSlideshow;
+class Previewer;
 
 // Separate from global namspace because nested classes 
 // are not supported by moc.
@@ -63,10 +65,15 @@ public:
   };
 
   GroupView ( QWidget *, QIconView *, DialogFiles *, SourceFileEntry *p=NULL );
+  GroupView ( QWidget *, QIconView *, DialogFiles *, CXmlSlideshow   * );
   GroupView ( QWidget *, SourceFileEntry * );
   virtual ~GroupView  ( );
 
+  void setSlideshow ( CXmlSlideshow * );
+
+  CXmlSlideshow   *slideshow       ( ); // could be NULL
   SourceFileEntry *sourceFileEntry ( ); // could be NULL
+
   void append ( void * );
 
   QString groupName     ( );
@@ -85,6 +92,7 @@ private: // member variables
   QIconView       *m_pPreview;
   DialogFiles     *m_pDialog;
   SourceFileEntry *m_pSourceFileEntry;
+  CXmlSlideshow   *m_pSlideshow;
 };
 
 class ScanDVDate : public QProcess 
@@ -99,10 +107,10 @@ public:
 
 protected slots:
   virtual void slotExited ( );
- 
+
 private:
-  bool bExited; 
-  QString        qsFileName; 
+  bool bExited;
+  QString        qsFileName;
   QIconViewItem *pItem;
   DialogFiles   *pDialog;
 };
@@ -110,8 +118,6 @@ private:
 class DialogFiles : public uiDialogFiles
 {
   Q_OBJECT
-
-  class Thumbs; // forward declaration
   class DirItem : public QListViewItem  {
   public:
     DirItem ( QListView *, QString );
@@ -127,7 +133,19 @@ class DialogFiles : public uiDialogFiles
     QString  qsPathName;
     bool     bReadable;
   };
+protected:
+  // When the image is rendered the returned data is temp stored in this struct
+  // to be executed in timerEvent.
+  class WorkWaiting  {
+  public:
+     WorkWaiting ( QIconViewItem *, QImage *, bool );
+    ~WorkWaiting ( );
 
+    QIconViewItem *pItem;
+    QImage        *pImage;
+    QString        qsIconText;
+    bool           bMarkIcon;
+  };
   class ThumbnailRequest : public ExecuteJob {
   public:
     ThumbnailRequest ( DialogFiles * );
@@ -154,18 +172,6 @@ class DialogFiles : public uiDialogFiles
     uint iCurrentThumb;
     QImage **arrayOfThumbs;
   };
-  // When the image is rendered the returned data is temp stored in this struct
-  // to be executed in timerEvent.
-  class WorkWaiting  {
-  public:
-    WorkWaiting ( QIconViewItem *, QImage *, bool );
-    ~WorkWaiting ( );
-
-    QIconViewItem *pItem;
-    QImage        *pImage;
-    bool           bMarkIcon;
-  };
-
   class Thumbs {
   public:
      Thumbs ( );
@@ -191,9 +197,10 @@ public:
   };
 
 public: // public strctures ...
-  DialogFiles ( QWidget *, const char *n=0, WFlags f=0 );
+  DialogFiles ( QWidget *, bool b=false, const char *n=0, WFlags f=0 );
   virtual ~DialogFiles ( );
 
+  void initMe        ( );
   void initWork      ( QIconViewItem *, QImage *, bool );
   bool initScanDV    ( Thumbs * );
   void addProgress   ( int );
@@ -203,27 +210,22 @@ public: // public strctures ...
   QValueList<SourceFileEntry *> &getGroups ( );
 
 protected:
-  void initMe            ( );
   void initGroups        ( );
   void copyEntry         ( SourceFileEntry *, SourceFileEntry * );
-  GroupView *addGroup    ( SourceFileEntry * );
   GroupView *addGroup    ( QString &, QStringList & );
   void addSourceToGroup  ( GroupView * );
   QString uniqueGroupName( QString );
   bool findDesktopDir    ( QString );
   void initVirtualFolders( );
   void initDirectories   ( );
-  void showContextMenu   ( const QPoint &, QIconViewItem * );
-  void showBasicMenu     ( const QPoint & );
   void createIconStars   ( );
-  void recreateThumbs    ( Thumbs  * );
   bool isValid           ( QIconViewItem * );
+  bool removeThumb       ( QIconViewItem * );
   void addPlayButton     ( QIconViewItem *, QPixmap * );
+  void recreateThumbs    ( Thumbs  * );
+  void createPix         ( Thumbs  *, uint );
   void createPix         ( QPixmap *, QImage *, float f=0.0f, int i=-1 );
   void markIcon          ( QIconViewItem *, int );
-  void setIconText       ( QIconViewItem * );
-  void setIconText       ( Thumbs * );
-  void resizeIcons       ( int );
 
   void setTreeDir        ( QString );
   void setQuickDir       (     int );
@@ -236,6 +238,8 @@ protected:
   void registerRequest   ( MultiThumbRequest * );
   void append            ( Thumbs  * );
   void clearPreview      ( );
+  void updateTitlebar    ( );
+  void resizeIcons       ( int );
   Thumbs *createFromCache( Cache::Thumbs::Entry * );
   void currentSourceToPreview    ( );
   void allSourcesToPreview       ( );
@@ -243,12 +247,23 @@ protected:
   void play              ( QString );
   void lock              ( );
   void unlock            ( );
+  bool lockDialog        ( );
+  void unlockDialog      ( );
+  bool isImageDialog     ( );
+
   QValueList<QListViewItem *> getSelectedVirtual ( );
 
   // Virtual functions
-  virtual void timerEvent       ( QTimerEvent    * );
-  virtual void load      ( QStringList & );
-  virtual QString getDirFilter  ( );
+  virtual void timerEvent          ( QTimerEvent   * );
+  virtual void load                ( QStringList   & );
+  virtual void setIconText         ( Thumbs        * );
+  virtual void setIconText         ( QIconViewItem * );
+  virtual void newThumbnailRequest ( QIconViewItem * );
+  virtual void showBasicMenu       ( const QPoint &  );
+  virtual void showContextMenu     ( const QPoint &, QIconViewItem * );
+  virtual void playFromGroup       ( Cache::Thumbs::Entry * );
+  virtual GroupView *addGroup      ( SourceFileEntry * );
+  virtual QString getDirFilter     ( );
 
 protected slots:
   virtual void slotToVirtualFolder       ( QListBoxItem  * );
@@ -279,6 +294,7 @@ protected slots:
   virtual void slotEditVirtual           ( );
   virtual void slotCloneVirtual          ( );
   virtual void slotDeleteVirtual         ( );
+  virtual void slotPlay                  ( );
   virtual void accept                    ( );
   virtual void reject                    ( );
   virtual void slotAutoGroup             ( );
@@ -295,11 +311,13 @@ protected:
   static bool m_bDate;
   static bool m_bLength;
   static int  m_iThumbnailSize;
+  bool        m_bTooSmallForText; // less then 50x50 which is too small to display text
 
-  QTimer   *m_pTimerAutoOpen;
-  QTimer   *m_pTimerScanDir;
-  QTimer   *m_pTimerThumbing;
-  QListBox *m_pVirtualFolderDialog;
+  QTimer    *m_pTimerAutoOpen;
+  QTimer    *m_pTimerScanDir;
+  QTimer    *m_pTimerThumbing;
+  QListBox  *m_pVirtualFolderDialog;
+  Previewer *m_pPreviewer;
 
   QString   m_qsProjectDir;
   QString   m_qsDocumentsDir;
@@ -315,13 +333,16 @@ protected:
 
   bool      m_bCanClose;
   bool      m_bCanChangeIcons;
+  bool      m_bIsImageDialog;   // Dialog can either be Image or Video dialog.
   uint      m_iProgress;
-  //uint      m_iThumbnailSize;
   uint      m_iMultiThumbNumber;
 
   QMutex    m_mutex;
+  QMutex    m_mutexDialog;
   QMutex    m_mutexRequest;
 
+  DialogFiles *m_pIAmAlive;
+
   QValueList<ScanDVDate  *>       m_listOfDVScansToDo;
   QValueList<WorkWaiting *>       m_listOfWorkToDo;
   QValueList<MultiThumbRequest *> m_listOfRequests;
