@@ -122,6 +122,7 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
 
   QFileInfo fileInfo;
   QString qsFormat, qsBackgroundName;
+  int iPause = -1;
 
   m_pDVDMenu = pMenu;
   qsFormat = QString ("hh:mm:ss.zzz");
@@ -165,9 +166,14 @@ void DialogMovie::initMe ( DVDMenu *pMenu )
   groupBox8->setTitle ("");
   m_pCheckSameAsMenuLength->hide ( );
 
+  if (  (  ! pMenu->getInterface ( )->qsPause.isEmpty ( ) ) && 
+        (    pMenu->getInterface ( )->qsPause !=  "inf" ) ) 
+    iPause = pMenu->getInterface ( )->qsPause.toInt   ( );
+
   m_pLabelTitle->setText       ( "SubMenu:"       );
   m_pSpinBoxTitle->setValue    ( pMenu->getInterface ( )->iMenu     );
   m_pSpinBoxTitleset->setValue ( pMenu->getInterface ( )->iTitleset );
+  m_pSpinBoxPause->setValue    ( iPause );
   // The VMGM Must stay in Titleset 0 !!!
   if ( ! pMenu->getInterface ( )->bIsSubMenu ) {
     m_pSpinBoxTitle->setEnabled    ( false );
@@ -1977,12 +1983,16 @@ void DialogMovie::accept ()
 	      iSubMenu = -1;
 	  }
 	  
-	  CDVDMenuInterface *pInterface = m_pDVDMenu->getInterface  ( );
-	  startingTime = QTime::fromString ( m_pEditStarting1->text ( ) );
-	  endingTime   = QTime::fromString ( m_pEditEnding1->text   ( ) );
-
+	  CDVDMenuInterface *pInterface = m_pDVDMenu->getInterface   ( );
+	  startingTime = QTime::fromString ( m_pEditStarting1->text  ( ) );
+	  endingTime   = QTime::fromString ( m_pEditEnding1->text    ( ) );
+	  if ( m_pSpinBoxPause->value ( ) == -1 )
+	    pInterface->qsPause = "inf";
+	  else 
+	    pInterface->qsPause = QString ("%1").arg ( m_pSpinBoxPause->value  ( ) );
+         
 	  if ( m_pDVDMenu->getInterface ( )->qsMovieFileName.isEmpty ( ) )
-		  startingTime = QTime ( );
+		startingTime = QTime ( );
 	  // Here we hande the start/stop time.
 	  if ( startingTime.isValid ( ) )	{
 	    pInterface->timeOffset = startingTime;
