@@ -156,6 +156,7 @@ void DialogShadow::initMe ( MenuObject *pMenuObject, QPixmap *pBackground )
      m_pDialSunAngle->setValue       (   iSunAngle   );
      m_pSliderBlur->setValue         (     iBlur     );
      m_pLabelColor->setPaletteBackgroundColor ( m_pShadow->color ( ) );
+     m_pSliderDistance->setPageStep  ( 1 );
 
      m_pSliderShearX->setValue       ( (int) ( m_pShadow->shearX ( ) * 1000.0 ) );
      m_pSliderShearY->setValue       ( (int) ( m_pShadow->shearY ( ) * 1000.0 ) );
@@ -164,7 +165,7 @@ void DialogShadow::initMe ( MenuObject *pMenuObject, QPixmap *pBackground )
      m_pSliderCutOff->setValue       ( (int) ( m_pShadow->cutOff ( ) * 1000.0 ) );
      m_pSliderCutOffRadius->setValue ( (int) ( m_pShadow->cutOffRadius ( ) * 1000.0 ) );
      m_pSliderColorFade->setValue    ( (int) ( m_pShadow->colorFading  ( ) * 1000.0 ) );
-   
+
      m_pEditShearX->setText ( QString ( "%1" ).arg ( m_pShadow->shearX ( ) ) );
      m_pEditShearY->setText ( QString ( "%1" ).arg ( m_pShadow->shearY ( ) ) );
      m_pEditScaleX->setText ( QString ( "%1" ).arg ( m_pShadow->scaleX ( ) ) );
@@ -181,7 +182,7 @@ void DialogShadow::initMe ( MenuObject *pMenuObject, QPixmap *pBackground )
        m_pShadow = pTemp;
      }
   }
-  
+
   refresh ( );
 
   connect ( m_pButtonOkay,         SIGNAL ( clicked ( ) ), this, SLOT ( accept ( ) ) );
@@ -204,6 +205,7 @@ void DialogShadow::initMe ( MenuObject *pMenuObject, QPixmap *pBackground )
   connect ( m_pSliderCutOffRadius, SIGNAL ( valueChanged ( int ) ), this, SLOT ( slotCutOffRadius ( int ) ) );
   connect ( m_pSliderCutOff,       SIGNAL ( sliderReleased ( ) ),   this, SLOT ( slotCutOff       ( ) ) );
   connect ( m_pSliderCutOffRadius, SIGNAL ( sliderReleased ( ) ),   this, SLOT ( slotCutOffRadius ( ) ) );
+  connect ( m_pEditDistance,       SIGNAL ( textChanged ( const QString & ) ), this, SLOT ( slotDistance ( const QString & ) ) );
 
   QTimer::singleShot ( 0, this, SLOT (slotCenterScrollView ( ) ) );
 }
@@ -236,7 +238,7 @@ void DialogShadow::reject ( )
   if ( m_pOrigShadow )
     m_pMenuObject->setShadow ( m_pOrigShadow );
   m_pOrigShadow = NULL;
-  
+
   QDialog::reject ( );
 }
 
@@ -369,13 +371,22 @@ void DialogShadow::slotTransparency ( )
     refresh ( );
 }
 
+void DialogShadow::slotDistance ( const QString &qsDistance )
+{
+  bool bOkay = false;
+  int iDistance = qsDistance.toInt ( &bOkay );
+  if ( bOkay )
+    m_pSliderDistance->setValue ( iDistance );
+}
+
 // called from m_pSliderDistance
 void DialogShadow::slotDistance ( int iDistance ) // [ 0 .. 100 ]
 {
   QString qsText;
   int iDist = iDistance;
-  if ( ( iDistance < 3 ) && ( iDistance > -3 ) )
-    iDist = 0;
+//  if ( ( iDistance < 3 ) && ( iDistance > -3 ) )
+//    iDist = 0;
+
   qsText.sprintf      ( "%d", iDist );
   m_pEditDistance->setText ( qsText );
 
