@@ -1,7 +1,11 @@
 /****************************************************************************
 ** DVDMenuUndoObject - code
-** Created: Thursday Jan 2'nd 2003
-** Varol Okan
+**
+**   Created : Thursday Jan 2'nd 2003
+**        by : Varol Okan
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ****************************************************************************/
 
 #include <qpixmap.h>
@@ -68,6 +72,16 @@ void DVDMenuUndoObject::initMe ()
 	m_bDeleteObject     = false;
 }
 
+DVDMenuUndoObject::BackgroundInfo::BackgroundInfo ( )
+{
+	bModified = false;
+	bMovieBackgroundHasSound = false;
+	iFormat = 0;
+	iHeight = 0;
+	iWidth  = 0;
+	iStretchType = -1;
+}
+
 QString
 DVDMenuUndoObject::getTypeString ()
 {
