@@ -1149,10 +1149,14 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::pgc_struct *pPgc, DVDMenu *pMenu )
     pVob->pause = QString ( "0" );
   }
 
-  if (pMenu->isMovieMenu ())
-    pVob->pause = QString ("0");
+  if ( pInterface->qsPause.isEmpty ( ) )  {
+    if (pMenu->isMovieMenu ())
+      pVob->pause = QString ("0");
+    else
+      pVob->pause = QString ("inf");
+  }
   else
-    pVob->pause = QString ("inf");
+    pVob->pause = QString (  "%1" ).arg ( pInterface ->qsPause );
 
   for ( t=0;t<listButtonsFromMenu.count();t++) {
     pButton = listButtonsFromMenu [ t ];
