@@ -30,16 +30,18 @@ FilePreviewDialog::FilePreviewDialog ( void *pExistingEngine, QWidget *pParent )
   m_pMediaInterface = MediaCreator::createPreferredWidget (this, "MediaWidget", pExistingEngine);
   QGridLayout *m_pVideoLayout = new QGridLayout (this, 1, 1, 4, 6, "MediaMainLayout");
   m_pVideoLayout->addWidget (m_pMediaInterface->getWidget(), 0, 0);
-  
+
   m_pMediaInterface->initMediaEngine();
-  setMinimumWidth( 120 );
+  setMinimumWidth ( 120 );
   m_bSetupPreview = false;
 }
 
 FilePreviewDialog::~FilePreviewDialog()
 {
-  m_pMediaInterface->stop ( );
-  delete m_pMediaInterface;
+  if ( m_pMediaInterface )  {
+    m_pMediaInterface->stop ( );
+    delete m_pMediaInterface;
+  }
 }
 
 void FilePreviewDialog::previewUrl ( const QUrl &theUrl )
