@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **  pure virtual class as base for the three button types.
 **
@@ -31,39 +33,39 @@ public:
 
 	virtual bool readProjectFile       ( QDomNode      & );
 	virtual bool writeProjectFile      ( QDomElement   & );
-	virtual void createStructure       ( QListViewItem * );
 	virtual bool createContextMenu     ( QPoint );
-	virtual MenuObject *clone          ( );
-	virtual void replaceColor          ( QColor, QColor );
+	virtual StructureItem *createStructure ( StructureItem * );
+	virtual MenuObject    *clone       ( QWidget *p1=NULL, MenuObject *p2=NULL );
+	virtual void replaceColor          ( Rgba, Rgba );
 
 public:
 	// Further public functions not dervied from the base class.
-	void setFrameWidth                 (int);
-	void setFrameStyle                 (int);
-	void setFrameJoin                  (int);
-	void setFrameColor                 (QColor);
+	void setFrameWidth                 ( int  );
+	void setFrameStyle                 ( int  );
+	void setFrameJoin                  ( int  );
+	void setFrameColor                 ( Rgba );
 
-	int    width                       ();
-	QColor color                       ();
-	int    join                        ();
-	int    style                       ();
+	int  width                         ( );
+	Rgba color                         ( );
+	int  join                          ( );
+	int  style                         ( );
 
 protected slots:
-	virtual void slotEdit              ();
-	virtual void slotMatrix            ();
-	virtual void slotAddText           ();
-	virtual void slotAddImage          ();
-	virtual void slotAddMovie          ();
-	virtual void slotDefineAsButton    ();
+	virtual void slotEdit              ( );
+	virtual void slotMatrix            ( );
+	virtual void slotAddText           ( );
+	virtual void slotAddImage          ( );
+	virtual void slotAddMovie          ( );
+	virtual void slotDefineAsButton    ( );
 
 protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString);
 
 private:
-	QColor  m_colorFrame;
-	int     m_iFrameWidth;
-	int     m_iFrameStyle;
-	int     m_iFrameJoin;
+	Rgba m_colorFrame;
+	int  m_iFrameWidth;
+	int  m_iFrameStyle;
+	int  m_iFrameJoin;
 };
 
 #endif	// FRAMEOBJECT_H
