@@ -117,7 +117,7 @@ void MaskObject::createMask ( )
     ImageObject *pImageObject = (ImageObject *)m_pMenuObject;
 
     // Now that we have the object to draw we should create the QImage - object ...
-    theImage = pImageObject->image ( );
+    theImage = pImageObject->image ( ).copy ( );  // Copy is required otherwise the orig image is changed.
     theImage.setAlphaBuffer ( true );
     //    http://bullwinkle.toonzone.net/rbplan.wav
     // Lastly we should filter out color keys if present (MovieObject, and Imagebject only)
@@ -158,7 +158,7 @@ bool MaskObject::filterColorKeys ( QImage &theShadow )
   QValueList<QColor *>listColorKeyMax;
   QColor *pColorMin, *pColorMax, theColor, targetColor;
   QRgb thePixel, *pLine, *pShadowLine;
-  
+
   int t, iX, iY, iDelta, iRed, iGreen, iBlue, iColorKeyCount;
   iColorKeyCount = pManipulator->listColorKeys.count();
   for (t=0;t<iColorKeyCount;t++)	{
@@ -170,7 +170,7 @@ bool MaskObject::filterColorKeys ( QImage &theShadow )
     iRed = theColor.red() + iDelta; iGreen = theColor.green() + iDelta; iBlue = theColor.blue() + iDelta;
     iRed = (iRed > 255) ? 255 : iRed; iGreen = (iGreen > 255) ? 255 : iGreen; iBlue = (iBlue > 255) ? 255 : iBlue;
     pColorMax = new QColor (iRed, iGreen, iBlue);
-    
+
     listColorKeyMin.append (pColorMin);
     listColorKeyMax.append (pColorMax);
   }
