@@ -1002,7 +1002,8 @@ MenuObject *MenuPreview::insertDraggedSourceInfo(QDropEvent *pDropEvent, QImage
 	m_listMenuObjects.append(pButtonObject);
 
 	// And finally we connect everything ...
-	connectStdSlots ( pButtonObject, false );
+	connectStdSlots ( pButtonObject, true ); // If false, then Dragged SourceFileInfoButtons can not be edited 
+	                                         // Is this the bug with double edit dialogs ?
 	// disconnect ( pMenuObject );
 	// After all of this we also want to create a text object ...
 	QString qsWhatDidWeDragg = fileInfo.baseName();
@@ -1413,14 +1414,14 @@ MenuObject *MenuPreview::createImageObject(bool bShowDialog)
 
 	if (bShowDialog)	{
 	  // The first step is to get the image name
-	  QString qsImageFilter      = "*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP";
+	  QString qsImageFilter = Global::pApp->getImageFilter ( ); //"*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP";
 
 	  //	  QString qsImageName = QFileDialog::getOpenFileName(Global::qsCurrentPath, tr("Image Files (*.jpg *.jpeg *.png *.xbm *.bmp *.JPG *.JPEG *.PNG *.XBM *.BMP)"), this,
 	  QString qsImageName = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, QString ("Images ( ") + qsImageFilter + QString (" );;All ( * )"), this, 
 	      tr("Select image"), tr("Select a image object."));
 	  if (qsImageName.isNull())
 	    return NULL;
-	  
+
 	  QFileInfo fileInfo  (qsImageName);
 	  Global::qsCurrentPath = fileInfo.filePath();
 
@@ -2021,7 +2022,7 @@ void MenuPreview::connectStdSlots (MenuObject *pObject, bool bAddExtraSlots )
     if ( pObject->objectType ( ) == tempButton.objectType ( ) ) {
       ButtonObject *pButton = (ButtonObject *)pObject;
       for ( i=0; i < pButton->getNormalCount ( ) ; i++ )
-	connectStdSlots ( pButton->getNormal ( (int)i ), true );
+	connectStdSlots ( pButton->getNormal ( (int)i ), false );
       for ( i=0; i<pButton->getSelectedCount ( ) ; i++ )
 	connect (  pButton->getSelected     ( i ), SIGNAL ( signalDeleteMe (MenuObject *) ), this, SLOT(slotDeleteObject (MenuObject *) ) );
       for ( i=0; i<pButton->getHighlightedCount ( ) ; i++ )
