@@ -38,52 +38,7 @@
 #include "filepreviewdialog.h"
 
 #include "sourcefileentry.h"
-#include "qslideshow/xml_slideshow.h"
-
-
-// TODO
-// - Implement feature if plugin has no controls, skip third page
-// - Grey out DialogImages for now and focus on the next release
-//   DialogImages can be part of 1.3
-//
-// - complexdvd - plugin :
-//   - Implement Widget to [x] get random background images
-//   - Implement check  to [x] set length of DVDMenu to audio track length
-//   - MaxNumberOfButtons per DVDMenu
-//   - Randim images from interfacelift.com
-//   - AssignMenuAudio
-//
-// - DialogImages:
-//   - Change IconView - context menu for items
-//     - Edit ...
-//     - to Slideshow ...
-//     - to Virtual Folger ...
-//     - Remove
-//     - Separator
-//     - StarRatings
-//
-//   - Virtual Folder to display image chache instead of Video cache
-//   - Slideshows
-//     - Implement [Edit] button
-//     - Change conext menu
-//       - Edit ...
-//       - to Slideshow ...
-//       - to Virtual Folger ...
-//       - to Preview -=>
-//       - all to Preview -=>
-//       - Separator
-//       - Add ...
-//       - Remove
-//       - Clear All
-//
-//     Slideshow: Edit  (Button to def slideshow parms)
-//      - list of audio files
-//      - background ( color or image )
-//      - Type : NTSC or PAL
-//     Slideshow: Edit ... (context menu for single image)
-//      - Add coment ( Subtitle )
-//      - Set duration
-//      - rect / pos / rotate
+#include "xml_slideshow.h"
 
 namespace Input
 {
@@ -112,11 +67,11 @@ OneClickWizard::OneClickWizard ( QWidget *pParent, const char *pName, bool bModa
   m_pCheckAddECC   ->hide ( );
   m_pCheckBurnDVD  ->hide ( );
   m_pEditDevice    ->hide ( );
-  m_pButtonAddImages->setEnabled ( FALSE );
+//  m_pButtonAddImages->setEnabled ( FALSE );
 
   // Can not create QTolbox without any item, so we have to remove the first item in the constructor.
   m_pToolBoxGroups->removeItem ( m_pToolBoxGroups->item ( 0 ) );
-  GroupView *pGroupView = new GroupView ( m_pToolBoxGroups, NULL ); // or this 
+  GroupView *pGroupView = new GroupView ( m_pToolBoxGroups, (SourceFileEntry *)NULL ); // or this 
   m_pToolBoxGroups->addItem ( pGroupView, QString ( "Groups" ) );
 
   m_pFrameSlideshow->hide ( );
@@ -130,8 +85,8 @@ OneClickWizard::OneClickWizard ( QWidget *pParent, const char *pName, bool bModa
   connect ( m_pButtonRename,      SIGNAL ( clicked ( ) ), this, SLOT ( slotGroupRename   ( ) ) );
   connect ( m_pButtonAddVideos,   SIGNAL ( clicked ( ) ), this, SLOT ( slotAddVideos     ( ) ) );
   connect ( m_pButtonAddImages,   SIGNAL ( clicked ( ) ), this, SLOT ( slotAddImages     ( ) ) );
-  connect ( m_pToolBoxGroups,     SIGNAL ( currentChanged ( int ) ), this, SLOT ( slotCurrentGroup ( int ) ) );
-  connect ( m_pComboPlugins,      SIGNAL ( activated ( int ) ), this, SLOT ( slotChangePlugin ( int ) ) );
+  connect ( m_pToolBoxGroups,     SIGNAL ( currentChanged( int ) ), this, SLOT ( slotCurrentGroup ( int ) ) );
+  connect ( m_pComboPlugins,      SIGNAL ( activated    (  int ) ), this, SLOT ( slotChangePlugin ( int ) ) );
   connect ( m_pCheckCreateISO,    SIGNAL ( toggled      ( bool ) ), this, SLOT ( slotCreateISO ( bool ) ) );
   connect ( m_pCheckBurnDVD,      SIGNAL ( toggled      ( bool ) ), this, SLOT ( slotBurnDVD   ( bool ) ) );
   connect ( pGroupView,           SIGNAL ( contextMenuRequested( QListViewItem *, const QPoint &, int ) ),
@@ -359,6 +314,11 @@ void OneClickWizard::checkControls ( )
   m_pButtonDelete->setEnabled ( bShow );
   m_pButtonRename->setEnabled ( bShow );
 
+  if ( iSlideshows > 1 )
+    m_pFrameSlideshow->show ( );
+  else
+    m_pFrameSlideshow->hide ( );
+
   QWidget *pConfigPage = QWizard::page ( 1 );
   QWidget *pPluginPage = QWizard::page ( 2 );
 
@@ -374,7 +334,7 @@ void OneClickWizard::checkControls ( )
     setNextEnabled   ( pConfigPage, FALSE );
   }
   if ( m_pToolBoxGroups->count ( ) == 0 )  {
-    GroupView *pGroupView = new GroupView ( m_pToolBoxGroups, NULL );
+    GroupView *pGroupView = new GroupView ( m_pToolBoxGroups, (SourceFileEntry *)NULL );
     m_pToolBoxGroups->addItem ( pGroupView, uniqueGroupName ( QString ( "Groups" ) ) );
   }
 }
@@ -525,7 +485,8 @@ void OneClickWizard::slotGroupRename ( )
 void OneClickWizard::slotAddVideos ( )
 {
   DialogFiles fileDialog ( this );
-  if ( fileDialog.exec  ( ) == QDialog::Rejected )
+  fileDialog.initMe      ( );
+  if ( fileDialog.exec   ( ) == QDialog::Rejected )
     return;
 
   // Basic test to remove empty Groups ...
@@ -553,7 +514,7 @@ void OneClickWizard::slotAddVideos ( )
 
 GroupView *OneClickWizard::addGroup ( SourceFileEntry *pEntry )
 {
-  int      t;
+  int       t;
   bool      bAlternate = true;
   QFileInfo fileInfo;
   QPixmap   thePixmap, errorPixmap;
@@ -595,6 +556,55 @@ GroupView *OneClickWizard::addGroup ( SourceFileEntry *pEntry )
   return pGroupView;
 }
 
+GroupView *OneClickWizard::addGroup ( CXmlSlideshow *pSlideshow )
+{
+  if ( ! pSlideshow )
+    return NULL;
+
+  int       t;
+  bool      bAlternate = true;
+  QFileInfo fileInfo;
+  QPixmap   thePixmap, errorPixmap;
+  Cache::Thumbs::Entry      *pCache  = NULL;
+  CXmlSlideshow::img_struct *pXmlImg = NULL;
+  GroupView::Item *pItem      = NULL;
+  GroupView       *pGroupView = new GroupView ( m_pToolBoxGroups, NULL, NULL, pSlideshow );
+  QImage theImage ( QImage ( ).fromMimeSource ( "error.jpg" ) );
+
+  theImage = theImage.smoothScale ( GroupView::m_iSize, GroupView::m_iSize );
+  errorPixmap.convertFromImage    ( theImage );
+
+  uint iCount = pSlideshow->countImg ( );
+  for ( t=(int)iCount-1; t>=0; t-- ) {
+    pXmlImg = pSlideshow->getImg ( t );
+    if ( ! pXmlImg ) // || t > 100 ) // Only the first 100 images for performance issues
+      continue;
+    pCache = Global::pThumbsCache->find ( pXmlImg->src, true );
+    fileInfo.setFile ( pXmlImg->src );
+    bAlternate = ! bAlternate;
+    pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), bAlternate );
+    if ( pCache )  {
+      pItem->pCache = pCache;
+      if ( ! pCache->arrayOfThumbs )
+             pCache->loadImages  ( );
+      if ( pCache->arrayOfThumbs && pCache->arrayOfThumbs[0] ) {
+        theImage = pCache->arrayOfThumbs[0]->smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
+        thePixmap.convertFromImage ( theImage );
+        pItem->setPixmap ( 0, thePixmap );
+      }
+      else
+        pItem->setPixmap ( 0, errorPixmap );
+    }
+    else
+      pItem->setPixmap ( 0, errorPixmap );
+  }
+  connect  ( pGroupView, SIGNAL ( contextMenuRequested ( QListViewItem *, const QPoint &, int ) ), this, SLOT ( slotGroupContextMenu ( QListViewItem *, const QPoint &, int ) ) );
+
+  // And finally we can add the listBox to the ToolBox
+  m_pToolBoxGroups->addItem ( pGroupView, uniqueGroupName ( pSlideshow->slideshow_name ) );
+  return pGroupView;
+}
+
 void OneClickWizard::slotGroupContextMenu ( QListViewItem *pSelItem, const QPoint &pos, int )
 {
   QPopupMenu *pMenu   = new QPopupMenu  ( this );
@@ -657,8 +667,6 @@ void OneClickWizard::toSourceGroup ( )
 
 void OneClickWizard::slotSourceToSourceGroup ( QListBoxItem *pSelItem )
 {
-  //  Thumbs       *pThumbs;
-  //  QValueList<Thumbs *>::iterator it;
   bool      bSelected  = true;
   int       t, i;
   QFileInfo fileInfo;
@@ -721,7 +729,7 @@ void OneClickWizard::play ( QString qsFileName )
   qsCommand = Global::qsExternalPlayer + " " + qsFileName + " &";
 
   int iRet = system ( qsCommand.ascii ( ) );
-  iRet++;
+  iRet++; // avoid compiler to complain.
 }
 
 void OneClickWizard::addSourceToGroup ( GroupView *pGroupView )
@@ -769,6 +777,7 @@ void OneClickWizard::addSourceToGroup ( GroupView *pGroupView )
 void OneClickWizard::slotAddImages ( )
 {
   DialogImages fileDialog ( this );
+  fileDialog.initMe     ( );
   if ( fileDialog.exec  ( ) == QDialog::Rejected )
     return;
 
@@ -781,21 +790,22 @@ void OneClickWizard::slotAddImages ( )
     }
   }
 
+  CXmlSlideshow *pSlideshow;
   QValueList<CXmlSlideshow *>newList = fileDialog.getSlideshows ( );
   // If we have something selected, then we should display the MaxNrOfButtons per menu
-  QValueList<CXmlSlideshow *>::iterator it = newList.begin  ( );
-  Group *pGroup = NULL;
-  QListView *pGroupView = NULL;
 
-  while ( it != newList.end ( ) )  {
-    pGroup = new Group;
-    pGroup->pSlideshow = *it++;
+  if ( newList.count ( ) > 0 )  {
+    QValueList<CXmlSlideshow *>::iterator it = newList.begin  ( );
+    Group *pGroup = NULL;
 
-    pGroupView = new QListView ( this );
-/*
-Add the thumbnails per source ideo in the SourceFileEntry.
-*/
-    m_pToolBoxGroups->addItem  ( pGroupView, uniqueGroupName ( pGroup->pSlideshow->slideshow_name ) );
+    while (  it != newList.end ( ) )  {
+      pGroup     = new Group;
+      pSlideshow = new CXmlSlideshow;
+     *pSlideshow = *(*it++);
+      pGroup->pSlideshow = pSlideshow;
+      addGroup  ( pGroup->pSlideshow );
+      m_listOfGroups.append ( pGroup );
+    }
   }
 
   checkControls ( );
@@ -836,6 +846,12 @@ void OneClickWizard::accept ( )
 
   Global::qsProjectPath = m_pLabelDVDPath->text ( );
 
+  Utils theUtils;
+//  theUtils.recMkdir ( m_pLabelTempPath->text ( ) );
+//  theUtils.recMkdir ( m_pLabelDVDPath ->text ( ) );
+  theUtils.recMkdir ( Global::qsTempPath    );
+  theUtils.recMkdir ( Global::qsProjectPath );
+
   groupsToPlugin ( );
 
   // Once we are at this point we can delete the stored objects ...
@@ -865,7 +881,7 @@ void OneClickWizard::groupsToPlugin ( )
     if ( m_pPlugin )
          m_pPlugin->addGroup ( pGroup );
   }
-  // Here we'll create the DVD. The plugin will directly cll back QDVDAuthor
+  // Here we'll create the DVD. The plugin will directly call back QDVDAuthor
   if ( m_pPlugin )  {
        m_pPlugin->setTempPath    ( Global::qsTempPath    );
        m_pPlugin->setProjectName ( Global::qsProjectName );
@@ -880,17 +896,17 @@ void OneClickWizard::sourceFileToPlugin ( Plugin::SourceGroup *pGroup, SourceFil
 
   QValueList<SourceFileInfo *>::iterator itInfo;
   Utils theUtils;
-  SourceFileInfo  *pInfo    = NULL;
-  QImage          *pPreview = NULL;
+  SourceFileInfo *pInfo      = NULL;
+  QImage         *pPreview   = NULL;
 
-  pGroup->qsGroupName         = pEntry->qsDisplayName;
-  pGroup->bSlideshow          = false;
-  pGroup->bCreateChapterMenu  = false;
+  pGroup->qsGroupName        = pEntry->qsDisplayName;
+  pGroup->bSlideshow         = false;
+  pGroup->bCreateChapterMenu = false;
 
   // The following is currently not used ...
-  pGroup->dateStart           = QDateTime ( date, time );
+  pGroup->dateStart          = QDateTime ( date, time );
   date = date.addDays ( 10 );
-  pGroup->dateEnd             = QDateTime ( date, time );
+  pGroup->dateEnd            = QDateTime ( date, time );
   ////////////////////////////////////////////////////////
   itInfo = pEntry->listFileInfos.begin ( );
   while ( itInfo != pEntry->listFileInfos.end ( ) )  {
@@ -914,7 +930,6 @@ void OneClickWizard::sourceFileToPlugin ( Plugin::SourceGroup *pGroup, SourceFil
     pSourceEntry->qsFileName = pInfo->qsFileName;
     pSourceEntry->iLength    = theUtils.getMsFromString ( pInfo->qsLength );
     pGroup->listFiles.append ( pSourceEntry );
-//printf ( "%s\n", pEntry->qsFileName.ascii ( ) );
   }
   // In case no screenshot could be found ... Sorry we have an issue here
   if ( pGroup->qsScreenshot.isEmpty ( ) )  {
@@ -927,9 +942,47 @@ void OneClickWizard::sourceFileToPlugin ( Plugin::SourceGroup *pGroup, SourceFil
 
 void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlideshow *pSlideshow )
 {
-  // Prevent compiler complaining.
-  pGroup     = pGroup;
-  pSlideshow = pSlideshow;
+  QDate date ( 2008,  1,  8 );
+  QTime time (   12, 22, 44 );
+
+  unsigned int     t, iCount;
+  CXmlSlideshow::img_struct *pXmlImg = NULL;
+
+  pGroup->qsGroupName         = pSlideshow->slideshow_name;
+  pGroup->bSlideshow          = true;
+  pGroup->bCreateChapterMenu  = false;
+  pGroup->iFilterLength       = (int)( pSlideshow->filter_delay * 1000.0f );
+  pGroup->qsBackground        = pSlideshow->background;
+  pGroup->listAudio           = pSlideshow->audio_list;
+
+  // The following is currently not used ...
+  pGroup->dateStart           = QDateTime ( date, time );
+  date = date.addDays ( 10 );
+  pGroup->dateEnd             = QDateTime ( date, time );
+  ////////////////////////////////////////////////////////
+  iCount = pSlideshow->countImg ( );
+  for ( t=0; t<iCount; t++ )  {
+    pXmlImg = pSlideshow->getImg ( t );
+    // Make sure the Group has a sceenshot associated with
+    if ( pGroup->qsScreenshot.isEmpty ( ) )
+         pGroup->qsScreenshot = pXmlImg->src;
+
+    Plugin::SourceGroup::SourceEntry *pSourceEntry = new Plugin::SourceGroup::SourceEntry;
+    pSourceEntry->qsFileName = pXmlImg->src;
+    if ( pXmlImg->fDuration > 0.0f )
+      pSourceEntry->iLength  = (unsigned long)( pXmlImg->fDuration * 1000.0 ); // in MSec
+    else
+      pSourceEntry->iLength  = (unsigned long)( pSlideshow->delay  * 1000.0 ); // in MSec
+    pGroup->listFiles.append ( pSourceEntry );
+  }
+  // In case no screenshot could be found ... Sorry we have an issue here
+  if ( pGroup->qsScreenshot.isEmpty ( ) )  {
+    Utils theUtils;
+    QImage theImage ( QImage ( ).fromMimeSource ( "error.jpg" ) );
+    QString qsScreenshot = theUtils.getUniqueTempFile ( "error_group.png" );
+    theImage.save ( qsScreenshot, "PNG", 100 );
+    pGroup->qsScreenshot = qsScreenshot;
+  }
 }
 
 /*
