@@ -4,12 +4,16 @@
 #include <stdlib.h>
 
 #include <qprogressdialog.h>
+#include <qradiobutton.h>
 #include <qapplication.h>
 #include <qpushbutton.h>
 #include <qcheckbox.h>
+#include <qgroupbox.h>
 #include <qfileinfo.h>
+#include <qcombobox.h>
 #include <qlayout.h>
 #include <qcursor.h>
+#include <qtimer.h>
 
 #include "uisimpledvd.h"
 #include "simpledvd.h"
@@ -22,8 +26,10 @@ extern "C" void destroyPlugin ( Plugin::Interface *pDeleteMe ) {
     delete pDeleteMe;
 }
 
-#ifndef PREFIX
-#define PREFIX "/usr"
+#include "../../CONFIG.h"
+
+#ifndef PREFIX_DIRECTORY
+#define PREFIX_DIRECTORY "/usr"
 #endif
 
 namespace Plugin
@@ -31,9 +37,11 @@ namespace Plugin
 
 ComplexDVD::ComplexDVD ( )
 {
+  srand ( (unsigned)time ( NULL ) );
   m_iNrOfMenus    = 0;
   m_pConfigWidget = NULL;
   m_qsPluginName  = "ComplexDVD" + QString ( " -%1-" ).arg ( getPluginVersion ( ), 0, 'f', 2 );
+  QTimer::singleShot ( 10, this, SLOT ( slotInitTimer ( ) ) );
 }
 
 ComplexDVD::~ComplexDVD ( )
@@ -50,11 +58,77 @@ QWidget *ComplexDVD::getConfigWidget ( QWidget *pParent )
   return m_pConfigWidget;
 }
 
+void ComplexDVD::slotInitTimer ( )
+{
+  QStringList list;
+  list.append ( "Random"      );// 11009
+  list.append ( "Nature"      );//  2497
+  list.append ( "3D-graphics" );//   787
+  list.append ( "Animals"     );//   567
+  list.append ( "Anime"       );//  1573
+  list.append ( "Art"         );//    84
+  list.append ( "Cars"        );//   708
+  list.append ( "cartoons"    );//   450
+  list.append ( "Computer"    );//   777
+  list.append ( "Fantasy"     );//   169
+  list.append ( "Flowers"     );//   370
+  list.append ( "Games"       );//   420
+  list.append ( "Girls"       );//  1463
+  list.append ( "Holiday"     );//    23
+  list.append ( "Military"    );//    13
+  list.append ( "Movies"      );//   483
+  list.append ( "Music"       );//    52
+  list.append ( "Space"       );//   573
+
+  m_listNumberOfImages.append ( 11009 );
+  m_listNumberOfImages.append (  2497 );
+  m_listNumberOfImages.append (   787 );
+  m_listNumberOfImages.append (   567 );
+  m_listNumberOfImages.append (  1573 );
+  m_listNumberOfImages.append (    84 );
+  m_listNumberOfImages.append (   708 );
+  m_listNumberOfImages.append (   450 );
+  m_listNumberOfImages.append (   777 );
+  m_listNumberOfImages.append (   169 );
+  m_listNumberOfImages.append (   370 );
+  m_listNumberOfImages.append (   420 );
+  m_listNumberOfImages.append (  1463 );
+  m_listNumberOfImages.append (    23 );
+  m_listNumberOfImages.append (    13 );
+  m_listNumberOfImages.append (   483 );
+  m_listNumberOfImages.append (    52 );
+  m_listNumberOfImages.append (   573 );
+
+  if ( m_pConfigWidget )
+       m_pConfigWidget->m_pComboType->insertStringList ( list );
+
+  connect ( m_pConfigWidget->m_pCheckRandomImages, SIGNAL ( toggled ( bool ) ), this, SLOT ( slotRandomImages ( bool ) ) );
+  connect ( m_pConfigWidget->m_pRadioWPA,          SIGNAL ( toggled ( bool ) ), this, SLOT ( slotWPArchive    ( bool ) ) );
+  connect ( m_pConfigWidget->m_pRadioHDRCreme,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotHDRCreme     ( bool ) ) );
+}
+
+void ComplexDVD::slotRandomImages ( bool bOn )
+{
+  m_pConfigWidget->m_pGroupRandom->setEnabled ( bOn );
+}
+
+void ComplexDVD::slotWPArchive ( bool bOn )
+{
+  m_pConfigWidget->m_pComboType->setEnabled     (   bOn );
+  m_pConfigWidget->m_pRadioHDRCreme->setChecked ( ! bOn );
+}
+
+void ComplexDVD::slotHDRCreme ( bool bOn )
+{
+  m_pConfigWidget->m_pComboType->setEnabled ( ! bOn );
+  m_pConfigWidget->m_pRadioWPA->setChecked  ( ! bOn );
+}
+
 void ComplexDVD::getRandomBackground ( )
 {
   // gets random images off of InterFaceLift.com and stores them in /tmp
   int iOffset = 1;
-  QString qsCommand, qsTempPath;
+  QString qsCommand, qsTempPath, qsTarget;
   qsTempPath = m_qsTempPath + "/" + m_qsProjectName;
 
   QDialog   progressDialog    ( NULL );
@@ -69,38 +143,65 @@ void ComplexDVD::getRandomBackground ( )
 
   if ( m_pConfigWidget && m_pConfigWidget->m_pCheckMainMenu && 
        m_pConfigWidget->m_pCheckMainMenu->isChecked ( ) )
-    iOffset ++;
+       iOffset ++;
 
-  qsCommand = QString ( "rm %1/menu_*.jpg 2>&1 >/dev/null" ).arg ( qsTempPath );
-  system ( qsCommand.ascii ( ) );
+  qsCommand = QString ( "if [ -e %1/menu_1.jpg ]; then rm %2/menu_*.jpg >/dev/null 2>&1; fi" ).arg ( qsTempPath ).arg ( qsTempPath );
+  int iRet  = system ( qsCommand.ascii ( ) );
 
   for ( int t=0; t<m_iNrOfMenus; t++ )  {
-    qsCommand=QString ( "POTD=`wget -qO - 'interfacelift.com/wallpaper/index.php?sort=random&aspect=&widescreen&w=1280&h=800' | grep \"download</a>\" | sed -e \"s,.*href=\\\",,\" -e \"s,\\\",,\" | awk 'NR==\"3\" {print}' | awk '{ gsub(/dl\\/wallpaper\\//,\"\");gsub(/>download<\\/a>/,\"\");print}'`; wget -q -O \"%1/menu_%2.jpg\"  interfacelift.com/wallpaper/downloads$POTD" ).arg ( qsTempPath ).arg ( t + iOffset );
+    qsTarget  = QString   ( "\"%1/menu_%2.jpg\"" ).arg ( qsTempPath ).arg ( t + iOffset );
+    qsCommand = getImgCmd ( qsTarget );
+
     progressDialog.show     ( ); // why does this dlg disappear ? 
     progressDialog.raise    ( );
     progressBar.setProgress ( t + iOffset );
     qApp->processEvents     ( 10 );
 
-//printf ( "%s\n", qsCommand.ascii ( ) );
-    system ( qsCommand.ascii ( ) );
+    iRet = system ( qsCommand.ascii ( ) );
   }
 }
 
+QString ComplexDVD::getImgCmd ( QString &qsTarget )
+{
+
+//    qsCommand=QString ( "POTD=`wget -qO - 'interfacelift.com/wallpaper/index.php?sort=random&aspect=&widescreen&w=1280&h=800' | grep \"download</a>\" | sed -e \"s,.*href=\\\",,\" -e \"s,\\\",,\" | awk 'NR==\"3\" {print}' | awk '{ gsub(/dl\\/wallpaper\\//,\"\");gsub(/>download<\\/a>/,\"\");print}'`; wget -q -O \"%1/menu_%2.jpg\"  interfacelift.com/wallpaper/downloads$POTD" ).arg ( qsTempPath ).arg ( t + iOffset );
+  int iIdx, iRandom;
+  QString  qsRandom, qsCommand;
+
+  if ( m_pConfigWidget->m_pRadioWPA->isChecked ( ) )  {
+    // Get images from WallpapersArchive.com
+    iIdx = m_pConfigWidget->m_pComboType->currentItem ( );
+    if ( iIdx == 0 ) // random :
+         iIdx = ( rand ( ) % ( m_pConfigWidget->m_pComboType->count ( ) - 1 ) ) + 1;
+    iRandom   = ( rand ( ) % m_listNumberOfImages[iIdx] );
+    qsRandom  = m_pConfigWidget->m_pComboType->text ( iIdx );
+
+    qsCommand=QString ( "PICURL=`wget -qO - 'wallpapersarchive.com/%1/wallpaper%2/' | grep \"img src=\\\"http://www.wallpapersarchive.com/wallpapers/\" | sed -e \"s/.*src=\\\"//g\" -e \"s/\\\".*//\"`; wget -q --user-agent=MSIE -O %3 $PICURL" ).arg ( qsRandom ).arg ( iRandom ).arg ( qsTarget );
+  }
+  else  {
+    // Get images from HDRCreme instead
+    iRandom   = ( rand ( ) % 2381 );
+    qsCommand=QString ( "PICURL=`wget -qO - 'hdrcreme.com/photo-gallery/%1/original/' | grep \"img src=\\\"../../../photo\" | sed -e \"s/.*src=\\\"..\\/..\\/..//g\" -e \"s/\\\".*//\"`; wget -q --user-agent=MSIE -O %2 hdrcreme.com$PICURL" ).arg ( iRandom ).arg ( qsTarget );
+  }
+
+//printf ( "%s\n", qsCommand.ascii () );
+  return qsCommand;
+}
+
 void ComplexDVD::createMainMenu ( )
 {
   // creates a MainMenu with only one Button to the next Menu.
   // This is for the user to fill in 
   SourceGroup::type theType = SourceGroup::NTSC; // pGroup->enType;
   QString qsMenuName = QString ( "Menu 1" ); // this will be converted to VMGM due to the 1
-  QString qsMenuXML, qsCommand, qsMenuBackground;
+  QString qsMenuXML, qsCommand, qsMenuBackground;//, qsRandom;
 
   qsMenuBackground = m_qsTempPath + "/" + m_qsProjectName + "/MainMenu.jpg";
-  qsCommand = QString ( "rm \"%1\"" ).arg ( qsMenuBackground );
-  system ( qsCommand.ascii ( ) );
+  qsCommand = QString ( "rm \"%1\" >/dev/null 2>&1" ).arg ( qsMenuBackground );
+  int iRet  = system ( qsCommand.ascii ( ) );
 
-  qsCommand=QString ( "POTD=`wget -qO - 'interfacelift.com/wallpaper/index.php?sort=random&aspect=&widescreen&w=1280&h=800' | grep \"download</a>\" | sed -e \"s,.*href=\\\",,\" -e \"s,\\\",,\" | awk 'NR==\"3\" {print}' | awk '{ gsub(/dl\\/wallpaper\\//,\"\");gsub(/>download<\\/a>/,\"\");print}'`; wget -q -O \"%1\"  interfacelift.com/wallpaper/downloads$POTD" ).arg ( qsMenuBackground );
-//printf ( "%s\n", qsCommand.ascii ( ) );
-  system ( qsCommand.ascii ( ) );
+  qsCommand = getImgCmd ( qsMenuBackground );
+  iRet = system ( qsCommand.ascii ( ) );
 
   qsMenuXML += "<MainVMGM MenuWidth=\"720\" TitlesetNr=\"0\" MenuHeight=\"480\" MenuFormat=\"1\" MenuRatio=\"4:3\" MenuNr=\"0\" >\n";
   qsMenuXML += "  <MenuVariables>\n";
@@ -108,7 +209,7 @@ void ComplexDVD::createMainMenu ( )
   qsMenuXML += "   <MenuDuration>00:00:01.000</MenuDuration>\n";
   qsMenuXML += "   <MenuBackground ResizeAlgo=\"Normal Qt\" OffsetX=\"0\" OffsetY=\"0\" StretchType=\"0\" >"+qsMenuBackground+"</MenuBackground>\n";
   qsMenuXML += "   <MenuName>Main Menu VMGM</MenuName>\n";
-  qsMenuXML += "   <MaskColors>#00fefffe,#fffa9632,#ffff1414,#ffffff14,</MaskColors>\n";
+  qsMenuXML += "   <MaskColors>#00fefffe,#a0ff1414,#a0fa9632,#ff0f0fff,</MaskColors>\n";
   qsMenuXML += "  </MenuVariables>\n";
   qsMenuXML += "  <PreviewVariables>\n";
   qsMenuXML += "   <ButtonObject Action=\"jump+-+Menu 2+-+\" PreAction=\"\" ButtonName=\"Button 1\" >\n";
@@ -118,12 +219,12 @@ void ComplexDVD::createMainMenu ( )
   qsMenuXML += "     </TextObject>\n";
   qsMenuXML += "    </NormalState>\n";
   qsMenuXML += "    <SelectedState>\n";
-  qsMenuXML += "     <TextObject StyleStrategy=\"256\" TextAlign=\"4,64\" ForegroundColor=\"#ffff1414\" Font=\"Courier,26,-1,5,75,0,0,0,0,0\" Text=\"First Menu\">\n";
+  qsMenuXML += "     <TextObject StyleStrategy=\"256\" TextAlign=\"4,64\" ForegroundColor=\"#a0ff1414\" Font=\"Courier,26,-1,5,75,0,0,0,0,0\" Text=\"First Menu\">\n";
   qsMenuXML += "      <MenuObject Width=\"231\" X=\"257\" Y=\"210\" Height=\"45\" ObjectName=\"First Menu\" />\n";
   qsMenuXML += "     </TextObject>\n";
   qsMenuXML += "    </SelectedState>\n";
   qsMenuXML += "    <HighlightedState>\n";
-  qsMenuXML += "     <TextObject StyleStrategy=\"256\" TextAlign=\"4,64\" ForegroundColor=\"#fffa9632\" Font=\"Courier,26,-1,5,75,0,0,0,0,0\" Text=\"First Menu\">\n";
+  qsMenuXML += "     <TextObject StyleStrategy=\"256\" TextAlign=\"4,64\" ForegroundColor=\"#a0fa9632\" Font=\"Courier,26,-1,5,75,0,0,0,0,0\" Text=\"First Menu\">\n";
   qsMenuXML += "      <MenuObject Width=\"231\" X=\"257\" Y=\"210\" Height=\"45\" ObjectName=\"First Menu\" />\n";
   qsMenuXML += "     </TextObject>\n";
   qsMenuXML += "    </HighlightedState>\n";
@@ -156,8 +257,8 @@ bool ComplexDVD::execute ( )
   m_iNrOfMenus  = (int)( ( m_listOfGroups.count ( ) + iButtonsPerMenu - 1 ) / iButtonsPerMenu );
 
   // Here we eval if we should snap some random images off of ImageFaceLift.com
-  if ( m_pConfigWidget && m_pConfigWidget->m_pCheckInterFaceLift && 
-       m_pConfigWidget->m_pCheckInterFaceLift->isChecked ( ) )
+  if ( m_pConfigWidget && m_pConfigWidget->m_pCheckRandomImages && 
+       m_pConfigWidget->m_pCheckRandomImages->isChecked ( ) )
     getRandomBackground ( );
   if ( m_pConfigWidget && m_pConfigWidget->m_pCheckMainMenu && 
        m_pConfigWidget->m_pCheckMainMenu->isChecked ( ) )  {
@@ -217,18 +318,18 @@ bool ComplexDVD::execute ( )
 QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber )
 {
   QFileInfo fileInfo;
-  QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName;
+  QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName, qsGroupName;
   QString qsHeight = "480";
   QString qsButtonName, qsFrameName, qsObjectName, qsJumpTo, qsX, qsY, qsTempPath;
-  int iCount = 0;
+  int iCount = 0, iSlideCount = 1;
   SourceGroup *pGroup = NULL;
   if ( list.count ( ) < 1 )
     return qsMenuXML;
 
   qsTempPath = m_qsTempPath + "/" + m_qsProjectName;
-  qsBackgroundFile = PREFIX"/share/qdvdauthor/plugins/simpledvd/background.jpg";
-  if ( m_pConfigWidget && m_pConfigWidget->m_pCheckInterFaceLift && 
-       m_pConfigWidget->m_pCheckInterFaceLift->isChecked ( ) )
+  qsBackgroundFile = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/background.jpg";
+  if ( m_pConfigWidget && m_pConfigWidget->m_pCheckRandomImages && 
+       m_pConfigWidget->m_pCheckRandomImages->isChecked ( ) )
     qsBackgroundFile = QString ( "%1/menu_%2.jpg" ).arg ( qsTempPath ).arg ( iMenuNumber );
 
   qsMenuName.sprintf ( "Menu %d", iMenuNumber );
@@ -242,7 +343,7 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
   qsMenuXML += "    <MenuDuration>00:00:01.000</MenuDuration>\n";
   qsMenuXML += "   <MenuBackground ResizeAlgo=\"Normal Qt\" OffsetX=\"0\" OffsetY=\"0\" StretchType=\"2\" >"+qsBackgroundFile+"</MenuBackground>\n";
   qsMenuXML += "   <MenuName>"+qsMenuName+"</MenuName>\n";
-  qsMenuXML += "   <MaskColors>#00fefffe,#fffa9632,#ffff1414,#ffffff14,</MaskColors>\n";
+  qsMenuXML += "   <MaskColors>#00fefffe,#a0ff1414,#a0fa9632,#ff0f0fff,</MaskColors>\n";
   qsMenuXML += "  </MenuVariables>\n";
   qsMenuXML += "  <PreviewVariables>\n";
 
@@ -268,15 +369,21 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
 
     if ( ! pGroup )
        continue;
-    qsFileName = "";
-    if ( pGroup->listFiles.size ( ) > 0 )  {
+
+    qsFileName  = "";
+    qsGroupName = pGroup->qsGroupName;
+    if ( pGroup->bSlideshow )  {
+      qsGroupName.sprintf ( "[%02d] - %s", iSlideCount++, (const char *)pGroup->qsGroupName.utf8 ( ) );
+      qsFileName  = pGroup->qsGroupName + ".vob+-+00:00:00.000";
+    }
+    else if ( pGroup->listFiles.size ( ) > 0 )  {
       fileInfo.setFile ( pGroup->listFiles[0]->qsFileName );
       qsFileName = fileInfo.fileName ( );
       if ( qsFileName.length ( ) > 0 )
         qsFileName += "+-+00:00:00.000";
     }
 //jump+-+[01] - cordes.mpg+-+001_capture001.mpeg+-+00:00:00.000
-    qsJumpTo = QString ( "jump+-+%1+-+%2" ).arg ( pGroup->qsGroupName ).arg ( qsFileName );
+    qsJumpTo = QString ( "jump+-+%1+-+%2" ).arg ( qsGroupName ).arg ( qsFileName );
     qsButtonName  = QString ( "Button %1" ).arg ( ++iCount );
     qsObjectName  = QString ( "Object_%1" ).arg (   iCount );
     qsFrameName   = QString ( "Frame %1"  ).arg (   iCount );
@@ -291,7 +398,7 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
     qsY = ( iCount > 3 ) ? "295" : "45";
 
     // Next we create the ButtonObject for the video jump+-+vmgm+-+
-    qsMenuXML += "   <ButtonObject Action=\""+qsJumpTo+"\" ButtonName=\""+qsButtonName+"\" >\n";
+    qsMenuXML += "   <ButtonObject Action=\""+qsJumpTo+"\" ButtonName=\""+qsButtonName+"\"  SourceEntry=\""+qsGroupName+"\" >\n";
     qsMenuXML += "    <NormalState>\n";
     qsMenuXML += "     <ImageObject FileName=\""+pGroup->qsScreenshot+"\" >\n";
     qsMenuXML += "      <Manipulator>\n";
@@ -302,12 +409,12 @@ QString ComplexDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumbe
     qsMenuXML += "    </NormalState>\n";
 
     qsMenuXML += "    <SelectedState>\n";
-    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#ffff1414\" >\n";
+    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#a0ff1414\" >\n";
     qsMenuXML += "      <MenuObject Width=\"150\" X=\""+qsX+"\" Y=\""+qsY+"\" Height=\"112\" ObjectName=\""+qsFrameName+"\" />\n";
     qsMenuXML += "     </FrameObject>\n";
     qsMenuXML += "    </SelectedState>\n";
     qsMenuXML += "    <HighlightedState>\n";
-    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#fffa9632\" >\n";
+    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#ff0f0fff\" >\n";
     qsMenuXML += "      <MenuObject Width=\"150\" X=\""+qsX+"\" Y=\""+qsY+"\" Height=\"112\" ObjectName=\""+qsFrameName+"\" />\n";
     qsMenuXML += "     </FrameObject>\n";
     qsMenuXML += "    </HighlightedState>\n";
@@ -329,9 +436,9 @@ QString ComplexDVD::getMenuButtons ( bool bPrev, bool bNext, int iMenuNumber )
 {
   QString qsMenuXML, qsMenuName;
   // The three buttons to the previous, next and Main menu ...
-  QString qsButtonPrev = PREFIX"/share/qdvdauthor/plugins/simpledvd/prev.png";
-  QString qsButtonMain = PREFIX"/share/qdvdauthor/plugins/simpledvd/main.png";
-  QString qsButtonNext = PREFIX"/share/qdvdauthor/plugins/simpledvd/next.png";
+  QString qsButtonPrev = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/prev.png";
+  QString qsButtonMain = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/main.png";
+  QString qsButtonNext = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/complexdvd/next.png";
   if ( bPrev )  {
     qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber - 1 );
     qsMenuXML += "   <ButtonObject Action=\"jump+-+"+qsMenuName+"+-+\" ButtonName=\"Button 7\" >\n";
