@@ -1,12 +1,10 @@
 
 // This is the implementation of the SimpleDVD plugin for QDVDAuthor.
 
-//#include <qprogressbar.h>
 #include <qprogressdialog.h>
 #include <qapplication.h>
 #include <qpushbutton.h>
 #include <qfileinfo.h>
-//#include <qdialog.h>
 
 #include "uisimpledvd.h"
 #include "simpledvd.h"
@@ -19,8 +17,10 @@ extern "C" void destroyPlugin ( Plugin::Interface *pDeleteMe ) {
     delete pDeleteMe;
 }
 
-#ifndef PREFIX
-#define PREFIX "/usr"
+#include "../../CONFIG.h"
+
+#ifndef PREFIX_DIRECTORY
+#define PREFIX_DIRECTORY "/usr"
 #endif
 
 namespace Plugin
@@ -108,15 +108,15 @@ bool SimpleDVD::execute ( )
 QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber )
 {
   QFileInfo fileInfo;
-  QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName;
+  QString qsMenuXML, qsBackgroundFile, qsMenuName, qsFileName, qsGroupName;
   QString qsHeight = "480";
   QString qsButtonName, qsFrameName, qsObjectName, qsJumpTo, qsX, qsY;
-  int iCount = 0;
+  int iCount = 0, iSlideCount = 1;
   SourceGroup *pGroup = NULL;
   if ( list.count ( ) < 1 )
     return qsMenuXML;
 
-  qsBackgroundFile = PREFIX"/share/qdvdauthor/plugins/simpledvd/background.jpg";
+  qsBackgroundFile = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/background.jpg";
   qsMenuName.sprintf ( "Menu %d", iMenuNumber );
   pGroup = list[0];
   if ( pGroup->enType == SourceGroup::PAL )
@@ -128,18 +128,18 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
   qsMenuXML += "    <MenuDuration>00:00:01.000</MenuDuration>\n";
   qsMenuXML += "   <MenuBackground ResizeAlgo=\"Normal Qt\" OffsetX=\"0\" OffsetY=\"0\" StretchType=\"2\" >"+qsBackgroundFile+"</MenuBackground>\n";
   qsMenuXML += "   <MenuName>"+qsMenuName+"</MenuName>\n";
-  qsMenuXML += "   <MaskColors>#00fefffe,#fffa9632,#ffff1414,#ffffff14,</MaskColors>\n";
+  qsMenuXML += "   <MaskColors>#00fefffe,#a0ff1414,#a0fa9632,#ff0f0fff,</MaskColors>\n";
   qsMenuXML += "  </MenuVariables>\n";
   qsMenuXML += "  <PreviewVariables>\n";
 
-  // Transparent area - Top
+  // Semi-transparent area - Top
   qsMenuXML += "   <TextObject BackgroundColor=\"#ffaaff5a\" TextAlign=\"4,64\" ForegroundColor=\"#fff15735\" Font=\"Sans Serif,20,-1,5,75,0,0,0,0,0\" Text=\"\" >\n";
   qsMenuXML += "    <MenuObject Width=\"740\" X=\"0\" Y=\"35\" Height=\"150\" ObjectName=\"\" >\n";
   qsMenuXML += "     <Modifiers Transparency=\"0.60\" />\n";
   qsMenuXML += "    </MenuObject>\n";
   qsMenuXML += "   </TextObject>\n";
 
-  // Transparent area - Bottom
+  // Semi-transparent area - Bottom
   qsMenuXML += "   <TextObject BackgroundColor=\"#fff4f5f4\" TextAlign=\"4,64\" ForegroundColor=\"#ff000000\" Font=\"Courier,12,-1,5,50,0,0,0,0,0\" Text=\"\" >\n";
   qsMenuXML += "    <MenuObject Width=\"740\" X=\"-8\" Y=\"285\" Height=\"150\" ObjectName=\"\" >\n";
   qsMenuXML += "     <Modifiers Transparency=\"0.60\" />\n";
@@ -154,15 +154,22 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
 
     if ( ! pGroup )
        continue;
-    qsFileName = "";
-    if ( pGroup->listFiles.size ( ) > 0 )  {
+
+    qsGroupName = pGroup->qsGroupName;
+    qsFileName  = "";
+    if ( pGroup->bSlideshow )  {
+      qsGroupName.sprintf ( "[%02d] - %s", iSlideCount++, (const char *)pGroup->qsGroupName.utf8 ( ) );
+      qsFileName  = pGroup->qsGroupName + ".vob+-+00:00:00.000";
+    }
+    else if ( pGroup->listFiles.size ( ) > 0 )  {
       fileInfo.setFile ( pGroup->listFiles[0]->qsFileName );
       qsFileName = fileInfo.fileName ( );
       if ( qsFileName.length ( ) > 0 )
         qsFileName += "+-+00:00:00.000";
     }
-//jump+-+[01] - cordes.mpg+-+001_capture001.mpeg+-+00:00:00.000
-    qsJumpTo = QString ( "jump+-+%1+-+%2" ).arg ( pGroup->qsGroupName ).arg ( qsFileName );
+
+    // jump+-+[01] - cordes.mpg+-+001_capture001.mpeg+-+00:00:00.000
+    qsJumpTo = QString ( "jump+-+%1+-+%2" ).arg ( qsGroupName ).arg ( qsFileName );
     qsButtonName  = QString ( "Button %1" ).arg ( ++iCount );
     qsObjectName  = QString ( "Object_%1" ).arg (   iCount );
     qsFrameName   = QString ( "Frame %1"  ).arg (   iCount );
@@ -177,7 +184,7 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
     qsY = ( iCount > 3 ) ? "295" : "45";
 
     // Next we create the ButtonObject for the video jump+-+vmgm+-+
-    qsMenuXML += "   <ButtonObject Action=\""+qsJumpTo+"\" ButtonName=\""+qsButtonName+"\" >\n";
+    qsMenuXML += "   <ButtonObject Action=\""+qsJumpTo+"\" ButtonName=\""+qsButtonName+"\"  SourceEntry=\""+qsGroupName+"\" >\n";
     qsMenuXML += "    <NormalState>\n";
     qsMenuXML += "     <ImageObject FileName=\""+pGroup->qsScreenshot+"\" >\n";
     qsMenuXML += "      <Manipulator>\n";
@@ -188,12 +195,12 @@ QString SimpleDVD::getMenuXML ( QValueList<SourceGroup *> &list, int iMenuNumber
     qsMenuXML += "    </NormalState>\n";
 
     qsMenuXML += "    <SelectedState>\n";
-    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#ffff1414\" >\n";
+    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#a0ff1414\" >\n";
     qsMenuXML += "      <MenuObject Width=\"150\" X=\""+qsX+"\" Y=\""+qsY+"\" Height=\"112\" ObjectName=\""+qsFrameName+"\" />\n";
     qsMenuXML += "     </FrameObject>\n";
     qsMenuXML += "    </SelectedState>\n";
     qsMenuXML += "    <HighlightedState>\n";
-    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#fffa9632\" >\n";
+    qsMenuXML += "     <FrameObject Width=\"10\" Color=\"#ff0f0fff\" >\n";
     qsMenuXML += "      <MenuObject Width=\"150\" X=\""+qsX+"\" Y=\""+qsY+"\" Height=\"112\" ObjectName=\""+qsFrameName+"\" />\n";
     qsMenuXML += "     </FrameObject>\n";
     qsMenuXML += "    </HighlightedState>\n";
@@ -215,9 +222,9 @@ QString SimpleDVD::getMenuButtons ( bool bPrev, bool bNext, int iMenuNumber )
 {
   QString qsMenuXML, qsMenuName;
   // The three buttons to the previous, next and Main menu ...
-  QString qsButtonPrev = PREFIX"/share/qdvdauthor/plugins/simpledvd/prev.png";
-  QString qsButtonMain = PREFIX"/share/qdvdauthor/plugins/simpledvd/main.png";
-  QString qsButtonNext = PREFIX"/share/qdvdauthor/plugins/simpledvd/next.png";
+  QString qsButtonPrev = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/prev.png";
+  QString qsButtonMain = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/main.png";
+  QString qsButtonNext = PREFIX_DIRECTORY"/share/qdvdauthor/plugins/simpledvd/next.png";
   if ( bPrev )  {
     qsMenuName = QString ( "Menu %1" ).arg ( iMenuNumber - 1 );
     qsMenuXML += "   <ButtonObject Action=\"jump+-+"+qsMenuName+"+-+\" ButtonName=\"Button 7\" >\n";
