@@ -14,7 +14,7 @@ class SourceGroup
     class SourceEntry  {
     public:
       SourceEntry ( ) { iLength=0; };
-      QString qsFileName;
+      QString    qsFileName;
       unsigned long iLength; // in MSec
     };
              SourceGroup ( ) { enType=NTSC; bSlideshow=false; bCreateChapterMenu=false; };
@@ -33,9 +33,12 @@ class SourceGroup
     QDateTime     dateEnd;     // The ending date of the Slideshow  / Videos
 
     QValueList<SourceEntry *> listFiles;
-    QString  qsScreenshot;
-    bool     bSlideshow;
-}; // end class CreateDVD
+    QString     qsScreenshot;
+    bool        bSlideshow;
+    int         iFilterLength;
+    QString     qsBackground;
+    QStringList listAudio;
+}; // end class SourceGroup
 
 }; // end namespace Plugin
 
