@@ -61,6 +61,9 @@ public:
 	QDVDAuthor ( );
 	virtual ~QDVDAuthor ( );
 
+protected:
+	virtual void customEvent ( QCustomEvent * );
+
 public slots:
 	virtual void fileNew      ( );
 	virtual void fileWizard   ( );
@@ -187,6 +190,7 @@ private: 	// Private functions ...
 	void createMenuXml          ( );
 	void createDVD              ( );
 	bool checkHealth            ( );
+	void engageCreateDVD        ( bool ); // Called to put QDVDAuthor in wait mode for slideshows to finish
 	QString getTempFile         ( QString );
 
 private:
@@ -202,6 +206,7 @@ private:
 	QString                 m_qsStyle;
 	QTimer                 *m_pTimerAutosave;
 	bool                    m_bAutosaving;
+	bool                    m_bCreateDVDAfterSlideshows;
 
 	Plugin::Interface      *m_pPluginInterface;
 	ColorToolBar           *m_pColorToolbar;
