@@ -366,22 +366,17 @@ xine_stream_t *XineInfo::getXineStream ()
 
 QImage XineInfo::getScreenshot ( long iMSecOffset )
 {
-	if ( ! xine_open ( m_pXineStream, (const char *)m_qsFileName ) ) 
-		return getScreenshot ( m_qsFileName );
-	if (iMSecOffset == 0)
-		return getScreenshot ( m_qsFileName );
-	// first we try the trick mode ... Ooops not implemented, will crash QDVDAuthor. Maybe in the future.
-	int iTricky = 0; // xine_trick_mode (m_pXineStream, XINE_TRICK_MODE_SEEK_TO_TIME, iStartTime * 1000);
-	if (iTricky == 0)	{	// Input does not support the trick mode, 
-		// so we use start/stop to get there ...
-		iTricky = xine_play ( m_pXineStream, 0, iMSecOffset );
-		//int iError = xine_get_error (m_pXineStream);
-		xine_stop (m_pXineStream);
-	}
-	QImage theScreenshot = getScreenshot (m_qsFileName);
+  if ( ! xine_open ( m_pXineStream, (const char *)m_qsFileName ) )
+    return getScreenshot ( m_qsFileName );
 
-	xine_close (m_pXineStream);
-	return theScreenshot;
+  xine_play ( m_pXineStream, 0, iMSecOffset );
+  xine_stop ( m_pXineStream );
+
+  QImage theScreenshot = getScreenshot ( m_qsFileName );
+  
+  xine_close ( m_pXineStream );
+
+  return theScreenshot;
 }
 
 QImage XineInfo::getScreenshot(QString)
@@ -390,7 +385,6 @@ QImage XineInfo::getScreenshot(QString)
 	int iWidth, iHeight;
 	double fScaleFactor;
 
-//	setFileName   (qsMovieFile);
 	GetScreenshot (pRgbPile, iWidth, iHeight, fScaleFactor);
 	
 	if (!pRgbPile)
