@@ -1,8 +1,11 @@
 /****************************************************************************
 ** MediaCreator - class
 **
-** Created: Tue Nov 16 12:09:08 2004
-**      by: Varol Okan using kate editor
+**   Created : Tue Nov 16 12:09:08 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
+**
 **
 ** This class is only a helper class to create a appropriate Media object.
 ** Here we take care of the availability of the actual libraries etc.
@@ -26,6 +29,8 @@
 
 class SourceFileInfo;
 class MediaScanner;
+class ExecuteJob;
+class Subtitles;
 class MediaInfo;
 class QImage;
 
@@ -44,7 +49,9 @@ public:
 
 	// This will register a creation of a preview in a background task.
 	static void            registerWithMediaScanner  ( QObject *, QString &, QImage *, long s=0L );
-	static void            registerWithMediaScanner  ( QObject *, SourceFileInfo *, long s=0L, bool b=true );
+	static void            registerWithMediaScanner  ( QObject *, SourceFileInfo *, long s=0L,   bool b=false );
+	static void            registerWithMediaScanner  ( QObject *, SourceFileInfo *, Subtitles *, float );
+	static void            registerWithMediaScanner  ( ExecuteJob * );
 	static void            unregisterFromMediaScanner( SourceFileInfo * );
 	static void            unregisterFromMediaScanner( QObject * );
 
@@ -53,8 +60,11 @@ public:
 	static QString         getEngineDescription ( QString );
 	static QString         preferredEngine      ( );
 
-	static QString        m_qsPreferredEngine;
-	static MediaScanner  *pPreviewObject;	// This is not a var but the child thread ...
+	static QString         m_qsPreferredEngine;
+	static MediaScanner   *pPreviewObject;	// This is not a var but the child thread ...
+
+private:
+	static void            ensureMediaScannerExists ( );
 };
 
 #endif	// MEDIACREATOR_H
