@@ -43,9 +43,9 @@
 
 #include "qplayer.h"
 #include "mediacreator.h"
-#include "sourcefiledialog.h"
 #include "dialogaboutqplayer.h"
 #include "dialogconfigure.h"
+#include "../filepreviewdialog.h"
 
 #include "mediainfo.h"
 
@@ -330,6 +330,28 @@ void QPlayer::saveHistory ()
 // The standard slots implemented in QXine ...
 void QPlayer::fileOpen()
 {
+  QString qsFilter = "*.mpg *.vob *.avi *.m2v *.mpeg2";
+  if ( m_pMediaInterface )  {
+    MediaInfo *pInfo = m_pMediaInterface->getMediaInfo ( );
+    if ( pInfo )
+         qsFilter = pInfo->getExtensions ( true );
+    else  {
+      pInfo = MediaCreator::createInfo ( m_pMediaInterface->getMediaEngine ( ) );
+      if ( pInfo )  {
+           qsFilter = pInfo->getExtensions ( true );
+           delete pInfo;
+      }
+    }
+  }
+
+  QString qsFileName = FilePreviewDialog::getOpenFileName ( m_pMediaInterface->getMediaEngine ( ),
+                         QString::null, qsFilter, this );
+
+  if ( qsFileName.isEmpty ( ) )
+    return;
+  setFileName ( qsFileName );
+
+/*
 	// Here we open the MovieDialog.
 	// Note: THe preview depends on the same class as
 	// the main VideoDiaplay in QXine, thus please
@@ -347,6 +369,7 @@ void QPlayer::fileOpen()
 	if (iReturn == QDialog::Rejected)
 		return;
 	setFileName (pDialog->getFileName());
+*/
 }
 
 void QPlayer::setFileName (QString qsFileName, bool bAddCurrentPath)
