@@ -13,7 +13,7 @@
 #include <qpopupmenu.h>
 #include <qtoolbar.h>
 
-#include "xml_slideshow.h"
+#include "../xml_slideshow.h"
 #include "dialogfilter.h"
 #include "dialogcreate.h"
 #include "imagepreview.h"
