@@ -145,10 +145,14 @@ bool Modifiers::readProjectFile (QDomNode &theNode)
 // ImageManipulator class
 //
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-ImageManipulator::ImageManipulator ()
+ImageManipulator::ImageManipulator ( )
 {
 	node_name = QString (MANIPULATOR);
+	reset ( );
+}
 
+void ImageManipulator::reset ( )
+{
 	backgroundFileName = QString ("");
 	bShowBackground = false;
 	fKenBurnsX1 = -1.0f;
@@ -167,9 +171,9 @@ ImageManipulator::ImageManipulator ()
 	fScaleX = 1.0f;
 	fScaleY = 1.0f;
 	fRotate = 0.0f;
-	fRed    = 1.0f;
-	fGreen  = 1.0f;
-	fBlue   = 1.0f;
+	fRed    = 1.0;
+	fGreen  = 1.0;
+	fBlue   = 1.0;
 	fBrightness   = 0.0f;
 	fTransparency = 0.0f;	// Opaque in the beginning ...
 	iStartFrame   =   -1;
