@@ -1,8 +1,10 @@
 /****************************************************************************
 ** SelectionObject is being used in MenuPreview for multiple selections
 **
-** Created: Sun Mar 23 21:45:00 2006
-**      by: Varol Okan using xemacs
+**   Created : Sun Mar 23 21:45:00 2006
+**        by : Varol Okan using xemacs
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
 **
 **
 ****************************************************************************/
@@ -13,11 +15,12 @@
 #include "objectcollection.h"
 
 class QPainter;
+class ShadowObject;
 
 class SelectionObject : public ObjectCollection
 {
   Q_OBJECT
-  
+
 public:
   // Public functions needed for the abstract base class.
   SelectionObject         ( QWidget *pParent=0 );
@@ -31,8 +34,26 @@ public:
   virtual bool mousePressEvent ( QMouseEvent * );
   virtual bool createContextMenu      ( QPoint );
 
-  virtual void drawContents       ( QPainter * );
-  virtual void drawSelected       ( QPainter * );
+  virtual void setActive        ( bool );
+  virtual void drawContents     ( QPainter   * );
+  virtual void drawSelected     ( QPainter   * );
+  virtual void setShadow        ( MenuObject * );
+  virtual MenuObject* shadow    (              );
+
+  void clearShadows   ( );
+  void drawShadows    ( QPainter * );
+  void updateShadows  ( ShadowObject *, bool );
+
+signals:
+  void signalAlignSelection ( );
+
+protected slots:
+  virtual void slotAlign  ( );
+  virtual void slotDelete ( );
+  virtual void slotCut    ( );
+
+private:
+  QValueList<ShadowObject *> m_listOfShadows;
 
 };
 
