@@ -21,6 +21,8 @@
 #include "xml_dvd.h"
 #include "messagebox.h"
 #include "sourcefileentry.h"
+#include "xml_slideshow.h"
+#include "render_client.h"
 
 AudioEntry::AudioEntry ( )
 {
@@ -66,7 +68,7 @@ Audio &Audio::operator = ( Audio &theOther )
 bool Audio::readProjectFile  ( QDomNode &xmlNode )
 {
   QString     qsAttribute, qsFile, qsTagName;
-  QDomElement theElement = xmlNode.toElement();
+  QDomElement theElement = xmlNode.toElement ( );
   QDomNode    infoNode;
 
   qsAttribute = theElement.attributeNode ( AUDIO_NUMBER ).value();
@@ -108,7 +110,7 @@ bool Audio::writeProjectFile ( QDomElement &inElement )
 
   // store the file name too ...
   tmpFileElement = xmlDoc.createElement( AUDIO_FILE_NAME );
-  text = xmlDoc.createTextNode( qsFileName );
+  text = xmlDoc.createTextNode( qsFileName.utf8 ( ) );
   tmpFileElement.appendChild( text );
   theElement.appendChild ( tmpFileElement );
   if ( pTranscodeInterface )  {
@@ -282,6 +284,7 @@ bool TranscodeInterface::writeProjectFile (QDomElement &theElement)
 
 SourceFileInfo::SourceFileInfo ()
 {
+  pSlideshow     = NULL;
   pPreview       = NULL;
   bAutotranscode = true;
   bMetaSubtitles = true;
@@ -298,10 +301,12 @@ SourceFileInfo::SourceFileInfo ()
 
 SourceFileInfo::~SourceFileInfo ()
 {
-  if (pPreview)
+  if ( pPreview )
     delete pPreview;
-  if (pTranscodeInterface)
+  if ( pTranscodeInterface )
     delete pTranscodeInterface;
+  if ( pSlideshow )
+    delete pSlideshow;
 
   deleteSubtitles ( );
   deleteAudio     ( );
@@ -425,185 +430,99 @@ SourceFileEntry::~SourceFileEntry()
 
 bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
 {
-        int t;
-	QString qsAttribute, infoName, infoText;
+  int t;
+  QString qsAttribute, infoName, infoText;
 
-	QDomNode    infoNode, transcodeNode;
-	QDomElement infoElement;
-	QDomElement theElement = xmlNode.toElement();
+  QDomNode    infoNode, transcodeNode;
+  QDomElement infoElement;
+  QDomElement theElement = xmlNode.toElement();
 
-	QDomAttr a = theElement.attributeNode ( SOURCE_OBJECT_DISPLAY_NAME );
-	qsDisplayName = a.value();
-	a = theElement.attributeNode ( SOURCE_OBJECT_PRE );
-	qsPre = a.value();
-	a = theElement.attributeNode ( SOURCE_OBJECT_POST );
-	qsPost = a.value();
-	qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_IS_SOUND_SOURCE ).value();
-	bSoundSource = false;
-	if ( (!qsAttribute.isEmpty ()) && (qsAttribute == QString ("true")) )
-	  bSoundSource = true;
-	qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_PAUSE ).value();
-	if (!qsAttribute.isEmpty ())
-	  iPause = qsAttribute.toInt();
+  QDomAttr a = theElement.attributeNode ( SOURCE_OBJECT_DISPLAY_NAME );
+  qsDisplayName = a.value();
+  a = theElement.attributeNode ( SOURCE_OBJECT_PRE );
+  qsPre = a.value();
+  a = theElement.attributeNode ( SOURCE_OBJECT_POST );
+  qsPost = a.value();
+  qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_IS_SOUND_SOURCE ).value();
+  bSoundSource = false;
+  if ( (!qsAttribute.isEmpty ()) && (qsAttribute == QString ("true")) )
+    bSoundSource = true;
+  qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_PAUSE ).value();
+  if (!qsAttribute.isEmpty ())
+    iPause = qsAttribute.toInt();
 
-	for ( t=0; t<MAX_AUDIO; t++ ) {
-	  arrayAudioEntries[t].iAudioNumber = -1;
-	  arrayAudioEntries[t].qsIso639     = QString ( );
-	}
-	for ( t=0; t<MAX_SUBTITLES; t++ ) {
-	  arraySubtitleEntries[t].m_iSubtitleNumber = -1;
-	  arraySubtitleEntries[t].m_qsIso639        = QString ( );
-	}
-	  
-	QDomNode sourceNode = theElement.firstChild();
-	while (!sourceNode.isNull() )	{
-		theElement = sourceNode.toElement();
-		// Okay, here we read the stored data from the xml file.
-		QString tagName = theElement.tagName();
-		// Okay, this is ugly but after all it is the simplest of all xml file structure.
-		// No need to get fancy ...
-		if ( SOURCE_OBJECT_AUDIO == tagName )  {
-		  QString qsIso639;
-		  int iAudioNumber = -1;
-		  qsAttribute = theElement.attributeNode ( AUDIO_LANGUAGE ).value ( );
-		  if ( ! qsAttribute.isEmpty ( ) )
-		    qsIso639 = qsAttribute;  
-		  qsAttribute = theElement.attributeNode ( AUDIO_NUMBER ).value ( );
-		  if ( ! qsAttribute.isEmpty ( ) )
-		    iAudioNumber = qsAttribute.toInt ( );
+  for ( t=0; t<MAX_AUDIO; t++ ) {
+    arrayAudioEntries[t].iAudioNumber = -1;
+    arrayAudioEntries[t].qsIso639     = QString ( );
+  }
+  for ( t=0; t<MAX_SUBTITLES; t++ ) {
+    arraySubtitleEntries[t].m_iSubtitleNumber = -1;
+    arraySubtitleEntries[t].m_qsIso639        = QString ( );
+  }
 
-		  if ( ( iAudioNumber > -1 ) && ( iAudioNumber < MAX_AUDIO ) ) {
-		    arrayAudioEntries[ iAudioNumber ].iAudioNumber = iAudioNumber;
-		    arrayAudioEntries[ iAudioNumber ].qsIso639     = qsIso639;
-		  }		 
-		}
-		if ( SOURCE_OBJECT_SUBTITLES == tagName )  {
-		  QString qsIso639;
-		  int iSubtitleNumber = -1;
-		  qsAttribute = theElement.attributeNode ( SUBTITLES_LANG ).value ( );
-		  if ( ! qsAttribute.isEmpty ( ) )
-		    qsIso639 = qsAttribute;  
-		  qsAttribute = theElement.attributeNode ( SUBTITLES_NUMBER ).value ( );
-		  if ( ! qsAttribute.isEmpty ( ) )
-		    iSubtitleNumber = qsAttribute.toInt ( );
+  QDomNode  sourceNode = theElement.firstChild ( );
+  while ( ! sourceNode.isNull() )	{
+    theElement   = sourceNode.toElement  ( );
+    // Okay, here we read the stored data from the xml file.
+    QString tagName = theElement.tagName ( );
+    // Okay, this is ugly but after all it is the simplest of all xml file structure.
+    // No need to get fancy ...
+    if ( SOURCE_OBJECT_AUDIO == tagName )  {
+      QString qsIso639;
+      int iAudioNumber = -1;
+      qsAttribute = theElement.attributeNode ( AUDIO_LANGUAGE ).value ( );
+      if ( ! qsAttribute.isEmpty ( ) )
+        qsIso639 = qsAttribute;  
+      qsAttribute = theElement.attributeNode ( AUDIO_NUMBER ).value ( );
+      if ( ! qsAttribute.isEmpty ( ) )
+        iAudioNumber = qsAttribute.toInt ( );
 
-		  if ( ( iSubtitleNumber > -1 ) && ( iSubtitleNumber < MAX_SUBTITLES ) ) {
-		    arraySubtitleEntries[ iSubtitleNumber ].m_iSubtitleNumber = iSubtitleNumber;
-		    arraySubtitleEntries[ iSubtitleNumber ].m_qsIso639        = qsIso639;
-		  }		 
-		}
-		else if ( SOURCE_OBJECT_INFO == tagName )  {
-			SourceFileInfo *pFileInfos = new SourceFileInfo;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_SIZE).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsSize = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_RESOLUTION).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsResolution = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_FPS).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsFPS = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_RATIO).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsRatio = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_LENGTH).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsLength = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_VIDEO_FORMAT).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsVideoFormat = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_VIDEO_CODEC).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsVideoCodec = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUDIO_FORMAT).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsAudioFormat = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUDIO_CODEC).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsAudioCodec  = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_STATUS).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsStatus = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_BITS).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsBits = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_SAMPLE).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsSample = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_BPS).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-				pFileInfos->qsBPS = qsAttribute;
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_PAUSE).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-			  pFileInfos->iPause = qsAttribute.toInt();
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_TITLESET).value();
-			if ( ! qsAttribute.isEmpty ( ) )
-			  pFileInfos->iTitleset = qsAttribute.toInt();
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUTOTRANSCODE).value();
-			pFileInfos->bAutotranscode = true;
-			if ( ! qsAttribute.isEmpty ( ) )
-			  pFileInfos->bAutotranscode = ( qsAttribute == QString ("true") );
-			qsAttribute = theElement.attributeNode (SOURCE_OBJECT_METASUBTITLES).value();
-			pFileInfos->bMetaSubtitles = true;
-			if ( ! qsAttribute.isEmpty ( ) )
-			  pFileInfos->bMetaSubtitles = ( qsAttribute == QString ("true") );
-			qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_MSEC_OFFSET ).value ( );
-			if ( ! qsAttribute.isEmpty ( ) )
-			  pFileInfos->iMSecPreview = qsAttribute.toInt ( );
+      if ( ( iAudioNumber > -1 ) && ( iAudioNumber < MAX_AUDIO ) ) {
+        arrayAudioEntries[ iAudioNumber ].iAudioNumber = iAudioNumber;
+        arrayAudioEntries[ iAudioNumber ].qsIso639     = qsIso639;
+      }
+    }
+    if ( SOURCE_OBJECT_SUBTITLES == tagName )  {
+      QString qsIso639;
+      int iSubtitleNumber = -1;
+      qsAttribute = theElement.attributeNode ( SUBTITLES_LANG ).value ( );
+      if ( ! qsAttribute.isEmpty ( ) )
+        qsIso639 = qsAttribute;  
+      qsAttribute = theElement.attributeNode ( SUBTITLES_NUMBER ).value ( );
+      if ( ! qsAttribute.isEmpty ( ) )
+        iSubtitleNumber = qsAttribute.toInt ( );
 
-			infoNode = theElement.firstChild ( );
-			pFileInfos->deleteSubtitles ( );
-			while (!infoNode.isNull())	{
-				infoElement = infoNode.toElement();
-				// Okay, here we read the stored data from the xml file.
-				infoName = infoElement.tagName();
-				infoText = infoElement.text ();
-				if (SOURCE_OBJECT_FILE_NAME == infoName)	{
-					if (!infoText.isEmpty())
-						pFileInfos->qsFileName = infoText;
-				}
-				else if (SOURCE_OBJECT_CHAPTERS == infoName)	{
-					if (!infoText.isEmpty())
-						pFileInfos->listChapters = QStringList::split (",", infoText);
-				}
-				else if (SOURCE_OBJECT_PROPERTIES == infoName)	{
-					qsAttribute = infoElement.attributeNode (SOURCE_PROPERTIES_POST).value();
-					if (!qsAttribute.isEmpty())
-						pFileInfos->qsPostCommand = qsAttribute;
-					qsAttribute = infoElement.attributeNode (SOURCE_PROPERTIES_PRE).value();
-					if (!qsAttribute.isEmpty())
-						pFileInfos->qsPreCommand = qsAttribute;
-					qsAttribute = infoElement.attributeNode (SOURCE_PROPERTIES_PAUSE).value();
-					if (!qsAttribute.isEmpty())
-						pFileInfos->iPause = qsAttribute.toInt();
-				}
-				else if (SOURCE_OBJECT_TRANSCODE == infoName)	{
-					if ( pFileInfos->pTranscodeInterface)
-						delete pFileInfos->pTranscodeInterface;
-					pFileInfos->pTranscodeInterface = new TranscodeInterface;
-					pFileInfos->pTranscodeInterface->readProjectFile (infoNode);
-				}
-				else if (SOURCE_OBJECT_SUBTITLES == infoName)	{
-				  Subtitles *pSubtitle = new Subtitles;
-				  pSubtitle->readProjectFile ( infoNode );
-				  pFileInfos->addSubtitles   ( pSubtitle );
-				}
-				else if (SOURCE_OBJECT_AUDIO == infoName)	{
-				  Audio *pAudio = new Audio;
-				  pAudio->readProjectFile ( infoNode );
-				  pFileInfos->addAudio    ( pAudio   );
-				}
-				infoNode = infoNode.nextSibling ();
-			}
-			listFileInfos.append (pFileInfos);
-		}
-		else if (SOURCE_OBJECT_CHAPTERS == tagName)	{
-			infoText = theElement.text ();
-			listChapters = QStringList::split ( QString (","), infoText);
-		}
-		// Otherwise go to the next node ...
-		sourceNode = sourceNode.nextSibling();
-	}
+      if ( ( iSubtitleNumber > -1 ) && ( iSubtitleNumber < MAX_SUBTITLES ) ) {
+        arraySubtitleEntries[ iSubtitleNumber ].m_iSubtitleNumber = iSubtitleNumber;
+        arraySubtitleEntries[ iSubtitleNumber ].m_qsIso639        = qsIso639;
+      }
+    }
+    else if ( SOURCE_OBJECT_INFO == tagName )  {
+      SourceFileInfo *pFileInfos = new SourceFileInfo;
+      pFileInfos->readProjectFile ( sourceNode );
+      listFileInfos.append        ( pFileInfos );
+    }
+    else if (SOURCE_OBJECT_CHAPTERS == tagName)	{
+      infoText = theElement.text ();
+      listChapters = QStringList::split ( QString (","), infoText);
+    }
+    // Otherwise go to the next node ...
+    sourceNode = sourceNode.nextSibling();
+  }
+
+  // Finally we check the slideshow flag.
+  if ( listFileInfos.count ( ) == 1 )  {
+    SourceFileInfo *pInfo = listFileInfos[0];
+    if ( pInfo->pSlideshow )  {
+      Utils theUtils;
+      QString qsFileName = theUtils.getTempFile ( pInfo->pSlideshow->slideshow_name + ".vob" );
+      QFileInfo fileInfo ( qsFileName );
+      if ( ! fileInfo.exists ( ) ) { // generated file does not exist.
+        bIsSlideshow = true;
+        Render::Manager::registerEntry ( this );
+      }
+    }
+  }
   // VAROL 
   /*
   printf ( "%s::%s : %d > ", __FILE__, __FUNCTION__, __LINE__ );
@@ -614,31 +533,25 @@ bool SourceFileEntry::readProjectFile  (QDomNode &xmlNode)
   return true;
 }
 
-bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
+bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave )
 {
-  // This check means that the slideshow has not yet been finished, thus we should not bother to
-  // store this record since the mpeg does probably not exist.
-  if (bIsSlideshow && bAutosave)	{
-    MessageBox::warning (NULL,QObject::tr("Warning"), QObject::tr ("Warning, the slideshow \n%1\nis not finished.\nThe SourceFileEntry will not be stored.").arg(qsDisplayName), QMessageBox::Ok, QMessageBox::NoButton);
-    return true;
-  }
-  uint t, i;
-  QDomDocument xmlDoc = theElement.ownerDocument();
-  QDomElement sourceNode = xmlDoc.createElement( SOURCE_OBJECT );	// <FrameObject>
-  
-  QDomElement fileElement, infoElement, chapterElement, transcodeElement, subtitlesElement, propertiesElement; //tag;
-  QDomElement tag;
-  QDomText text;
+  uint t;
+  SourceFileInfo *pInfo;
+  QDomDocument   xmlDoc     = theElement.ownerDocument ( );
+  QDomElement    sourceNode = xmlDoc.createElement ( SOURCE_OBJECT );  // <Source>
+  QDomElement    infoElement, chapterElement;
+  QDomText       text;
+
   // Here we set the attributes of the <dvdauthor> tag
   if ( ! qsDisplayName.isNull() )
-    sourceNode.setAttribute( SOURCE_OBJECT_DISPLAY_NAME, qsDisplayName );
-  if ( ! qsPre.isNull() )
-    sourceNode.setAttribute( SOURCE_OBJECT_PRE, qsPre );
-  if ( ! qsPost.isNull() )
-    sourceNode.setAttribute( SOURCE_OBJECT_POST, qsPost );
-  if (bSoundSource)
-    sourceNode.setAttribute( SOURCE_OBJECT_IS_SOUND_SOURCE, "true" );
-  sourceNode.setAttribute( SOURCE_OBJECT_PAUSE, QString ("%1").arg (iPause) ); 
+    sourceNode.setAttribute ( SOURCE_OBJECT_DISPLAY_NAME, qsDisplayName );
+  if ( ! qsPre.isNull  ( ) )
+    sourceNode.setAttribute ( SOURCE_OBJECT_PRE, qsPre );
+  if ( ! qsPost.isNull ( ) )
+    sourceNode.setAttribute ( SOURCE_OBJECT_POST, qsPost );
+  if ( bSoundSource )
+    sourceNode.setAttribute ( SOURCE_OBJECT_IS_SOUND_SOURCE, "true" );
+  sourceNode.setAttribute   ( SOURCE_OBJECT_PAUSE, QString ("%1").arg ( iPause ) ); 
 
   for ( t=0; t<MAX_AUDIO; t++ )  {
     if ( arrayAudioEntries [ t ].iAudioNumber > -1 ) {
@@ -656,100 +569,22 @@ bool SourceFileEntry::writeProjectFile (QDomElement &theElement, bool bAutosave)
       sourceNode.appendChild  ( infoElement );
     }
   }
-  // VAROL 
-  /*
-  printf ( "%s::%s : %d > ", __FILE__, __FUNCTION__, __LINE__ );
-  for ( int e=0;e<MAX_AUDIO;e++ )
-    printf ( "[%d=%s] ", arrayAudioEntries[e].iAudioNumber, arrayAudioEntries[e].qsIso639.ascii() );
-  printf ( "\n" );
-  */
+
   if (listFileInfos.count() > 0)	{
-    for (t=0;t<listFileInfos.count();t++)	{
-      infoElement = xmlDoc.createElement( SOURCE_OBJECT_INFO );
-      if (!listFileInfos[t]->qsSize.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_SIZE, listFileInfos[t]->qsSize );
-      if (!listFileInfos[t]->qsResolution.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_RESOLUTION, listFileInfos[t]->qsResolution );
-      if (!listFileInfos[t]->qsFPS.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_FPS, listFileInfos[t]->qsFPS );
-      if (!listFileInfos[t]->qsRatio.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_RATIO, listFileInfos[t]->qsRatio );
-      if (!listFileInfos[t]->qsLength.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_LENGTH, listFileInfos[t]->qsLength );
-      if (!listFileInfos[t]->qsVideoFormat.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_VIDEO_FORMAT, listFileInfos[t]->qsVideoFormat );
-      if (!listFileInfos[t]->qsVideoCodec.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_VIDEO_CODEC,  listFileInfos[t]->qsVideoCodec  );
-      if (!listFileInfos[t]->qsAudioFormat.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_AUDIO_FORMAT, listFileInfos[t]->qsAudioFormat );
-      if (!listFileInfos[t]->qsAudioCodec.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_AUDIO_CODEC,  listFileInfos[t]->qsAudioCodec  );
-      if (!listFileInfos[t]->qsStatus.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_STATUS, listFileInfos[t]->qsStatus );
-      if (!listFileInfos[t]->qsBits.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_BITS, listFileInfos[t]->qsBits );
-      if (!listFileInfos[t]->qsSample.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_SAMPLE, listFileInfos[t]->qsSample );
-      if (!listFileInfos[t]->qsBPS.isNull())
-	infoElement.setAttribute( SOURCE_OBJECT_BPS, listFileInfos[t]->qsBPS );
-      if ( listFileInfos[t]->iPause !=-1 )
-	infoElement.setAttribute( SOURCE_OBJECT_PAUSE, QString ("%1").arg(listFileInfos[t]->iPause) );
-      if ( listFileInfos[t]->iTitleset != -1 )
-	infoElement.setAttribute( SOURCE_OBJECT_TITLESET, QString ("%1").arg(listFileInfos[t]->iTitleset) );
-      if ( listFileInfos[t]->bAutotranscode == false )
-	infoElement.setAttribute( SOURCE_OBJECT_AUTOTRANSCODE, "false" );
-      if ( listFileInfos[t]->bMetaSubtitles == false )
-	infoElement.setAttribute( SOURCE_OBJECT_METASUBTITLES, "false" );
-      if ( listFileInfos[t]->iMSecPreview !=-1 )
-	infoElement.setAttribute( SOURCE_OBJECT_MSEC_OFFSET, QString ("%1").arg(listFileInfos[t]->iMSecPreview) );
-      // Here we create another level in the XML tree for name and chapter ...
-      // First the file name
-      fileElement = xmlDoc.createElement( SOURCE_OBJECT_FILE_NAME );
-      text = xmlDoc.createTextNode(listFileInfos[t]->qsFileName);
-      fileElement.appendChild( text );
-      infoElement.appendChild( fileElement );
-      // Second the properties (Post / Pre, and Pause)
-      propertiesElement = xmlDoc.createElement( SOURCE_OBJECT_PROPERTIES );
-      if (!listFileInfos[t]->qsPostCommand.isNull())
-	propertiesElement.setAttribute( SOURCE_PROPERTIES_POST, listFileInfos[t]->qsPostCommand );
-      if (!listFileInfos[t]->qsPreCommand.isNull())
-	propertiesElement.setAttribute( SOURCE_PROPERTIES_PRE, listFileInfos[t]->qsPreCommand );
-      propertiesElement.setAttribute( SOURCE_PROPERTIES_PAUSE, QString ("%1").arg(listFileInfos[t]->iPause ));
-      infoElement.appendChild( propertiesElement );
-      // Then chapters if avail.
-      if (listFileInfos[t]->listChapters.count() > 0)	{
-	chapterElement = xmlDoc.createElement( SOURCE_OBJECT_CHAPTERS );
-	text = xmlDoc.createTextNode(listFileInfos[t]->listChapters.join(QString(",")));
-	chapterElement.appendChild( text );
-	infoElement.appendChild( chapterElement );
-      }
-      // next to last the TranscodeInterface if any.
-      if (listFileInfos[t]->pTranscodeInterface)	{
-	transcodeElement = xmlDoc.createElement( SOURCE_OBJECT_TRANSCODE );
-	listFileInfos[t]->pTranscodeInterface->writeProjectFile (transcodeElement);
-	infoElement.appendChild( transcodeElement );
-      }
-      // Next to last we add the audio channels.
-      for ( i=0; i<MAX_AUDIO; i++ ) {
-	if ( listFileInfos[t]->arrayAudio[i] )
-	     listFileInfos[t]->arrayAudio[i]->writeProjectFile ( infoElement );
-      }
-      // And finally the Subtitles
-      for ( i=0; i<MAX_SUBTITLES; i++ ) {
-	if ( listFileInfos[t]->arraySubtitles[i] )
-	  listFileInfos[t]->arraySubtitles[i]->writeProjectFile ( infoElement );
-      }
-      sourceNode.appendChild( infoElement );
+    QValueList<SourceFileInfo *>::iterator it = listFileInfos.begin ( );
+    while ( it != listFileInfos.end ( ) )  {
+      pInfo = *it++;
+      pInfo->writeProjectFile ( sourceNode, bAutosave );
     }
   }
-  if (listChapters.count() > 0)	{
-    //printf ("SourceFileEntry::writeProjectFile <%d><%s>\n", listChapters.count (), (const char *)listChapters[0]);
-    chapterElement = xmlDoc.createElement( SOURCE_OBJECT_CHAPTERS );
+
+  if ( listChapters.count ( ) > 0 )  {
+    chapterElement = xmlDoc.createElement ( SOURCE_OBJECT_CHAPTERS );
     sourceNode.appendChild( chapterElement );
-    text = xmlDoc.createTextNode(listChapters.join(QString(",")));
-    chapterElement.appendChild( text );
+    text =  xmlDoc.createTextNode ( listChapters.join ( QString ( "," ) ) );
+    chapterElement.appendChild   ( text );
   }
-  
+
   theElement.appendChild( sourceNode );
   return true;
 }
@@ -775,7 +610,7 @@ SourceFileEntry *SourceFileEntry::flatClone ()
     pClone->arrayAudioEntries[t] = arrayAudioEntries [t];
   for ( int t=0; t<MAX_SUBTITLES; t++ ) 
     pClone->arraySubtitleEntries[t] = arraySubtitleEntries [t];
-  
+
   return pClone;
 }
 
@@ -798,12 +633,12 @@ int SourceFileEntry::audioCount ( bool bMaxCount )
     pInfo = listFileInfos [ t ];
     if ( pInfo ) {
       for ( i=MAX_AUDIO-1; i>=0; i-- ) {
-	if ( pInfo->arrayAudio [ i ] ) {
-	  if ( iMaxInfoAudio < i ) {
-	    iMaxInfoAudio = i;
-	    i=-1;
-	  }
-	}
+        if ( pInfo->arrayAudio [ i ] ) {
+          if ( iMaxInfoAudio < i ) {
+            iMaxInfoAudio = i;
+            i=-1;
+          }
+        }
       }
     }
   }
@@ -831,12 +666,12 @@ int SourceFileEntry::subtitleCount ( bool bMaxCount )
     pInfo = listFileInfos [ t ];
     if ( pInfo ) {
       for ( i=MAX_SUBTITLES-1; i>=0; i-- ) {
-	if ( pInfo->arraySubtitles [ i ] ) {
-	  if ( iMaxInfoSubtitle < i ) {
-	    iMaxInfoSubtitle = i;
-	    i=-1;
-	  }
-	}
+        if ( pInfo->arraySubtitles [ i ] ) {
+          if ( iMaxInfoSubtitle < i ) {
+            iMaxInfoSubtitle = i;
+            i=-1;
+          }
+        }
       }
     }
   }
@@ -883,6 +718,238 @@ SourceFileEntry & SourceFileEntry::operator = (SourceFileEntry &theOther)
 	return *this;
 }
 
+bool SourceFileInfo::readProjectFile ( QDomNode &xmlNode )
+{
+  QDomElement theElement = xmlNode.toElement  ( );
+
+  // Okay, here we read the stored data from the xml file.
+  QString qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_SIZE).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsSize = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_RESOLUTION).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsResolution = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_FPS).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsFPS = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_RATIO).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsRatio = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_LENGTH).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsLength = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_VIDEO_FORMAT).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsVideoFormat = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_VIDEO_CODEC).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsVideoCodec = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUDIO_FORMAT).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsAudioFormat = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUDIO_CODEC).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsAudioCodec  = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_STATUS).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsStatus = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_BITS).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsBits = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_SAMPLE).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsSample = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_BPS).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    qsBPS = qsAttribute;
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_PAUSE).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    iPause = qsAttribute.toInt();
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_TITLESET).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    iTitleset = qsAttribute.toInt();
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_AUTOTRANSCODE).value();
+  bAutotranscode = true;
+  if ( ! qsAttribute.isEmpty ( ) )
+    bAutotranscode = ( qsAttribute == QString ("true") );
+
+  qsAttribute = theElement.attributeNode (SOURCE_OBJECT_METASUBTITLES).value();
+  bMetaSubtitles = true;
+  if ( ! qsAttribute.isEmpty ( ) )
+    bMetaSubtitles = ( qsAttribute == QString ("true") );
+
+  qsAttribute = theElement.attributeNode ( SOURCE_OBJECT_MSEC_OFFSET ).value ( );
+  if ( ! qsAttribute.isEmpty ( ) )
+    iMSecPreview = qsAttribute.toInt ( );
+
+  QDomNode infoNode = theElement.firstChild ( );
+  deleteSubtitles ( );
+  while ( ! infoNode.isNull ( ) )  {
+    QDomElement infoElement = infoNode.toElement( );
+    // Okay, here we read the stored data from the xml file.
+    QString infoName = infoElement.tagName  ( );
+    QString infoText = infoElement.text     ( );
+    if (SOURCE_OBJECT_FILE_NAME == infoName)	{
+      if ( ! infoText.isEmpty ( ) )
+        qsFileName = infoText;
+    }
+    else if ( SOURCE_OBJECT_CHAPTERS == infoName )  {
+      if ( ! infoText.isEmpty ( ) )
+        listChapters = QStringList::split (",", infoText);
+    }
+    else if ( SOURCE_OBJECT_PROPERTIES == infoName )  {
+      qsAttribute = infoElement.attributeNode ( SOURCE_PROPERTIES_POST ).value ( );
+      if ( ! qsAttribute.isEmpty ( ) )
+        qsPostCommand = qsAttribute;
+
+      qsAttribute = infoElement.attributeNode (SOURCE_PROPERTIES_PRE).value();
+      if ( ! qsAttribute.isEmpty ( ) )
+        qsPreCommand = qsAttribute;
+
+      qsAttribute = infoElement.attributeNode (SOURCE_PROPERTIES_PAUSE).value();
+      if ( ! qsAttribute.isEmpty ( ) )
+        iPause = qsAttribute.toInt ( );
+    }
+    else if (SOURCE_OBJECT_TRANSCODE == infoName)	{
+      if ( pTranscodeInterface)
+        delete pTranscodeInterface;
+      pTranscodeInterface = new TranscodeInterface;
+      pTranscodeInterface->readProjectFile (infoNode);
+    }
+    else if ( SLIDESHOW_TAG == infoName )	{
+      if ( pSlideshow )
+        delete pSlideshow;
+      pSlideshow = new CXmlSlideshow;
+      QDomElement theElement = infoNode.toElement ( );
+      pSlideshow->readXml ( &theElement );
+    }
+    else if (SOURCE_OBJECT_SUBTITLES == infoName)	{
+      Subtitles *pSubtitle = new Subtitles;
+      pSubtitle->readProjectFile ( infoNode );
+      addSubtitles   ( pSubtitle );
+    }
+    else if (SOURCE_OBJECT_AUDIO == infoName)	{
+      Audio *pAudio = new Audio;
+      pAudio->readProjectFile ( infoNode );
+      addAudio    ( pAudio   );
+    }
+    infoNode = infoNode.nextSibling ();
+  }
+  return true;
+}
+
+bool SourceFileInfo::writeProjectFile ( QDomElement &sourceNode, bool /* bAutosave */ )
+{
+  uint i;
+  QDomDocument xmlDoc = sourceNode.ownerDocument ( );
+  QDomElement  fileElement, infoElement, chapterElement, propertiesElement;
+  QDomElement  tag,  slideshowElement, transcodeElement, subtitlesElement;
+  QDomText     text;
+  // Here we set the attributes of the <SourceInfo> tag
+
+  infoElement = xmlDoc.createElement( SOURCE_OBJECT_INFO );
+  if ( ! qsSize.isNull ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_SIZE, qsSize );
+  if ( ! qsResolution.isNull ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_RESOLUTION, qsResolution );
+  if ( ! qsFPS.isNull        ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_FPS, qsFPS );
+  if ( ! qsRatio.isNull      ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_RATIO, qsRatio );
+  if ( ! qsLength.isNull     ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_LENGTH, qsLength );
+  if ( ! qsVideoFormat.isNull( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_VIDEO_FORMAT, qsVideoFormat );
+  if ( ! qsVideoCodec.isNull ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_VIDEO_CODEC,  qsVideoCodec  );
+  if ( ! qsAudioFormat.isNull( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_AUDIO_FORMAT, qsAudioFormat );
+  if ( ! qsAudioCodec.isNull ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_AUDIO_CODEC,  qsAudioCodec  );
+  if ( ! qsStatus.isNull     ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_STATUS, qsStatus );
+  if ( ! qsBits.isNull       ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_BITS, qsBits );
+  if ( ! qsSample.isNull     ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_SAMPLE, qsSample );
+  if ( ! qsBPS.isNull        ( ) )
+    infoElement.setAttribute ( SOURCE_OBJECT_BPS, qsBPS );
+  if ( iPause != -1 )
+    infoElement.setAttribute ( SOURCE_OBJECT_PAUSE, QString ("%1").arg(iPause) );
+  if ( iTitleset != -1 )
+    infoElement.setAttribute ( SOURCE_OBJECT_TITLESET, QString ("%1").arg(iTitleset) );
+  if ( bAutotranscode == false )
+    infoElement.setAttribute ( SOURCE_OBJECT_AUTOTRANSCODE, "false" );
+  if ( bMetaSubtitles == false )
+    infoElement.setAttribute ( SOURCE_OBJECT_METASUBTITLES, "false" );
+  if ( iMSecPreview != -1 )
+    infoElement.setAttribute ( SOURCE_OBJECT_MSEC_OFFSET, QString ("%1").arg(iMSecPreview) );
+
+  // Here we create another level in the XML tree for name and chapter ...
+  // First the file name
+  fileElement = xmlDoc.createElement( SOURCE_OBJECT_FILE_NAME );
+  text = xmlDoc.createTextNode ( qsFileName );
+  fileElement.appendChild( text );
+  infoElement.appendChild( fileElement );
+  // Second the properties (Post / Pre, and Pause)
+  propertiesElement = xmlDoc.createElement( SOURCE_OBJECT_PROPERTIES );
+  if (!qsPostCommand.isNull())
+    propertiesElement.setAttribute( SOURCE_PROPERTIES_POST, qsPostCommand );
+  if (!qsPreCommand.isNull())
+    propertiesElement.setAttribute( SOURCE_PROPERTIES_PRE, qsPreCommand );
+  propertiesElement.setAttribute( SOURCE_PROPERTIES_PAUSE, QString ("%1").arg(iPause ));
+  infoElement.appendChild( propertiesElement );
+  // Then chapters if avail.
+  if (listChapters.count() > 0)	{
+    chapterElement = xmlDoc.createElement( SOURCE_OBJECT_CHAPTERS );
+    text = xmlDoc.createTextNode ( listChapters.join(QString(",")));
+    chapterElement.appendChild( text );
+    infoElement.appendChild( chapterElement );
+  }
+  // next to last the TranscodeInterface if any.
+  if (pTranscodeInterface)	{
+    transcodeElement = xmlDoc.createElement( SOURCE_OBJECT_TRANSCODE );
+    pTranscodeInterface->writeProjectFile (transcodeElement);
+    infoElement.appendChild( transcodeElement );
+  }
+  if ( pSlideshow )  {
+    slideshowElement = xmlDoc.createElement (  SLIDESHOW_TAG );
+    pSlideshow->writeXml ( &slideshowElement );
+    infoElement.appendChild ( slideshowElement );
+  }
+
+  // Next to last we add the audio channels.
+  for ( i=0; i<MAX_AUDIO; i++ ) {
+    if ( arrayAudio[i] )
+      arrayAudio[i]->writeProjectFile ( infoElement );
+  }
+  // And finally the Subtitles
+  for ( i=0; i<MAX_SUBTITLES; i++ ) {
+    if ( arraySubtitles[i] )
+      arraySubtitles[i]->writeProjectFile ( infoElement );
+  }
+  sourceNode.appendChild ( infoElement );
+
+  return true;
+}
+
 SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
 {
   int t;
@@ -917,7 +984,7 @@ SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
     delete pTranscodeInterface;
     pTranscodeInterface = NULL;
   }
-  
+
   deleteSubtitles ( );
   for ( t=0; t<MAX_SUBTITLES; t++ ) {
     if ( theOther.arraySubtitles [ t ] ) {
@@ -932,7 +999,7 @@ SourceFileInfo & SourceFileInfo::operator = (SourceFileInfo &theOther)
       *(arrayAudio [ t ]) = *(theOther.arrayAudio [ t ]);
     }
   }
-  
+
   return *this;
 }
 
