@@ -33,9 +33,11 @@
 #include <qfiledialog.h>
 #include <qpushbutton.h>
 #include <qpopupmenu.h>
+#include <qcheckbox.h>
 #include <qlistview.h>
 #include <qdockarea.h>
 #include <qcombobox.h>
+#include <qspinbox.h>
 #include <qlistbox.h>
 #include <qcursor.h>
 #include <qheader.h>
@@ -43,7 +45,6 @@
 #include "win32.h"
 #include "global.h"
 #include "sourcetoolbar.h"
-#include "dialogslide.h"
 #include "qdvdauthor.h"
 #include "listviewmedia.h"
 #include "listviewitemmedia.h"
@@ -54,8 +55,12 @@
 #include "filepreviewdialog.h"
 #include "dialogthumbnail.h"
 #include "dialogfiles.h"
+#include "dialogimages.h"
 #include "smalldialogaudio.h"
+#include "dialogslideshow.h"
+#include "xml_slideshow.h"
 
+#include "render_client.h"
 #include "qplayer/mediainfo.h"
 #include "qplayer/mediacreator.h"
 
@@ -66,7 +71,6 @@ SourceToolBar::SourceToolBar ( const char *pName, QMainWindow *pMainWindow )
   : QDockWindow ( QDockWindow::InDock, pMainWindow, pName )
 {
 	m_pMediaInfo       = NULL;
-	m_pSlideDialog     = NULL;
 	m_pThumbnailDialog = NULL;
 	m_pDVDAuthor       = (QDVDAuthor *)pMainWindow;
 
@@ -118,8 +122,6 @@ SourceToolBar::~SourceToolBar ()
   m_listSourceFileEntries.clear ( );
   if ( m_pMediaInfo )
     delete m_pMediaInfo;
-  if ( m_pSlideDialog )
-    delete m_pSlideDialog;
   if ( m_pThumbnailDialog )
     delete m_pThumbnailDialog;
 }
@@ -179,6 +181,51 @@ SourceFileEntry *SourceToolBar::sourceFileEntry(uint iEntryNumber)
 	return m_listSourceFileEntries[iEntryNumber];
 }
 
+SourceFileEntry *SourceToolBar::sourceFileEntry ( CXmlSlideshow *pSlideshow )
+{
+  return (SourceFileEntry *)pSlideshow->id;
+if ( 0 )  {
+// Version 1 ... Make sure the Entry still exists
+  SourceFileEntry *pEntry = NULL;
+  QValueList<SourceFileEntry *>::iterator it = m_listSourceFileEntries.begin ( );
+  while ( it != m_listSourceFileEntries.end ( ) )  {
+    pEntry = *it++;
+    if ( pEntry->listFileInfos.count ( ) != 1 )
+      continue;
+    if ( pSlideshow->id == pEntry )
+      return pEntry;
+  }
+  return NULL;
+}
+if ( 0 )  {
+// Version 2 Check that the slideshow pointer is the same
+  SourceFileEntry *pEntry = NULL;
+  SourceFileInfo  *pInfo  = NULL;
+  QValueList<SourceFileEntry *>::iterator it = m_listSourceFileEntries.begin ( );
+  while ( it != m_listSourceFileEntries.end ( ) )  {
+    pEntry = *it++;
+    if ( pEntry->listFileInfos.count ( ) != 1 )
+      continue;
+    pInfo = pEntry->listFileInfos[0];
+    if ( ! pInfo->pSlideshow )
+      continue;
+    if ( pInfo->pSlideshow == pSlideshow )
+      return pEntry;
+  }
+  return NULL;
+}
+}
+
+bool SourceToolBar::sourceFileEntryExists ( SourceFileEntry *pEntry )
+{
+  QValueList<SourceFileEntry *>::iterator it = m_listSourceFileEntries.begin ( );
+  while ( it != m_listSourceFileEntries.end ( ) )  {
+    if ( pEntry == *it++ )
+      return true;
+  }
+  return false;
+}
+
 SourceFileEntry *SourceToolBar::getCurrentSourceFileEntry ()
 {
 	SourceFileEntry *pSourceFileEntry = NULL;
@@ -254,7 +301,7 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
   // Here we pop open the properties dialog for the movie, where you can set
   // o size of movie (resizing tool used = ???
   // o Define Title # / Add Chapters to Title
-  
+
   // Here we find out if we can actually play the file ... Meaning slideshows can not be played !!!
   uint t;
   bool bShow = true;
@@ -272,17 +319,21 @@ void SourceToolBar::slotRightClickedOnVideoList (QListViewItem *pItem, const QPo
   SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
   if ( pEntry ) {
     if ( pEntry->bSoundSource ) {
-      pMenu->insertItem ( tr ("Proprties ..."),        this, SLOT(slotEditAudio     ( ) ) );
+      pMenu->insertItem ( tr ("Proprties ..."),        this, SLOT ( slotEditAudio     ( ) ) );
     }
     else {
+      SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
       // Not a sound source
       if (bShow)
-	pMenu->insertItem ( tr ("&Play"),               this, SLOT(slotPlayMovie     ( ) ) );
-      pMenu->insertItem   ( tr ("P&roperties ..."),     this, SLOT(slotEditMovie     ( ) ) );
+	pMenu->insertItem ( tr ("&Play"),               this, SLOT ( slotPlayMovie     ( ) ) );
+
+      if ( pInfo->pSlideshow ) // If the movie was created through a slideshow ...
+        pMenu->insertItem ( tr ( "&Slideshow" ),        this, SLOT ( slotEditSlideshow ( ) ) );
+      pMenu->insertItem   ( tr ("P&roperties ..."),     this, SLOT ( slotEditMovie     ( ) ) );
       if ( pSourceFileEntry && (pSourceFileEntry->listFileInfos.count() > 1) ) {
-	pMenu->insertItem ( tr ("&Transcode All ..."),  this, SLOT(slotTranscodeAll  ( ) ) );
-	pMenu->insertItem ( tr ("&Disable Transcode" ), this, SLOT(slotTranscodeNone ( ) ) );
-	pMenu->insertItem ( tr ("&All to titleset ..."),this, SLOT(slotAllToTitleset ( ) ) );
+	pMenu->insertItem ( tr ("&Transcode All ..."),  this, SLOT ( slotTranscodeAll  ( ) ) );
+	pMenu->insertItem ( tr ("&Disable Transcode" ), this, SLOT ( slotTranscodeNone ( ) ) );
+	pMenu->insertItem ( tr ("&All to titleset ..."),this, SLOT ( slotAllToTitleset ( ) ) );
       }
       else if ( !pSourceFileEntry ) { // Here we handle if the user clicked on a SourceFileInfo
 	SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
@@ -339,7 +390,7 @@ void SourceToolBar::slotThumbnailing ( )
   SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
   if ( ! pInfo )
     return;
-  
+
   fileInfo.setFile ( pInfo->qsFileName );
   qsFileName = fileInfo.fileName ( );
   qsAction   = QString ( "jump" ) + QString ( STRING_SEPARATOR );
@@ -352,7 +403,7 @@ void SourceToolBar::slotThumbnailing ( )
     m_pThumbnailDialog = new DialogThumbnail ( m_pDVDAuthor );
 
   m_pThumbnailDialog->initSourceFileInfo ( pInfo, qsAction );
-  
+
   if ( ! m_pThumbnailDialog->isVisible ( ) )
          m_pThumbnailDialog->show ( );
 }
@@ -376,7 +427,7 @@ void SourceToolBar::slotTranscodeAll()
       break;
     }
   }
-  
+
   if ( ! pSourceFileEntry )
     return; // Could not find the currently selected SourceFileEntry
   // Okay we only want to convert if the FileInfos have the same transcoding information (Either none, or all values the same.
@@ -417,7 +468,7 @@ void SourceToolBar::slotTranscodeAll()
   theDialog.initMe (pSourceFileEntry);
   if (theDialog.exec () == QDialog::Rejected)
     return;
-  
+
   // Check if there was a transcodeInterface created by the dialog.
   if (theDialog.sourceFileInfo()->pTranscodeInterface)	{
     for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
@@ -550,6 +601,7 @@ void SourceToolBar::slotAllToTitleset ( )
 void SourceToolBar::slotAddMovie ( )
 {
   Input::DialogFiles fileDialog ( this );
+  fileDialog.initMe     ( );
   if ( fileDialog.exec  ( ) == QDialog::Rejected )
     return;
 
@@ -563,7 +615,7 @@ void SourceToolBar::slotAddMovie ( )
   // First we remove all 'old' SourceFileEntry objects
   for ( t=0; t<m_listSourceFileEntries.count ( ); t++ ) {
     if ( ! m_listSourceFileEntries[t]->bSoundSource )
-      tempList.append ( m_listSourceFileEntries[t] );
+      tempList.append  ( m_listSourceFileEntries[t] );
   }
   for ( t=0; t<tempList.count ( ); t++ ) 
     removeEntry ( tempList[t], true );
@@ -580,8 +632,8 @@ void SourceToolBar::slotAddMovie ( )
 	// Add the please - wait image
 	pInfo->pPreview  = new QImage ( QImage ( ).fromMimeSource ( "please_wait.jpg" ) );
 	// and the request the preview from a background thread.
-	MediaCreator::registerWithMediaScanner ( this, pInfo, pInfo->iMSecPreview, true );
 	*pInfo->pPreview = pInfo->pPreview->smoothScale ( Global::pApp->getDragNDropContainer ( )->sizeButton, QImage::ScaleMin );
+	MediaCreator::registerWithMediaScanner ( this, pInfo, pInfo->iMSecPreview, true );
       }
       else if ( pInfo->qsStatus !=  QString ( "Ok" ) )
 	statusColor = QColor ( COLOR_MOVIE_FILES_BAD );
@@ -617,7 +669,7 @@ void SourceToolBar::slotAddMovieOld ( )
   // are not flexible enough to handle this (yet).
   if (listAddMovies.count() < 1)
     return;
-  
+
   // Here we will check to see if the user selected audio files ...
   for ( t=0; t<(int)listAddMovies.count ( ); t++ ) {
     qsFileName = listAddMovies[t];
@@ -651,10 +703,10 @@ void SourceToolBar::addMovieList (QStringList &listAddMovies, QString *pTitle)
   SourceFileInfo *pInfo;
   for (t=0;t<listAddMovies.count();t++)	{
     pInfo = new SourceFileInfo;
-    pInfo->qsFileName   = listAddMovies[t];
+    pInfo->qsFileName = listAddMovies[t];
     // Here we generate a dummy image as a place holder
-    pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
-    *pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+    pInfo->pPreview   = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
+    *pInfo->pPreview  = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
     // and then register to obtain the info in the background.
     MediaCreator::registerWithMediaScanner ( this, pInfo, 0L, true );
     // register again if we need to extract Subtitles from MetaInfo
@@ -762,7 +814,7 @@ bool SourceToolBar::checkRightFileFormat ( SourceFileInfo *pInfo )
     pTranscode->fFrameRate  = 25.0;
     pTranscode->qsResolution= "720x576"; 
   }
-    
+
   pTranscode->qsVideoFormat = qsFormat;
   pTranscode->qsVideoType   = "mpeg2";
   pTranscode->iVideoBitrate = 6600000;
@@ -781,7 +833,7 @@ void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
   uint t, i;
   SourceFileEntry *pEntry = NULL;
   SourceFileInfo  *pInfo  = NULL;
-  
+
   switch ( pTimerEvent->timerId() )	{
   case MEDIASCANNER_EVENT + 1: //  ExecuteJob::TYPE_INFO:
     m_mutexThumbnails.lock ();
@@ -804,23 +856,23 @@ void SourceToolBar::timerEvent(QTimerEvent *pTimerEvent)
 	    pChild = (ListViewItemMedia *)pChild->nextSibling();
 	  }
 	  // Oh and the ListViewVideoSources should also be updated ...
-	  QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ();
-	  while (pItem)	{
-	    if (pItem->text (MOVIE_FILE_NAME_INDEX) == pInfo->qsFileName)	{
-	      pItem->setText (0, pInfo->qsVideoFormat);
-	      pItem->setText (1, pInfo->qsResolution);
-	      pItem->setText (2, pInfo->qsLength);
-	      pItem->setText (3, pInfo->qsSize);
-	      pItem->setText (4, pInfo->qsRatio);
-	      pItem->setText (5, pInfo->qsFPS);
-	      pItem->setText (6, pInfo->qsStatus);
+	  QListViewItem *pItem = m_pSourceWidget->m_pListViewVideoSources->firstChild ( );
+	  while ( pItem )  {
+	    if  ( pItem->text (MOVIE_FILE_NAME_INDEX) == pInfo->qsFileName )  {
+	      pItem->setText ( 0, pInfo->qsVideoFormat );
+	      pItem->setText ( 1, pInfo->qsResolution  );
+	      pItem->setText ( 2, pInfo->qsLength      );
+	      pItem->setText ( 3, pInfo->qsSize        );
+	      pItem->setText ( 4, pInfo->qsRatio       );
+	      pItem->setText ( 5, pInfo->qsFPS         );
+	      pItem->setText ( 6, pInfo->qsStatus      );
 	    }
-	    pItem = pItem->nextSibling();
+	    pItem = pItem->nextSibling ( );
 	  }
 	  pInfo->bUpdateInfo = false;
 	  m_pDVDAuthor->slotCalculateSize ( );
 	  updateEntryHeader ( pEntry );
-	  m_mutexThumbnails.unlock ();
+	  m_mutexThumbnails.unlock ( );
 	  // Finally once we have the required info, we can go ahead and create subtitles if needs be
 	  Subtitles::generateSubtitles ( this, pInfo, Global::qsLanguage );
 	  return;
@@ -947,14 +999,14 @@ void SourceToolBar::addMovie (SourceFileEntry *pEntry)
 {
   uint t;
   QColor statusColor (COLOR_MOVIE_FILES_OK);
-  
+
   SourceFileInfo *pInfo;
   for (t=0;t<pEntry->listFileInfos.count();t++)	{
     pInfo  = pEntry->listFileInfos[t];
     // Here we check that ALL sources are ok
     if (pInfo->qsStatus != QString ("Ok"))
       statusColor = QColor(COLOR_MOVIE_FILES_BAD);
-    
+
     new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
 		       pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
 		       pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
@@ -965,30 +1017,46 @@ void SourceToolBar::addMovie (SourceFileEntry *pEntry)
 void SourceToolBar::appendSourceFileEntry ( SourceFileEntry *pEntry, bool bUpdateAllInfo )
 {
   // This function is called when loading from an XML-project file ???
-  m_listSourceFileEntries.append(pEntry);
+  m_listSourceFileEntries.append ( pEntry );
   QColor statusColor (COLOR_MOVIE_FILES_BAD);
   // Here we set the preview size ...
+  SourceFileInfo *pInfo;
   pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
-  if (!pEntry->bSoundSource)	{	// Here we handle a Movie SourceFileEntry ...
-    for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
-      SourceFileInfo *pInfo = pEntry->listFileInfos[t];
-      // Add the plaeas - wait image
-      pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
-      // and the request the preview from a background thread.
-      MediaCreator::registerWithMediaScanner (this, pInfo, pInfo->iMSecPreview, bUpdateAllInfo );
-      *pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
-      // And show what we have thus far.
-      new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat, pInfo->qsResolution, pInfo->qsLength,  pInfo->qsSize, pInfo->qsRatio, pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+  if ( ! pEntry->bSoundSource )  {  // Here we handle a Movie SourceFileEntry ...
+    if ( pEntry->bIsSlideshow )  {
+      // Here we handle slideshow entries ( vide does not yet exist.
+      pInfo = pEntry->listFileInfos[0];
+      if ( pInfo && ( ! pInfo->pPreview ) )  {
+        QImage     theImage;
+        theImage =  QImage::fromMimeSource ( "create_slideshow.jpg" );
+        theImage = theImage.smoothScale ( Global::pApp->getDragNDropContainer ( )->sizeButton, QImage::ScaleMin );
+        pInfo->pPreview   = new QImage ( theImage );
+      }
+      // Okay, now we should also add this into the list box ...
+      statusColor = QColor ( COLOR_SLIDE_FILES_OK );
+    }
+    else  {
+      for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
+        pInfo = pEntry->listFileInfos[t];
+        // Add the plaeas - wait image
+        pInfo->pPreview = new QImage (QImage().fromMimeSource( "please_wait.jpg" ));
+        // and the request the preview from a background thread.
+        bool bNeedUpdate = ( pInfo->qsStatus != QString ( "Ok" ) );
+        MediaCreator::registerWithMediaScanner ( this, pInfo, pInfo->iMSecPreview, bUpdateAllInfo || bNeedUpdate );
+        *pInfo->pPreview = pInfo->pPreview->smoothScale ( m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
+        // And show what we have thus far.
+        new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat, pInfo->qsResolution, pInfo->qsLength,  pInfo->qsSize, pInfo->qsRatio, pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
+      }
     }
   }
-  else	{	// And here we have a Sound SourceFileEntry
+  else	{  // And here we have a Sound SourceFileEntry
     statusColor = QColor (COLOR_SOUND_FILES_OK);
-    
+
     for (uint t=0;t<pEntry->listFileInfos.count();t++)	{
       SourceFileInfo *pInfo = pEntry->listFileInfos[t];
       if (pInfo->qsStatus != QString ("Ok"))
 	statusColor = QColor (COLOR_SOUND_FILES_BAD);
-      
+
        pInfo->pPreview = new QImage (QImage().fromMimeSource( "sound_file.jpg" ));
       *pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
       new QListViewItem (m_pSourceWidget->m_pListViewAudioSources, pInfo->qsAudioFormat, pInfo->qsLength, pInfo->qsBits, pInfo->qsSample, pInfo->qsBPS, pInfo->qsSize, pInfo->qsStatus, pInfo->qsFileName);
@@ -1006,6 +1074,32 @@ void SourceToolBar::slotRemoveEntry(SourceFileEntry *pEntry)
     m_pDVDAuthor->removedSourceEntry( pEntry );
 }
 
+bool SourceToolBar::setRenderProgress ( SourceFileEntry *pEntry, float fProgress )
+{
+  // fProgress == -1.0 == reset
+  ListViewItemMedia *pItem = getItem ( pEntry );
+  if ( ! pItem )
+    return false;
+
+  pItem->setProgress ( fProgress );
+
+  return true;
+}
+
+ListViewItemMedia *SourceToolBar::getItem ( SourceFileEntry *pEntry )
+{
+  ListViewItemMedia *pItem;
+  // Okay found the SourceFileInfo now we need the ListViewItemMedia - object for this Info.
+  pItem = (ListViewItemMedia *)m_pListViewAllSources->firstChild ( );
+  while ( pItem )  {
+    if  ( pItem->sourceFileEntry ( ) == pEntry )
+      return pItem;
+    pItem = (ListViewItemMedia *)pItem->nextSibling ( );
+  }
+
+  return NULL;
+}
+
 void SourceToolBar::slotAddSound ( )
 {
   // never used, the real function comes from ...
@@ -1032,7 +1126,7 @@ void SourceToolBar::slotAddSound ( )
       listAddAudio .remove  ( qsFileName  );
     }
   }
-  
+
   // Okay, now we should also add this into the list box ...
   addSound     ( listAddAudio  );
   addMovieList ( listAddMovies );
@@ -1044,7 +1138,6 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
     return;
 	uint t;
 	QFileInfo fileInfo ( listSoundNames[0] );
-	//	QString qsFileName = fileInfo.fileName();
 
 	// And here we set the  current Directory for the application ...
 	QString qsPath = fileInfo.filePath ( );
@@ -1105,20 +1198,134 @@ void SourceToolBar::addSound (QStringList &listSoundNames)
 	delete pMediaInfo;
 }
 
-void SourceToolBar::slotAddSlideshow()
+void SourceToolBar::slotAddSlideshow ( )
 {
   Utils theUtil;
   if ( ! Global::pApp->checkForNewProject ( ) )
     return;
+
   // First we pop up the slideshow generation dialog box
-  QString qsTempPath = theUtil.getTempFile(QString ());
-  if ( ! m_pSlideDialog )  {
-    m_pSlideDialog = new CSlideDialog;
-    m_pSlideDialog->initMe(this, qsTempPath);
+  Input::DialogImages fileDialog ( this );
+  fileDialog.initMe    ( );
+  if ( fileDialog.exec ( ) == QDialog::Rejected )
+    return;
+
+  CXmlSlideshow             *pXmlSlideshow;
+  SourceFileEntry *pEntry;
+  SourceFileInfo  *pInfo;
+  QValueList<CXmlSlideshow *>newList = fileDialog.getSlideshows ( );
+  QValueList<CXmlSlideshow *>::iterator it = newList.begin ( );
+
+  while ( it != newList.end  ( ) )  {
+    pXmlSlideshow = *it++;
+    pEntry = sourceFileEntry ( pXmlSlideshow );
+    pInfo  = pEntry ? pEntry->listFileInfos[0] : NULL;
+    if ( pXmlSlideshow->countImg ( ) < 1 )  {
+      // No more images in the slideshow
+//      delete pXmlSlideshow; done in desstructor of GroupView
+      if ( pEntry && pInfo )  {
+           if ( pInfo->pSlideshow )
+                delete pInfo->pSlideshow;
+           pInfo->pSlideshow    = NULL;
+           pEntry->bIsSlideshow = false;
+      }
+      // Also if the slideshow has not finished rendering, Then get rid of the Entry all together
+      if ( pEntry && pEntry->bIsSlideshow )  {
+           removeEntry ( pEntry, false );
+           delete pEntry;
+      }
+      continue;
+    }
+
+    // Re-render the slideshow if different
+    if ( pEntry && pInfo )  {
+      CXmlSlideshow *pSlideshow = pInfo->pSlideshow;
+      if ( ! ( *pSlideshow == *pXmlSlideshow ) )  {
+         Render::Manager::unregisterEntry  (  pEntry );
+         pEntry->bIsSlideshow = true;
+
+        *pSlideshow = *pXmlSlideshow;
+
+         Render::Manager::registerEntry    (  pEntry );
+      }
+      continue;
+    }
+    entryFromSlideshow ( pXmlSlideshow );
   }
-  m_pSlideDialog->show();
-  // Note that the SourceFileEntry is generated  when we have given a name to the
-  // newly generated slideshow. This is then done SourceToolBar::slotAddSlideshow(QString);
+}
+
+SourceFileEntry *SourceToolBar::entryFromSlideshow ( CXmlSlideshow *pXmlSlideshow )
+{
+  Utils theUtils;
+  CXmlSlideshow::img_struct *pXmlImage;
+  SourceFileEntry *pEntry;
+  SourceFileInfo  *pInfo;
+
+  pXmlImage = pXmlSlideshow->getImg ( 0 );
+
+  pEntry = new SourceFileEntry;
+  pEntry->qsDisplayName.sprintf ( "[%02d] - %s", getFreeSourceSlot ( ), pXmlSlideshow->slideshow_name.ascii ( ) );
+  pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
+  pEntry->bIsSlideshow  = true;
+  // Next we create the Info. Note, only one info per entry ( only one Slideshow )
+  QImage     theImage;
+  theImage = QImage::fromMimeSource ( "create_slideshow.jpg" );
+  theImage = theImage.smoothScale   ( Global::pApp->getDragNDropContainer ( )->sizeButton, QImage::ScaleMin );
+
+  bool bPAL = ( pXmlSlideshow->yres == 576 );
+  pInfo = new SourceFileInfo;
+  pInfo->qsFileName    = theUtils.getTempFile ( pXmlSlideshow->slideshow_name + ".vob" );
+  pInfo->pSlideshow    = new CXmlSlideshow;
+ *pInfo->pSlideshow    = *pXmlSlideshow;
+
+  pInfo->qsVideoFormat = bPAL ? "PAL" : "NTSC";
+  pInfo->qsFPS         = bPAL ?  "25" : "29.97";
+  pInfo->qsResolution  = QString ( "%1x%2" ).arg ( pXmlSlideshow->xres ).arg ( pXmlSlideshow->yres );
+  pInfo->qsLength      = theUtils.getStringFromMs ( 1000 * ( pXmlSlideshow->countImg ( ) * pXmlSlideshow->filter_delay + (pXmlSlideshow->countImg ( )+1) * pXmlSlideshow->delay ) );
+  pInfo->qsRatio       = "4:3";
+
+  pInfo->pPreview   = new QImage ( theImage );
+  pEntry->listFileInfos.append   (   pInfo  );
+  m_listSourceFileEntries.append (  pEntry  );
+
+  // Okay, now we should also add this into the list box ...
+  new ListViewItemMedia ( m_pListViewAllSources, pEntry, QColor ( COLOR_SLIDE_FILES_OK ) );
+
+  // And finally we should register the slideshow for rendering in the background.
+  Render::Manager::registerEntry ( pEntry );
+  setRenderProgress ( pEntry, 0.0f );
+  return pEntry;
+}
+
+void SourceToolBar::slideshowDone ( SourceFileEntry *pEntry )
+{
+  if ( ! pEntry )
+    return;
+
+  ListViewItemMedia *pItem = getItem ( pEntry );
+  if ( ! pItem )
+    return;
+
+  if ( pEntry->listFileInfos.count ( ) < 1 )
+    return;
+
+  SourceFileInfo *pInfo = pEntry->listFileInfos[0];
+  // First we determine the fileName of the generated mpeg video ...
+  pEntry->bIsSlideshow = false;	// now we hold a mpeg and not a xml - file ...
+  pEntry->bSoundSource = false;
+
+  delete pItem;
+  new ListViewItemMedia ( m_pListViewAllSources, pEntry, QColor ( COLOR_MOVIE_FILES_OK ) );
+  long iOffset = 0;
+  if ( pInfo->pSlideshow ) // get us smack in the middle of the first image
+       iOffset = 1000 * (long)(1.5*pInfo->pSlideshow->delay) + pInfo->pSlideshow->filter_delay;
+  pInfo->iMSecPreview = iOffset;
+  new QListViewItem ( m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
+        pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
+        pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName );
+  MediaCreator::registerWithMediaScanner ( this, pInfo, iOffset, true );
+
+  Global::pApp->slotAutosave ( );
 }
 
 void SourceToolBar::slotEditMovie ( )
@@ -1156,6 +1363,24 @@ void SourceToolBar::editSourceFileInfo ( SourceFileInfo  *pSourceFileInfo )
   delete pDialog;
 }
 
+void SourceToolBar::slotEditSlideshow ( )
+{
+  SourceFileInfo *pInfo = getCurrentSourceFileInfo ( );
+  CXmlSlideshow *pSlideshow = pInfo->pSlideshow;
+
+  Input::DialogSlideshow theDialog ( this );
+  theDialog.initMe ( pSlideshow, false );
+
+  if ( theDialog.exec ( ) == QDialog::Accepted )  {
+    pSlideshow->slideshow_name = theDialog.m_pEditName->text  ( );
+    pSlideshow->background     = theDialog.background ( );
+    pSlideshow->audio_list     = theDialog.audioList  ( );
+    pSlideshow->delay          = theDialog.m_pSpinImageDelay->value    ( );
+    pSlideshow->filter_delay   = theDialog.m_pSpinFilterDelay->value   ( );
+    pSlideshow->intro_page     = theDialog.m_pCheckIntroPage->isChecked( );
+  }
+}
+
 void SourceToolBar::slotEditAudio ( )
 {
   SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
@@ -1217,7 +1442,7 @@ void SourceToolBar::refreshToolBarEntries()
 	// Here we check that ALL sources are ok
 	if (pInfo->qsStatus != QString ("Ok"))
 	  statusColor = QColor(COLOR_MOVIE_FILES_BAD);
-	  
+
 	  new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
 			     pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
 			     pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
@@ -1313,12 +1538,15 @@ void SourceToolBar::removeEntry (SourceFileEntry *pSourceFileEntry, bool bSource
 	// This function is also called from UndoObjects.
 	uint t;
 	QStringList listFileNames;
-	if (!pSourceFileEntry)
+	if ( ! pSourceFileEntry )
 		return;
 	m_listSourceFileEntries.remove (pSourceFileEntry);
 
+	if ( pSourceFileEntry->bIsSlideshow )
+		Render::Manager::unregisterEntry ( pSourceFileEntry );
+
 	// The first thing we should ensure is that we are not registered with the MediaScanner, which could crash QDVDAuthor
-	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)
+	for ( t=0; t<pSourceFileEntry->listFileInfos.count ( ); t++ )
 	  MediaCreator::unregisterFromMediaScanner ( pSourceFileEntry->listFileInfos[t] );
 
 	// Next we remove the entry from the AllSources - Tab
@@ -1375,7 +1603,7 @@ void SourceToolBar::removeEntry (SourceFileEntry *pSourceFileEntry, bool bSource
 	// If we should only remove the entry in the SoureToolBar and leave the ones in QDVDAuthor as is
 	// This is the case when we create a new entry. The first thing done is to remove all
 	// double entries but we want to leave the entries in the Menus intact.
-    if ( ! m_pDVDAuthor )
+	if ( ! m_pDVDAuthor )
 		return;
 
 	if ( ! bSourceOnly )
@@ -1415,81 +1643,6 @@ void SourceToolBar::slotPlayMovie()
 		return;
 }
 
-// the following two functions are called from CSlideDialog, if avail ...
-void SourceToolBar::slotAddSlideshow (QString qsSlideshowName)
-{
-	if ( ! m_pDVDAuthor->checkForNewProject () )
-		return;
-
-	// Lets create a new SourceFileEntry ...
-	SourceFileEntry *pEntry = new SourceFileEntry;
-	SourceFileInfo  *pInfo  = new SourceFileInfo;
-	// Here we create the temp image
-	pEntry->sizeThumbnail = m_pDVDAuthor->getDragNDropContainer()->sizeThumbnail;
-	pInfo->pPreview  = new QImage (QImage().fromMimeSource( "create_slideshow.jpg" ));
-	*pInfo->pPreview = pInfo->pPreview->smoothScale (m_pDVDAuthor->getDragNDropContainer()->sizeButton, QImage::ScaleMin);
-
-	pEntry->bIsSlideshow = true;
-	pInfo->qsFileName    = qsSlideshowName;
-	pEntry->listFileInfos.append(pInfo);
-	pEntry->qsDisplayName.sprintf ("[%02d] - %s", getFreeSourceSlot (), (const char *)qsSlideshowName);
-	m_listSourceFileEntries.append(pEntry);
-	// Okay, now we should also add this into the list box ...
-	new ListViewItemMedia (m_pListViewAllSources, pEntry, QColor (COLOR_SLIDE_FILES_OK));
-}
-
-void SourceToolBar::slotSlideshowDone(QString qsSlideshowName, QString qsFileName)
-{
-	Utils theUtil;
-	uint t;
-	int iListBoxPosition = -1;
-	SourceFileEntry *pEntry;
-	QString qsItemText;
-	QFileInfo fileInfo;
-	QListViewItem *pItem, *pParentItem = m_pListViewAllSources->firstChild();
-	for (t=0;t <(uint)m_pListViewAllSources->childCount();t++)	{
-		if ( ! pParentItem )
-			continue;
-		pItem = pParentItem->firstChild ();
-		if ( ! pItem )
-			continue;
-		qsItemText = pItem->text(SOURCE_FILE_ENTRY_NAME);
-		qsItemText.remove ("\n");
-		if (qsItemText == qsSlideshowName)	{
-			iListBoxPosition = t;
-			break;
-		}
-		pParentItem = pParentItem->nextSibling();
-	}
-	// Error ...
-	if ( ! pParentItem )
-		return;
-	
-	for (t=0;t<m_listSourceFileEntries.count();t++)	{
-		pEntry = m_listSourceFileEntries[t];
-		if (pEntry->qsDisplayName.find(qsSlideshowName) != -1)	{
-			// First we determine the fileName of the generated mpeg video ...
-			QFileInfo fileInfo (pEntry->listFileInfos[0]->qsFileName);
-			pEntry->listFileInfos[0]->qsFileName = qsFileName; //theUtil.getTempFile(fileInfo.fileName()+QString (".mpeg"));
-			pEntry->bIsSlideshow = false;	// now we hold a mpeg and not a xml - file ...
-			pEntry->bSoundSource = false;
-
-			delete pParentItem;
-			new ListViewItemMedia (m_pListViewAllSources, pEntry,QColor (COLOR_MOVIE_FILES_OK));
-			SourceFileInfo *pInfo = pEntry->listFileInfos[0];
-			fileInfo.setFile ( qsFileName );
-			qsFileName = QString ("%1/%2.xml").arg(fileInfo.dirPath( TRUE )).arg(fileInfo.baseName ());
-			importChapters ( qsFileName, pInfo );
-			new QListViewItem (m_pSourceWidget->m_pListViewVideoSources, pInfo->qsVideoFormat,
-				pInfo->qsResolution, pInfo->qsLength, pInfo->qsSize, pInfo->qsRatio,
-				pInfo->qsFPS, pInfo->qsStatus, pInfo->qsFileName);
-			MediaCreator::registerWithMediaScanner (this, pInfo);
-			return;
-		}
-	}
-	m_pDVDAuthor->slotAutosave ();
-}
-
 /* Old function. Should be replaced with Import::Chapters ) */
 void SourceToolBar::importChapters( QString qsChaptersFileName, SourceFileInfo *pInfo )
 {
