@@ -281,7 +281,7 @@ bool Subtitles::writeProjectFile ( QDomElement &inElement )
 
       text = xmlDoc.createTextNode( pEntry->qsText );
       infoElement.appendChild( text );
-      
+
       theElement.appendChild ( infoElement );
     }
   }
@@ -338,7 +338,7 @@ QRect Subtitles::getSubtitlesRect ( QString &qsResolution )
        iVideoWidth  = 720;
   if ( iVideoHeight < 240 ) // out of spec ?
        iVideoHeight = 480;
-  
+
   theRect = m_rect;
   // Try to figure out if the user was too lazy to input values ...
   if ( ( m_rect.x() == 0 ) && ( m_rect.y() == 0 ) ) {
@@ -367,7 +367,7 @@ bool Subtitles::alreadyRendered ( QString qsBasePath )
 
   qsSubIdx.sprintf ( "/sub%02d_", m_iSubtitleNumber );
   qsThePath = qsBasePath + qsSubIdx;
-  
+
   iTotalCount = (int)m_listOfSubtitles.count ( );
     for (t=0;t<iTotalCount; t++) {
     pEntry  = m_listOfSubtitles[t];
@@ -418,10 +418,10 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   Subtitles::entry *pEntry;
   qsLang = theUtils.iso639  ( m_qsIso639, false );
   progressDialog.setCaption ( QObject::tr ( "Creating %1 Subtitles for %2" ).arg ( qsLang ).arg ( fileInfo.fileName ( ) ) );
-  
+
   qsSubIdx.sprintf ( "/sub%02d_", m_iSubtitleNumber );
   qsThePath = qsBasePath + qsSubIdx;
-  
+
   // get the rect of the video ...
   iWidth  = theUtils.getWHFromResolution ( qsResolution, true  );
   iHeight = theUtils.getWHFromResolution ( qsResolution, false );
@@ -432,8 +432,12 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
   // get the rect for the subtitles. Try to be clever about it.
   theRect = getSubtitlesRect ( qsResolution );
-  m_rect  = theRect;
-  
+  // If we have user input we should abide by it
+  if ( ( m_rect.x ( ) == 0 ) && ( m_rect.y ( ) == 0 ) )
+    m_rect  = theRect;
+  else
+    theRect = m_rect;
+
   // Now we do some magic with colors ...
   // we will set the Background Color to be completely GREEN
   // and we set the foreground color to be completely RED
@@ -445,7 +449,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   //       color[2 .. MAX_SUBTITLE_COLORS] = fading foreground to background with delta transparency
   colors[0] = 0x0000FF00; // background
   colors[1] = 0x00FF0000; // foreground
-  
+
   int   iMaxColors = MAX_SUBTITLE_COLORS - 2;
   float fDelta   = (float)0xFF / (iMaxColors+1);
   int   iBGRed, iBGGreen, iBGBlue, iRed, iGreen, iBlue, iTransparency;
@@ -454,11 +458,11 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     iRed    = 255 - iGreen;
     colors[t+2] = ( iRed << 16 ) + ( iGreen << 8 );
   }
-  
+
   QRect boundingRect;
   QPen  thePen ( colors[1], 2, Qt::DashDotLine );
   int   iFlags = Qt::DontClip|Qt::WordBreak|Qt::AlignHCenter|Qt::AlignVCenter;
-  
+
   iTotalCount = (int)m_listOfSubtitles.count ();
   // Processing some Qt events / messages
   qApp->processEvents ( 100 ); // do some event processing ...
@@ -480,14 +484,14 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     // Then we reduce the colors to the max avail color space.
     theUtils.reduceColors ( theBrush, 2, (QRgb *)&colors );
   }
-  
+
   for (t=0;t<iTotalCount; t++) {
     pEntry  = m_listOfSubtitles[t];
     qsStart = pEntry->qsTimeStart;
     qsStart.remove ( ":"      );
     qsStart.replace( ".", "_" );
     qsFileName = QString ("%1%2.png").arg ( qsThePath ).arg( qsStart );
-    
+
     // First we should fill the drawing board with the propper background  color.
     QPixmap theDrawingBoard ( iWidth, iHeight );
     thePainter.begin ( &theDrawingBoard  ); {
@@ -495,10 +499,10 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
       thePainter.setPen   ( thePen );
       thePainter.setBrush ( QBrush ( colors[0] ) );
       thePainter.setFont  ( m_font );
-      
+
       // Here we draw onto the drawing board
       thePainter.drawText ( theRect, iFlags, pEntry->qsText, -1, &boundingRect );
-      
+
       int x, y, w, h, d;
       d = boundingRect.height ( ) - theRect.height ( );
       x = theRect.x ( ); // should be 0
@@ -536,17 +540,17 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
     }  thePainter.end ();
     // Enable transparency ...
     theImage.setAlphaBuffer ( true );
-    
+
     // Then we reduce the colors to the max avail color space.
     theUtils.reduceColors ( theImage, MAX_SUBTITLE_COLORS, (QRgb *)&colors );
-    
+
     // next we generate the backround color ...
     theColor = m_subColors[0].rgb ( ) & 0x00FFFFFF;
     iBGRed   = qRed   ( theColor );
     iBGGreen = qGreen ( theColor );
     iBGBlue  = qBlue  ( theColor );
     theImage.setColor ( 0, m_subColors[0].rgb ( ) );
-    
+
     // and then the rest of the colors
     theColor = m_subColors[1].rgb ( ) & 0x00FFFFFF;
     iRed     = qRed   ( theColor );
@@ -559,7 +563,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
       // which must be added to the multiplied by the user defined transparency
       fDelta = (float)(255 - m_subColors[j].alpha ( ) ) / 0xFF;
       iTransparency = (int)( fDelta * (255-iTransparency ) ) + iTransparency;
-      
+
       iDelta = ( (colors[j] & 0xFF0000 ) >> 16 );
       fDelta = (float)(0xFF - iDelta) / 0xFF;
       r = iRed   + (int)( ( iBGRed   - iRed   ) * fDelta );
@@ -607,7 +611,7 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
       }
     }
     theImage.save ( qsFileName, "PNG", 100 );  // 100%== No compression. png image
-    
+
     if ( ( iTotalCount > 20 ) && ( pProgressBar ) ) {
       pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );
       if ( t%10 == 0 ) 
