@@ -399,7 +399,7 @@ void TemplateDownload::downloadThumbnails ( )
       listOfThumbnails.append ( qsUrl );
     }
   }
-  if (listOfThumbnails.count () > 0 )  
+  if (listOfThumbnails.count () > 0 )
     m_Network.copy ( listOfThumbnails, "/tmp" );
 }
 
@@ -521,7 +521,7 @@ void TemplateDownload::slotDownload ( )
   QString                 qsOutput;
   QIconViewItem          *pItem;
   QIconView              *pIconView = m_pIconViewStatic;
-  
+
   m_pTabMain->setCurrentPage ( 2 );
   m_pButtonNext->setText ( "Finish" );
   m_iStage         = 4;
@@ -542,11 +542,11 @@ void TemplateDownload::slotDownload ( )
 	      m_iTotalBytes += pEntry->iLocationSize;
 	    }
 	  }
-	}      
+	}
       } // if pItem->isSelected ()
       pItem = pItem->nextItem ( );
     }   // while ( pItem ) ...
-    
+
     if ( t == 0 )
       pIconView  = m_pIconViewAnimated;
     else if ( t == 1 )
@@ -557,22 +557,23 @@ void TemplateDownload::slotDownload ( )
   m_pEditDownload->append ( qsOutput );
   // sanity check ...
   if ( iSelectedCounter < 1 ) {
-    if ( MessageBox::question ( NULL, tr ( "Warning" ), tr ( "No templates selected.\nDo you want to start over again ?" ), 
-				QMessageBox::Yes, QMessageBox::No ) == QMessageBox::Yes )
+    if ( MessageBox::question ( NULL, tr ( "Warning" ), tr ( "No templates selected.\nDo you want to start over again ?" ), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::Yes )
       resetDialog ( );
     else
       accept      ( );
+    return;
   }
 
   // Okay at this point we can start downloading the template files.
   lockDialog ( true );
+  m_pButtonDownload->setEnabled ( false );
   m_iCurrentEntry  = 0;
   downloadTemplate ( 0 );
 }
 
 void TemplateDownload::downloadTemplate ( int iCurrentEntry )
 {
-  if ( iCurrentEntry < m_xml.entryCount ( ) ) {
+  if (   iCurrentEntry < m_xml.entryCount ( ) ) {
     Xml::Entry *pEntry = m_xml.entry ( iCurrentEntry );
     if ( ( ! pEntry ) || ( ! pEntry->bSelectedForInstall ) ) { // if this entry is not selected for download, then go to the next
       downloadTemplate ( ++m_iCurrentEntry );
@@ -592,6 +593,7 @@ void TemplateDownload::downloadTemplate ( int iCurrentEntry )
       return;
     }
   }
+  m_pButtonDownload->setEnabled ( true );
   m_pEditDownload->append ( tr( "Done downloading templates.") );
   installTemplates ( );
 }
