@@ -144,7 +144,6 @@ TemplateWizard::DropZone::~DropZone ()
 TemplateWizard::TemplateWizard( QWidget* parent, const char* name, WFlags fl )
     : uiTemplateWizard( parent, name, fl )
 {
-	m_pDVDAuthor      = NULL;
 	m_fScale          = 0.0f;
 	m_bDontRestart    = false;
 	m_pListBoxToolTip = NULL;
@@ -185,9 +184,8 @@ void TemplateWizard::showDialog ()
 	initTab ( QString ("transition"), m_pIconViewTransition );
 }
 
-void TemplateWizard::initMe (QDVDAuthor*pDVDAuthor)
+void TemplateWizard::initMe ( )
 {
-	m_pDVDAuthor = pDVDAuthor;
 	refreshComboMenu ( );
 	setNextEnabled   ( page ( 0 ), false );
 	setFinishEnabled ( page ( 1 ), true  );
@@ -213,7 +211,7 @@ void TemplateWizard::initMe (QDVDAuthor*pDVDAuthor)
 	WizardPageLayout_2->addItem( spacer3, 1, 2 );
 	QSpacerItem *spacer3_2 = new QSpacerItem( 2, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	WizardPageLayout_2->addItem( spacer3_2, 1, 0 );
-    
+
 	connect (m_pComboMenu, SIGNAL(activated (const QString &)), this, SLOT(slotTargetMenuChanged (const QString &)));
 	resize( QSize(739, 536).expandedTo(minimumSizeHint()) );
 	clearWState( WState_Polished );
@@ -244,17 +242,14 @@ void TemplateWizard::refreshComboMenu ()
 	if (m_qsCurrentTemplate.isEmpty())
 		m_qsCurrentTemplate = QString ("New Menu");
 
-	if (m_pDVDAuthor)	{
-		// Here we ensure we have a unique name
-		m_qsCurrentTemplate = m_pDVDAuthor->getUniqueMenuTitle (m_qsCurrentTemplate, 0);
-	}
+	// Here we ensure we have a unique name
+	m_qsCurrentTemplate = Global::pApp->getUniqueMenuTitle (m_qsCurrentTemplate, 0);
+
 	m_pComboMenu->insertItem (m_qsCurrentTemplate);
 	m_pComboMenu->insertItem (VMGM_LABEL);
-	if ( ! m_pDVDAuthor )
-		return;
 
-	DVDMenu *pMainMenu = m_pDVDAuthor->getVMGMenu ( );
-	QValueList<DVDMenu *> listMenus = m_pDVDAuthor->getSubMenus ();
+	DVDMenu *pMainMenu = Global::pApp->getVMGMenu ( );
+	QValueList<DVDMenu *> listMenus = Global::pApp->getSubMenus ();
 	for (t=0;t<listMenus.count();t++)
 		m_pComboMenu->insertItem (listMenus[t]->name());
 	// if the main menu is empty, then we should suggest this instead of a new menu ...
@@ -269,8 +264,8 @@ void TemplateWizard::initPreview ()
 	m_pLabelPreview->hide();
 
 	// Here we create the mediaEngine for this dialog.
-	MediaInfo *pMediaInfo   = m_pDVDAuthor->getMediaInfo  ();
-	void      *pMediaEngine = pMediaInfo->getMediaEngine ();
+	MediaInfo *pMediaInfo   = Global::pApp->getMediaInfo ( );
+	void      *pMediaEngine = pMediaInfo->getMediaEngine ( );
 	m_pMediaInterface = MediaCreator::createPreferredWidget (m_pFramePreview, "TemplateMediaWidget", pMediaEngine);
 	connect (m_pMediaInterface, SIGNAL(signalPlaybackFinished()), this, SLOT(slotPlaybackFinished()));
 	
@@ -288,17 +283,16 @@ void TemplateWizard::initDragList ()
 	SourceFileEntry *pEntry;
 	SourceFileInfo  *pInfo;
 	int iWidth = 125;
-	if ( ! m_pDVDAuthor )
-		return;
+
 	m_listSourceFileDescriptions.clear ();
 	m_pListBoxSources->clear ();
-	for (t=0;(int)t<m_pDVDAuthor->sourceFileCount ();t++)	{
-		pEntry = m_pDVDAuthor->sourceFileEntry(t);
+	for ( t=0; (int)t<Global::pApp->sourceFileCount  ( ); t++ )  {
+		pEntry  = Global::pApp->sourceFileEntry ( t );
 		if ( ! pEntry )
 			continue;
-		if (pEntry->bSoundSource)
+		if ( pEntry->bSoundSource )
 			continue;
-		for (i=0;i<pEntry->listFileInfos.count (); i++)	{
+		for ( i=0; i<pEntry->listFileInfos.count ( ); i++ )  {
 			pInfo = pEntry->listFileInfos[i];
 			if ( ( ! pInfo ) || ( ! pInfo->pPreview ) )
 				continue;
@@ -395,7 +389,7 @@ void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
   QPixmap thumbnail;
   QFile   theFile;
   QDir    theDir;
-  
+
   // First we determine where the click came from
   m_bDontRestart = true;
   m_pMediaInterface->stop ();
@@ -412,7 +406,7 @@ void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
     m_bLocalTemplate = false;
     m_qsPathName = QString ("%1/share/qdvdauthor/%2/%3/").arg(PREFIX_DIRECTORY).arg( qsType ).arg(pIconViewItem->text());
   }
-  
+
   QFileInfo fileInfo ( m_qsPathName + QString ( "thumbnail.mpg" ) );
   if ( fileInfo.exists ( ) ) {
     m_pLabelPreview->hide();
@@ -424,7 +418,7 @@ void TemplateWizard::slotIconViewClicked (QIconViewItem *pIconViewItem)
       m_pFramePreview->setFixedSize ( thumbnail.size ( ) );
     else
       m_pFramePreview->setFixedSize ( 200, 150 );
-      
+
     theFile.setName ( m_qsPathName+QString ( "thumbnail.mpg" ) );
     m_pMediaInterface->playMRL ( m_qsPathName + QString ( "thumbnail.mpg" ) );
     m_bDontRestart = false;
@@ -484,11 +478,11 @@ void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
 
   if ( ! QTextDrag::decode(pDropEvent, theText) )
     return;
-  
+
   // The first step is to verify that it was dropped over a DropZone.
   thePos.setX ((int)(pDropEvent->pos().x () / m_fScale));
   thePos.setY ((int)(pDropEvent->pos().y () / m_fScale));
-  
+
   for (t=0;t<m_listDropZones.count();t++)	{
     if (m_listDropZones[t]->rect.contains (thePos))	{
       pDropZone = m_listDropZones[t];
@@ -497,24 +491,23 @@ void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
   }
   if ( ! pDropZone )
     return;
-  
+
   // Get the previewImage ...
-  if (m_pDVDAuthor)	{
-    for (t=0;(int)t<m_pDVDAuthor->sourceFileCount(); t++)	{
-      pEntry = m_pDVDAuthor->sourceFileEntry ( t );
-      for (i=0;i<pEntry->listFileInfos.count();i++)	{
-	if ( (pEntry)  &&  (theText.contains (pEntry->listFileInfos[i]->qsFileName) > 0 ) )	{
-	  pDropZone->qsFileName   = pEntry->listFileInfos[i]->qsFileName;
-	  pInfo = pEntry->listFileInfos[i];
-	  // Exit both loops ...
-	  t = m_pDVDAuthor->sourceFileCount();
-	  i = pEntry->listFileInfos.count  ();
-	}
+  for ( t=0; (int)t<Global::pApp->sourceFileCount ( ); t++ )  {
+    pEntry = Global::pApp->sourceFileEntry ( t );
+    for ( i=0; i<pEntry->listFileInfos.count ( ); i++ )  {
+      if ( pEntry && ( theText.contains ( pEntry->listFileInfos[i]->qsFileName ) > 0 ) )  {
+        pDropZone->qsFileName = pEntry->listFileInfos[i]->qsFileName;
+        pDropZone->bMovie     = true;
+        pInfo = pEntry->listFileInfos[i];
+        // Exit both loops ...
+        t = Global::pApp->sourceFileCount ( );
+        i = pEntry->listFileInfos.count   ( );
       }
     }
   }
-  DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
-  pDropZone->bMovie = pDND ? ( ! pDND->bImageButton ) : true;
+//  DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+//  pDropZone->bMovie = pDND ? ( ! pDND->bImageButton ) : true;
 
   if ( ( pDropZone->iType != DropZone::TextObject ) && ( pDropZone->iType != DropZone::FrameObject ) )  {
     if (pInfo && pInfo->pPreview) {
@@ -528,11 +521,13 @@ void TemplateWizard::droppedSomething (QDropEvent *pDropEvent)
       theImage = QImage().fromMimeSource( "error.jpg" );
       theImage = theImage.smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleFree );
     }
-    if ( ! pDropZone->bMovie ) {
+
+    DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+    if ( pDND ? pDND->bImageButton : false ) {
       Utils     theUtil;
       QFileInfo fileInfo ( pDropZone->qsFileName );
-      pDropZone->qsFileName = theUtil.getTempFile ( fileInfo.baseName ( ) ) + QString (".png");
-      theImage.save ( pDropZone->qsFileName, "PNG", 100 );
+      pDropZone->qsImagePreview = theUtil.getTempFile ( fileInfo.baseName ( ) ) + QString (".png");
+      theImage.save ( pDropZone->qsImagePreview, "PNG", 100 );
     }
 
     // Set the DropZoneValues ...
@@ -551,10 +546,8 @@ void TemplateWizard::slotTargetMenuChanged (const QString &qsMenuName)
 	// Here we check if we have a new or an existing menu.
 	bool bEditable = true;
 
-	if ( m_pDVDAuthor )	{
-		if (m_pDVDAuthor->getSubMenuByName (qsMenuName))
-			bEditable = false;
-	}
+	if ( Global::pApp->getSubMenuByName ( qsMenuName ) )
+		bEditable = false;
 	m_pComboMenu->setEditable ( bEditable );
 }
 
@@ -564,10 +557,10 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
   QPoint mousePos;
   QString qsFileName, qsFilter, qsExtensions;
   DropZone *pDropZone = NULL;
-  
+
   mousePos.setX ((int)( pMouseEvent->pos ().x() / m_fScale ));
   mousePos.setY ((int)( pMouseEvent->pos ().y() / m_fScale ));
-  
+
   for (t=0;t<m_listDropZones.count();t++)	{
     if (m_listDropZones[t]->rect.contains (mousePos))	{
       pDropZone = m_listDropZones[t];
@@ -576,9 +569,9 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
   }
   if ( ! pDropZone )
     return;
-  
-  qsFilter   = m_pDVDAuthor->getImageFilter ();
-  qsFilter  += " " + m_pDVDAuthor->getMovieFilter ();
+
+  qsFilter   = Global::pApp->getImageFilter ( );
+  qsFilter  += " " + Global::pApp->getMovieFilter ( );
   qsFileName = FilePreviewDialog::getOpenFileName ( NULL, Global::qsCurrentPath, tr ("Images/Movies (") + qsFilter + QString (")"));
   if (qsFileName.isNull())
     return;
@@ -587,15 +580,14 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
   Utils  theUtil;
 
   QFileInfo backgroundInfo (qsFileName);
-  MediaInfo *pMediaInfo = m_pDVDAuthor->getMediaInfo ();
+  MediaInfo *pMediaInfo = Global::pApp->getMediaInfo ( );
+
+  Global::qsCurrentPath = backgroundInfo.absFilePath ( );
 
-  Global::qsCurrentPath = backgroundInfo.absFilePath();
-  
   pDropZone->qsFileName = qsFileName;
   qsExtensions = pMediaInfo->getExtensions (true);
   if (qsExtensions.find ("."+backgroundInfo.extension(FALSE), 0, FALSE) > -1)	{
-    DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
-    pDropZone->bMovie = pDND ? ( ! pDND->bImageButton ) : true;
+    pDropZone->bMovie = true;
     if ( ( pDropZone->iType == DropZone::TextObject ) || ( pDropZone->iType == DropZone::FrameObject ) ) {
       refreshBackground ( );
       return;
@@ -606,15 +598,16 @@ void TemplateWizard::slotTemplateClicked (QMouseEvent *pMouseEvent)
     // The we save the screenshot in the temp dir
     qsFileName = theUtil.getTempFile(backgroundInfo.baseName())+QString (".png");
     theImage.save (qsFileName, "PNG");
-    if ( ! pDropZone->bMovie )
-           pDropZone->qsFileName = qsFileName;
+    DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+    if ( pDND && pDND->bImageButton )
+         pDropZone->qsImagePreview = qsFileName;
   }
   else	// Not a movie file, then we should reset this ...
     theImage = QImage(qsFileName);
-  
+
   if ( ( pDropZone->iType != DropZone::TextObject ) && ( pDropZone->iType != DropZone::FrameObject ) ) {
     theImage = theImage.smoothScale ((int)(m_fScale*pDropZone->rect.width()), (int)(m_fScale * pDropZone->rect.height()), QImage::ScaleMin);
-    
+
     if (pDropZone->pPixmap)
       delete pDropZone->pPixmap;
     pDropZone->pPixmap = new QPixmap;
@@ -738,8 +731,8 @@ void TemplateWizard::next ()
 	// The user clicked the next button.
 	if (m_qsPathName.isEmpty ())
 		return;
-	if ( ! m_pComboMenu->editable() )	{
-		DVDMenu *pDVDMenu = m_pDVDAuthor->getSubMenuByName(m_pComboMenu->currentText());
+	if ( ! m_pComboMenu->editable ( ) )	{
+		DVDMenu *pDVDMenu = Global::pApp->getSubMenuByName ( m_pComboMenu->currentText ( ) );
 		if ( ( pDVDMenu) && ( ! pDVDMenu->isEmpty () ) )	{
 			if (QMessageBox::information (NULL, tr ("Override Menu"), tr ("Warning the menu %1 will be replaced.\nAre you sure ?").arg (m_pComboMenu->currentText()), QMessageBox::Yes,  QMessageBox::No) == QMessageBox::No)
 			return;
@@ -806,22 +799,19 @@ QString TemplateWizard::getSourceEntryName (QString qsFileName)
   uint t, i;
   QString qsEntryName;
   SourceFileEntry *pEntry;
-  
-  if ( m_pDVDAuthor ) {
 
-    for (t=0;(int)t<m_pDVDAuthor->sourceFileCount ();t++)	{
-      pEntry = m_pDVDAuthor->sourceFileEntry(t);
-      for (i=0;i<pEntry->listFileInfos.count();i++)	{
-	if (pEntry->listFileInfos[i]->qsFileName == qsFileName)	{
-	  qsEntryName = pEntry->qsDisplayName;
-	  return qsEntryName;
-	}
+  for ( t=0; (int)t<Global::pApp->sourceFileCount ( ); t++ )  {
+    pEntry = Global::pApp->sourceFileEntry  ( t );
+    for  ( i=0; i<pEntry->listFileInfos.count ( ); i++ )	{
+      if ( pEntry->listFileInfos[i]->qsFileName == qsFileName )  {
+        qsEntryName = pEntry->qsDisplayName;
+        return qsEntryName;
       }
     }
   }
   return qsEntryName;
 }
-  
+
 void TemplateWizard::slotHelp ()
 {
   QString qsHeader, qsHtml;
@@ -846,24 +836,35 @@ void TemplateWizard::accept ()
 	// First we are going to replace the DropZone placeholder and then create a DVDMenu.
 	uint t;
 	int i, iFreeSlot, iX, iY, iWidth, iHeight;
-	QString qsAction, qsEntryName, qsEntry, qsPrefixDir, qsMenuName, qsGeometry, qsCurrentPath, qsType;
+	QString qsAction, qsEntryName, qsEntry, qsPrefixDir, qsMenuName;
+	QString qsGeometry, qsCurrentPath, qsType, qsExtensions;
 	QFileInfo fileInfo;
 	QStringList listAddMovies;
- 
+	DropZone *pDropZone;
+	bool bDropToImage;
+
 	QCursor myCursor (QCursor::WaitCursor);
 	setCursor(myCursor);
 	qsCurrentPath = Global::qsCurrentPath;
-	iFreeSlot = m_pDVDAuthor->getFreeSourceSlot ();
+	iFreeSlot = Global::pApp->getFreeSourceSlot ( );
 	qsEntryName.sprintf ("[%02d] - source", iFreeSlot);
 	
-	qsPrefixDir = QString ("%1/.qdvdauthor/").arg( QDir::homeDirPath () );
+	qsPrefixDir = QString ("%1/.qdvdauthor/").arg( QDir::homeDirPath ( ) );
 	if ( ! m_bLocalTemplate ) 
 	  qsPrefixDir = QString ("%1/share/qdvdauthor/").arg( PREFIX_DIRECTORY );
 
 	m_qsXMLDVDMenu.replace (QString ("+PREFIX_DIRECTORY+"), qsPrefixDir);
-	for (t=0;t<m_listDropZones.count();t++)	{
-		i = m_listDropZones[t]->iNumber;
-		if (m_listDropZones[t]->qsFileName.isEmpty())	{
+	for ( t=0; t<m_listDropZones.count ( ); t++ )  {
+		pDropZone = m_listDropZones[t];
+		i = pDropZone->iNumber;
+
+		fileInfo.setFile ( pDropZone->qsFileName );
+		bDropToImage = false;
+		qsExtensions = Global::pApp->getImageFilter ( );
+		if ( qsExtensions.find ( "."+fileInfo.extension ( FALSE ), 0, FALSE ) > -1 )
+		  bDropToImage = true;
+
+		if ( pDropZone->qsFileName.isEmpty())	{
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_OBJECT_TYPE+").arg(i), QString ("IgnoreObject"));
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BUTTON+").arg(i), QString ("IgnoreObject"));
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_FILE_NAME+").arg(i), QString ());
@@ -878,7 +879,7 @@ void TemplateWizard::accept ()
 		  QString qsButtonXml, qsPattern, qsSourceEntry;
 		  QRegExp rx;
 		  // Determine the EntryName by parsing through the currently existng SourceFileEntries and trying to find the defined file.
-		  qsSourceEntry = getSourceEntryName ( m_listDropZones[t]->qsFileName );
+		  qsSourceEntry = getSourceEntryName ( pDropZone->qsFileName );
 		  if ( qsSourceEntry.isEmpty ( ) ) // If this movie is not yet in a SourceFileEntry, then use he newly created one.
 		       qsSourceEntry = qsEntryName;
 		  qsSourceEntry.replace ( "<", "&lt;" );
@@ -886,7 +887,7 @@ void TemplateWizard::accept ()
 		  rx.setMinimal ( true );
 		  qsPattern = QString ( "DROP_ZONE_%1_BUTTON[^>]*>.*</.DROP_ZONE_%2_BUTTON.>" ).arg ( i ).arg ( i );		  
 		  rx.setPattern ( qsPattern );
-		  
+
 		  if ( m_qsXMLDVDMenu.find ( rx ) > -1 ) {
 		    qsButtonXml = rx.cap ( 0 );
 		    if ( qsButtonXml.find ( "+DROP_ZONE_SOURCE_ENTRY+" ) > -1 )
@@ -895,47 +896,50 @@ void TemplateWizard::accept ()
 		      qsButtonXml.replace ( "Action=", "SourceEntry=\"" + qsSourceEntry + "\" Action=" );
 		  }
 		  // TODO: fix this function ...
-		  adjustPixmapHeight ( m_listDropZones[t]->pPixmap, qsButtonXml );
+		  adjustPixmapHeight ( pDropZone->pPixmap, qsButtonXml );
 
 		  m_qsXMLDVDMenu.replace ( rx, qsButtonXml );
 		} // end of replacing this buttonObjects DROP_ZONE_SOURCE_ENTRY ...
 
-		fileInfo.setFile ( m_listDropZones[t]->qsFileName );
 		// Next we take care of the geometry
 		iWidth = iHeight = 0;
 		// the pixmap should have the real extensions of the Object
-		if ( m_listDropZones[t]->pPixmap ) {
-		  iWidth  = (int) ( m_listDropZones[t]->pPixmap->width ( ) / m_fScale + 0.5 );
-		  iHeight = (int) ( m_listDropZones[t]->pPixmap->height( ) / m_fScale + 0.5 );
+		if ( pDropZone->pPixmap ) {
+		  iWidth  = (int) ( pDropZone->pPixmap->width ( ) / m_fScale + 0.5 );
+		  iHeight = (int) ( pDropZone->pPixmap->height( ) / m_fScale + 0.5 );
 		}
 		if ( iWidth  < 2 )
-		     iWidth  = m_listDropZones[t]->rect.width ( );
+		     iWidth  = pDropZone->rect.width ( );
 		if ( iHeight < 2 )
-		     iHeight = m_listDropZones[t]->rect.height( );
-		iX = (int)((m_listDropZones[t]->rect.width () - iWidth )/2.0 + m_listDropZones[t]->rect.x());
-		iY = (int)((m_listDropZones[t]->rect.height() - iHeight)/2.0 + m_listDropZones[t]->rect.y());
+		     iHeight = pDropZone->rect.height( );
+		iX = (int)(( pDropZone->rect.width () - iWidth )/2.0 + pDropZone->rect.x());
+		iY = (int)(( pDropZone->rect.height() - iHeight)/2.0 + pDropZone->rect.y());
 		qsGeometry = QString (" X=\"%1\" Y=\"%2\" Width=\"%3\" Height=\"%4\" ").arg(iX).arg(iY).arg(iWidth).arg(iHeight);
 
-		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_FILE_NAME+").arg(i), fileInfo.absFilePath());
+//		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_FILE_NAME+").arg(i), fileInfo.absFilePath());
 		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BASE_NAME+").arg(i), fileInfo.baseName());
 //		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BASE_NAME+").arg(i), fileInfo.fileName());
-		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BUTTON+").arg(i), QString ("ButtonObject"));
-		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_GEOMETRY+").arg(i), qsGeometry);
+		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_BUTTON+"   ).arg(i), QString ("ButtonObject"));
+		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_GEOMETRY+" ).arg(i), qsGeometry);
 		qsType = "ImageObject"; // default
-		if ( m_listDropZones[t]->bMovie )
-		  qsType = "MovieObject";
+		DragNDropContainer *pDND = Global::pApp->getDragNDropContainer ( );
+		if ( pDND ? ! pDND->bImageButton : true )  {
+		  // Last check is to see if we have a img on our hand
+		  if ( ! bDropToImage )
+		    qsType = "MovieObject";
+		}
 		// Note we do not want to change Frames or text ...
-		if ( m_listDropZones[t]->iType == DropZone::TextObject )
+		if ( pDropZone->iType == DropZone::TextObject )
 		  qsType = "TextObject";
-		else if ( m_listDropZones[t]->iType == DropZone::FrameObject )
+		else if ( pDropZone->iType == DropZone::FrameObject )
 		  qsType = "FrameObject";
 
-		if (m_listDropZones[t]->bMovie)	{
+		if ( pDropZone->bMovie )  {
 			// Note: if we find the file already in a SourceFileEntry, then we do not need to add it again.
-			qsEntry = getSourceEntryName (m_listDropZones[t]->qsFileName);
+			qsEntry = getSourceEntryName ( pDropZone->qsFileName );
 			if (qsEntry.isEmpty())	{ // If nothing has been found in the current SourceFileEntry list
 				qsEntry = qsEntryName;
-				listAddMovies.append (m_listDropZones[t]->qsFileName);
+				listAddMovies.append ( pDropZone->qsFileName );
 			}
 			qsEntry.replace ("<", "&lt;");
 			qsEntry.replace (">", "&gt;");
@@ -944,16 +948,23 @@ void TemplateWizard::accept ()
 			m_qsXMLDVDMenu.replace ( QString ( "+DROP_ZONE_%1_MOVIE_SIZE+" ).arg( i ),  QString ( "720x480" ) );
 		}
 		else	{	// The image button should jump to the MainMenu  jump+-+vmgm+-+
-			qsAction = QString ("jump+-+vmgm+-+");
+			qsAction =  QString  ( "jump+-+vmgm+-+" );
 			m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_OBJECT_TYPE+").arg(i), qsType );
 		}
-		m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_%1_ACTION+").arg(i), qsAction);
+		if ( ! bDropToImage && pDND ? pDND->bImageButton : false )
+			fileInfo.setFile ( pDropZone->qsImagePreview );
+
+		m_qsXMLDVDMenu.replace ( QString ( "+DROP_ZONE_%1_FILE_NAME+"  ).arg ( i ), fileInfo.absFilePath ( ) );
+		m_qsXMLDVDMenu.replace ( QString ( "+DROP_ZONE_%1_ACTION+"     ).arg ( i ), qsAction );
 	}
 	// In case we missed one ...
-	m_qsXMLDVDMenu.replace (QString ("+DROP_ZONE_SOURCE_ENTRY+"), qsEntryName);
+	m_qsXMLDVDMenu.replace ( QString ("+DROP_ZONE_SOURCE_ENTRY+"), qsEntryName );
+	// Here we remove the PlayMe which is empty ( with or without CR )
+	m_qsXMLDVDMenu.remove  ( QString ( "<PlayMe></PlayMe>\n" ) );
+	m_qsXMLDVDMenu.remove  ( QString (  "<PlayMe></PlayMe>"  ) );
 
-	if (listAddMovies.count())
-		m_pDVDAuthor->addMovieList (listAddMovies, &qsEntryName);
+	if ( listAddMovies.count ( ) )
+		Global::pApp->addMovieList (listAddMovies, &qsEntryName);
 
 	// Lastly we replace <MenuSound> with a real deal 
 	handleMenuAudio ( );
@@ -969,7 +980,7 @@ void TemplateWizard::accept ()
 
 	float fLoadVersion = m_qsTemplateVersion.toFloat ( );
 	// if the menu exist we take this one over
-	DVDMenu *pDVDMenu = m_pDVDAuthor->getSubMenuByName(m_pComboMenu->currentText());
+	DVDMenu *pDVDMenu  = Global::pApp->getSubMenuByName ( m_pComboMenu->currentText ( ) );
 	if ( pDVDMenu )	{
 		qsMenuName = m_pComboMenu->currentText();
 		pDVDMenu->clear ();
@@ -979,23 +990,23 @@ void TemplateWizard::accept ()
 		pDVDMenu->updateDVDMenu();
 	}
 	else	{ // Otherwise we will create a new menu.
-		pDVDMenu = new DVDMenu(m_pDVDAuthor);
-		qsMenuName = m_pDVDAuthor->getUniqueMenuTitle (m_pComboMenu->currentText(), 0);
+		pDVDMenu   = new DVDMenu ( Global::pApp );
+		qsMenuName = Global::pApp->getUniqueMenuTitle ( m_pComboMenu->currentText ( ), 0 );
 		pDVDMenu->readProjectFile ( menuElement, fLoadVersion );
 		pDVDMenu->getInterface    ( )->qsMenuName = qsMenuName;
 		pDVDMenu->setTabLabel     ( qsMenuName );
 		pDVDMenu->updateDVDMenu   ( );
-		m_pDVDAuthor->addDVDMenu  ( pDVDMenu );
+		Global::pApp->addDVDMenu  ( pDVDMenu );
 	}
 	Global::qsCurrentPath = qsCurrentPath;
 
-	m_pDVDAuthor->slotAutosave ();
-	m_pDVDAuthor->slotUpdateStructure ();
+	Global::pApp->slotAutosave ( );
+	Global::pApp->slotUpdateStructure ( );
 	// Here we have to create the SoourceFileEntry for the DVDAuthorObject
 	// Note, the SourceFileEntry holds N SourceFileInfo's
 	refreshMovieButtons ( pDVDMenu );
 	QWizard::accept();
-	QTimer::singleShot (10, m_pDVDAuthor, SLOT(slotDeleteTemplateWizard()));
+	QTimer::singleShot (10, Global::pApp, SLOT ( slotDeleteTemplateWizard ( ) ) );
 	myCursor = QCursor(QCursor::ArrowCursor);
 	setCursor(myCursor);
 }
@@ -1045,7 +1056,7 @@ void TemplateWizard::adjustPixmapHeight ( QPixmap *pPixmap, QString &qsButtonXml
   int iPos, iHeight = (int)((float)pPixmap->height ( ) / m_fScale + 0.5 );
   if ( iHeight < 1 )
     return;
-  
+
   //printf ( "\n\n%s\n----------------\n", qsButtonXml.ascii ( ) );
   qsHeight = QString ( "Height=\"%1\"" ).arg ( iHeight );
 
@@ -1093,13 +1104,13 @@ void TemplateWizard::handleMenuAudio ( )
 	iPos += rx.matchedLength ( );
       }
     }
-    
+
     if ( listSoundFiles.count () > 0 ) {
       // Okay, we add the sound source
-      m_pDVDAuthor->checkForNewProject ( );
-      m_pDVDAuthor->addSound ( listSoundFiles );
+      Global::pApp->checkForNewProject ( );
+      Global::pApp->addSound ( listSoundFiles );
       // And the created SourceFileEntry will be the last in the list.
-      SourceFileEntry *pEntry = m_pDVDAuthor->sourceFileEntry ( m_pDVDAuthor->sourceFileCount ( ) - 1 );
+      SourceFileEntry *pEntry = Global::pApp->sourceFileEntry ( Global::pApp->sourceFileCount ( ) - 1 );
       if ( pEntry && pEntry->bSoundSource ) {
 	QString qsEntryName = pEntry->qsDisplayName;
 	qsEntryName = qsEntryName.replace ( "<", "&lt;" );
