@@ -3,6 +3,12 @@
 // This file contains the import filter for
 // dvdauthor-xml files, and spumux-xml files.
 //
+//
+//   Created : 
+//        by : Varol OKan
+// Copyright : (c) Varol Okan
+// License   : GPL v 2.0
+//
 /////////////////////////////////////////////////////////
 #ifndef XML_DVDAUTHOR_H
 #define XML_DVDAUTHOR_H
@@ -56,16 +62,16 @@
 #define TEXTSUB_FONT             "font"
 #define TEXTSUB_TRANSPARENT      "transparent"
 #define TEXTSUB_FONTSIZE         "fontsize"
-#define TEXTSUB_HORIZ_ALIGNMENT  "horizontal_alignment"
-#define TEXTSUB_VERT_ALIGNMENT   "vertical_alignment"
-#define TEXTSUB_LEFT_MARGIN      "left_margin"
-#define TEXTSUB_RIGHT_MARGIN     "right_margin"
-#define TEXTSUB_BOTTOM_MARGIN    "bottom_margin"
-#define TEXTSUB_TOP_MARGIN       "top_margin"
-#define TEXTSUB_SUBTITLE_FPS     "subtitle_fps"
-#define TEXTSUB_MOVIE_FPS        "movie_fps"
-#define TEXTSUB_MOVIE_WIDTH      "movie_width"
-#define TEXTSUB_MOVIE_HEIGHT     "movie_height"
+#define TEXTSUB_HORIZ_ALIGNMENT  "horizontal-alignment"
+#define TEXTSUB_VERT_ALIGNMENT   "vertical-alignment"
+#define TEXTSUB_LEFT_MARGIN      "left-margin"
+#define TEXTSUB_RIGHT_MARGIN     "right-margin"
+#define TEXTSUB_BOTTOM_MARGIN    "bottom-margin"
+#define TEXTSUB_TOP_MARGIN       "top-margin"
+#define TEXTSUB_SUBTITLE_FPS     "subtitle-fps"
+#define TEXTSUB_MOVIE_FPS        "movie-fps"
+#define TEXTSUB_MOVIE_WIDTH      "movie-width"
+#define TEXTSUB_MOVIE_HEIGHT     "movie-height"
 #define BUTTON_LABEL		 "name"
 #define BUTTON_X0		 "x0"
 #define BUTTON_Y0		 "y0"
@@ -122,11 +128,20 @@ public:
 		subpicture_struct ()
 		{node_name=QString("subpicture");};
 		virtual ~subpicture_struct () {};
-		virtual bool readXml (QDomElement *);
+		virtual bool readXml (QDomElement  * );
 		virtual bool writeXml(QDomDocument *, QDomElement *);
 		QString lang;		// language
 	};
-       class pre_struct : public base_struct  {
+        class fpc_struct : public base_struct  {
+		public:
+		fpc_struct ()
+		{node_name=QString ("fpc");};
+		virtual ~fpc_struct  ( ) { };
+		virtual bool readXml ( QDomElement  * );
+		virtual bool writeXml( QDomDocument *, QDomElement *);
+		QString value; // commands to be executed once at startup
+	};
+        class pre_struct : public base_struct  {
 		public:
 		pre_struct ()
 		{node_name=QString("pre");};
@@ -209,7 +224,7 @@ public:
 		QString 	lang;		// language-code
 		video_struct	video;
 		audio_struct	audio[8];
-		subpicture_struct subpicture;
+		subpicture_struct subpicture[32];
 		pgc_struct	**ppArrayPgc;
 	};
 	class titles_struct : public base_struct {
@@ -223,7 +238,8 @@ public:
 		QString		titles;
 		video_struct	video;
 		audio_struct	audio[8];
-		pgc_struct	**ppArrayPgc;
+		subpicture_struct   subpicture[32];
+		pgc_struct	  **ppArrayPgc;
 	};
 	class vmgm_struct : public base_struct {
 		public:
@@ -232,8 +248,9 @@ public:
 		virtual bool readXml (QDomElement  *);
 		virtual bool writeXml(QDomDocument *, QDomElement *);
 		menus_struct  *addMenus();
-
-		menus_struct	**ppArrayMenus;
+		
+		fpc_struct   fpc;
+		menus_struct **ppArrayMenus;
 	};
 	class titleset_struct : public base_struct {
 		public:
